@@ -106,6 +106,6 @@ private:
   }
 };
 
-typedef counted_ptr<byte_buffer_c> byte_buffer_cptr;
+typedef std::shared_ptr<byte_buffer_c> byte_buffer_cptr;
 
 #endif // __MTX_COMMON_BYTE_BUFFER_H
