@@ -22,12 +22,10 @@
 #include <matroska/FileKax.h>
 
 #include "common/hacks.h"
-#include "common/mm_io.h"
 #include "common/random.h"
 #include "common/stereo_mode.h"
 #include "common/strings/editing.h"
 #include "common/translation.h"
-#include "common/xml/element_mapping.h"
 
 #if !defined(LIBMATROSKA_VERSION) || (LIBMATROSKA_VERSION <= 0x000801)
 #define matroska_init()
@@ -59,6 +57,7 @@ fix_windows_errormode() {
 unsigned int verbose = 1;
 
 extern bool g_warning_issued;
+static std::string s_program_name;
 
 // Functions
 
@@ -118,7 +117,9 @@ mtx_common_cleanup() {
 }
 
 void
-mtx_common_init() {
+mtx_common_init(std::string const &program_name) {
+  s_program_name = program_name;
+
 #if defined(SYS_WINDOWS)
   fix_windows_errormode();
 #endif
@@ -138,8 +139,10 @@ mtx_common_init() {
   g_cc_local_utf8 = charset_converter_c::init("");
   init_cc_stdio();
 
-  xml_element_map_init();
-
   stereo_mode_c::init();
 }
 
+std::string const &
+get_program_name() {
+  return s_program_name;
+}
