@@ -11,14 +11,15 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __MTX_COMMON_COMMON_H
-#define __MTX_COMMON_COMMON_H
+#ifndef MTX_COMMON_COMMON_H
+#define MTX_COMMON_COMMON_H
 
 #undef min
 #undef max
 #undef __STRICT_ANSI__
 
 #include <algorithm>
+#include <memory>
 #include <stdexcept>
 #include <string>
 #include <vector>
@@ -44,6 +45,9 @@
 #include <boost/logic/tribool.hpp>
 #include <boost/math/common_factor.hpp>
 #include <boost/range.hpp>
+#include <boost/range/adaptor/filtered.hpp>
+#include <boost/range/adaptor/indexed.hpp>
+#include <boost/range/adaptor/map.hpp>
 #include <boost/range/algorithm_ext.hpp>
 #include <boost/range/algorithm.hpp>
 #include <boost/range/numeric.hpp>
@@ -51,9 +55,10 @@
 #include <boost/regex.hpp>
 #include <boost/system/error_code.hpp>
 
-namespace ba  = boost::algorithm;
-namespace bfs = boost::filesystem;
-namespace br  = boost::range;
+namespace balg  = boost::algorithm;
+namespace badap = boost::adaptors;
+namespace bfs   = boost::filesystem;
+namespace brng  = boost::range;
 
 #include "common/os.h"
 
@@ -78,15 +83,20 @@ namespace br  = boost::range;
 # endif
 #endif
 
-#include "common/smart_pointers.h"
 #include "common/debugging.h"
+#include "common/error.h"
+#include "common/memory.h"
+#include "common/mm_io.h"
 #include "common/output.h"
 
 namespace libebml {
-  class EbmlBinary;
+class EbmlBinary;
 };
 
+namespace libmatroska { };
+
 using namespace libebml;
+using namespace libmatroska;
 
 #define BUGMSG Y("This should not have happened. Please contact the author " \
                  "Moritz Bunkus <moritz@bunkus.org> with this error/warning " \
@@ -121,6 +131,7 @@ extern unsigned int verbose;
 #define mxfind2(it, value, cont) ((it = std::find((cont).begin(), (cont).end(), value)) != (cont).end())
 #define map_has_key(m, k)        ((m).end() != (m).find(k))
 
-void mtx_common_init();
+void mtx_common_init(std::string const &program_name);
+std::string const &get_program_name();
 
-#endif // __MTX_COMMON_COMMON_H
+#endif // MTX_COMMON_COMMON_H
