@@ -15,8 +15,6 @@
 
 #include "common/strings/editing.h"
 
-static std::string s_debug_options;
-
 static std::map<std::string, std::string> s_debugging_options;
 
 bool
@@ -28,7 +26,7 @@ debugging_requested(const char *option,
     std::map<std::string, std::string>::iterator option_ptr = s_debugging_options.find(current_option);
 
     if (s_debugging_options.end() != option_ptr) {
-      if (nullptr != arg)
+      if (arg)
         *arg = option_ptr->second;
       return true;
     }
@@ -49,26 +47,20 @@ request_debugging(const std::string &options) {
 
   for (auto &one_option : all_options) {
     std::vector<std::string> parts = split(one_option, "=", 2);
-    if (1 == parts.size())
-      s_debugging_options[parts[0]] = "";
+    if (parts[0] == "!")
+      s_debugging_options.clear();
     else
-      s_debugging_options[parts[0]] = parts[1];
+      s_debugging_options[parts[0]] = 1 == parts.size() ? std::string("") : parts[1];
   }
 }
 
-void
-clear_debugging_requests() {
-  s_debugging_options.clear();
-}
-
 void
 init_debugging() {
-  const char *value = getenv("MKVTOOLNIX_DEBUG");
-  if (nullptr != value)
-    request_debugging(value);
-  else {
-    value = getenv("MTX_DEBUG");
-    if (nullptr != value)
+  std::vector<std::string> env_vars = { "MKVTOOLNIX_DEBUG", "MTX_DEBUG", balg::to_upper_copy(get_program_name()) + "_DEBUG" };
+
+  for (auto &name : env_vars) {
+    auto value = getenv(name.c_str());
+    if (value)
       request_debugging(value);
   }
 }
