@@ -33,7 +33,7 @@ dirac::frame_t::frame_t()
 
 void
 dirac::frame_t::init() {
-  data                     = memory_cptr(nullptr);
+  data.reset();
   timecode                 = -1;
   duration                 = 0;
   contains_sequence_header = false;
@@ -224,7 +224,7 @@ dirac::es_parser_c::add_bytes(unsigned char *buffer,
   size_t previous_pos         = 0;
   int64_t previous_stream_pos = m_stream_pos;
 
-  if (m_unparsed_buffer.is_set() && (0 != m_unparsed_buffer->get_size()))
+  if (m_unparsed_buffer && (0 != m_unparsed_buffer->get_size()))
     cursor.add_slice(m_unparsed_buffer);
   cursor.add_slice(buffer, size);
 
@@ -279,18 +279,18 @@ dirac::es_parser_c::add_bytes(unsigned char *buffer,
     m_unparsed_buffer = new_unparsed_buffer;
 
   } else
-    m_unparsed_buffer = memory_cptr(nullptr);
+    m_unparsed_buffer.reset();
 }
 
 void
 dirac::es_parser_c::flush() {
-  if (m_unparsed_buffer.is_set() && (4 <= m_unparsed_buffer->get_size())) {
+  if (m_unparsed_buffer && (4 <= m_unparsed_buffer->get_size())) {
     uint32_t marker = get_uint32_be(m_unparsed_buffer->get_buffer());
     if (DIRAC_SYNC_WORD == marker)
       handle_unit(memory_c::clone(m_unparsed_buffer->get_buffer(), m_unparsed_buffer->get_size()));
   }
 
-  m_unparsed_buffer = memory_cptr(nullptr);
+  m_unparsed_buffer.reset();
 
   flush_frame();
 }
@@ -373,7 +373,7 @@ dirac::es_parser_c::handle_unknown_unit(memory_cptr packet) {
 
 void
 dirac::es_parser_c::flush_frame() {
-  if (!m_current_frame.is_set())
+  if (!m_current_frame)
     return;
 
   if (!m_pre_frame_extra_data.empty() || !m_post_frame_extra_data.empty())
@@ -384,7 +384,7 @@ dirac::es_parser_c::flush_frame() {
 
   m_frames.push_back(m_current_frame);
 
-  m_current_frame = frame_cptr(nullptr);
+  m_current_frame.reset();
 }
 
 void
