@@ -238,7 +238,7 @@ empty_ebml_master(EbmlElement *e) {
   EbmlMaster *m;
 
   m = dynamic_cast<EbmlMaster *>(e);
-  if (m == nullptr)
+  if (!m)
     return e;
 
   while (m->ListSize() > 0) {
@@ -269,7 +269,7 @@ create_ebml_element(const EbmlCallbacks &callbacks,
       continue;
 
     e = create_ebml_element(EBML_CTX_IDX_INFO(context, i), id);
-    if (e != nullptr)
+    if (e)
       return e;
   }
 
@@ -294,7 +294,7 @@ find_ebml_callbacks(const EbmlCallbacks &base,
     if (!(context != EBML_SEM_CONTEXT(EBML_CTX_IDX(context,i))))
       continue;
     result = find_ebml_callbacks(EBML_CTX_IDX_INFO(context, i), id);
-    if (nullptr != result)
+    if (result)
       return result;
   }
 
@@ -319,7 +319,7 @@ find_ebml_callbacks(const EbmlCallbacks &base,
     if (!(context != EBML_SEM_CONTEXT(EBML_CTX_IDX(context,i))))
       continue;
     result = find_ebml_callbacks(EBML_CTX_IDX_INFO(context, i), debug_name);
-    if (nullptr != result)
+    if (result)
       return result;
   }
 
@@ -341,7 +341,7 @@ find_ebml_parent_callbacks(const EbmlCallbacks &base,
     if (!(context != EBML_SEM_CONTEXT(EBML_CTX_IDX(context,i))))
       continue;
     result = find_ebml_parent_callbacks(EBML_CTX_IDX_INFO(context, i), id);
-    if (nullptr != result)
+    if (result)
       return result;
   }
 
@@ -363,7 +363,7 @@ find_ebml_semantic(const EbmlCallbacks &base,
     if (!(context != EBML_SEM_CONTEXT(EBML_CTX_IDX(context,i))))
       continue;
     result = find_ebml_semantic(EBML_CTX_IDX_INFO(context, i), id);
-    if (nullptr != result)
+    if (result)
       return result;
   }
 
@@ -372,18 +372,16 @@ find_ebml_semantic(const EbmlCallbacks &base,
 
 EbmlMaster *
 sort_ebml_master(EbmlMaster *m) {
-  if (m == nullptr)
+  if (!m)
     return m;
 
   int first_element = -1;
   int first_master  = -1;
   size_t i;
   for (i = 0; i < m->ListSize(); i++) {
-    if ((dynamic_cast<EbmlMaster *>((*m)[i]) != nullptr) &&
-        (first_master == -1))
+    if (dynamic_cast<EbmlMaster *>((*m)[i]) && (-1 == first_master))
       first_master = i;
-    else if ((dynamic_cast<EbmlMaster *>((*m)[i]) == nullptr) &&
-             (first_master != -1) && (first_element == -1))
+    else if (!dynamic_cast<EbmlMaster *>((*m)[i]) && (-1 != first_master) && (-1 == first_element))
       first_element = i;
     if ((first_master != -1) && (first_element != -1))
       break;
@@ -398,27 +396,34 @@ sort_ebml_master(EbmlMaster *m) {
     m->InsertElement(*e, first_master);
     first_master++;
     for (first_element++; first_element < static_cast<int>(m->ListSize()); first_element++)
-      if (dynamic_cast<EbmlMaster *>((*m)[first_element]) == nullptr)
+      if (!dynamic_cast<EbmlMaster *>((*m)[first_element]))
         break;
     if (first_element >= static_cast<int>(m->ListSize()))
       first_element = -1;
   }
 
   for (i = 0; i < m->ListSize(); i++)
-    if (dynamic_cast<EbmlMaster *>((*m)[i]) != nullptr)
+    if (dynamic_cast<EbmlMaster *>((*m)[i]))
       sort_ebml_master(dynamic_cast<EbmlMaster *>((*m)[i]));
 
   return m;
 }
 
+void
+move_children(EbmlMaster &source,
+              EbmlMaster &destination) {
+  for (auto child : source)
+    destination.PushElement(*child);
+}
+
 // ------------------------------------------------------------------------
 
 int64_t
 kt_get_default_duration(KaxTrackEntry &track) {
   KaxTrackDefaultDuration *default_duration;
 
-  default_duration = FINDFIRST(&track, KaxTrackDefaultDuration);
-  if (nullptr == default_duration)
+  default_duration = FindChild<KaxTrackDefaultDuration>(&track);
+  if (!default_duration)
     return 0;
   return uint64(*default_duration);
 }
@@ -427,8 +432,8 @@ int64_t
 kt_get_number(KaxTrackEntry &track) {
   KaxTrackNumber *number;
 
-  number = FINDFIRST(&track, KaxTrackNumber);
-  if (nullptr == number)
+  number = FindChild<KaxTrackNumber>(&track);
+  if (!number)
     return 0;
   return uint64(*number);
 }
@@ -437,8 +442,8 @@ int64_t
 kt_get_uid(KaxTrackEntry &track) {
   KaxTrackUID *uid;
 
-  uid = FINDFIRST(&track, KaxTrackUID);
-  if (nullptr == uid)
+  uid = FindChild<KaxTrackUID>(&track);
+  if (!uid)
     return 0;
   return uint64(*uid);
 }
@@ -447,8 +452,8 @@ std::string
 kt_get_codec_id(KaxTrackEntry &track) {
   KaxCodecID *codec_id;
 
-  codec_id = FINDFIRST(&track, KaxCodecID);
-  if (nullptr == codec_id)
+  codec_id = FindChild<KaxCodecID>(&track);
+  if (!codec_id)
     return "";
   return std::string(*codec_id);
 }
@@ -457,8 +462,8 @@ std::string
 kt_get_language(KaxTrackEntry &track) {
   KaxTrackLanguage *language;
 
-  language = FINDFIRST(&track, KaxTrackLanguage);
-  if (nullptr == language)
+  language = FindChild<KaxTrackLanguage>(&track);
+  if (!language)
     return "";
   return std::string(*language);
 }
@@ -467,8 +472,8 @@ int
 kt_get_max_blockadd_id(KaxTrackEntry &track) {
   KaxMaxBlockAdditionID *max_blockadd_id;
 
-  max_blockadd_id = FINDFIRST(&track, KaxMaxBlockAdditionID);
-  if (nullptr == max_blockadd_id)
+  max_blockadd_id = FindChild<KaxMaxBlockAdditionID>(&track);
+  if (!max_blockadd_id)
     return 0;
   return uint32(*max_blockadd_id);
 }
@@ -478,12 +483,12 @@ kt_get_a_channels(KaxTrackEntry &track) {
   KaxTrackAudio *audio;
   KaxAudioChannels *channels;
 
-  audio = FINDFIRST(&track, KaxTrackAudio);
-  if (nullptr == audio)
+  audio = FindChild<KaxTrackAudio>(&track);
+  if (!audio)
     return 1;
 
-  channels = FINDFIRST(audio, KaxAudioChannels);
-  if (nullptr == channels)
+  channels = FindChild<KaxAudioChannels>(audio);
+  if (!channels)
     return 1;
 
   return uint32(*channels);
@@ -494,12 +499,12 @@ kt_get_a_sfreq(KaxTrackEntry &track) {
   KaxTrackAudio *audio;
   KaxAudioSamplingFreq *sfreq;
 
-  audio = FINDFIRST(&track, KaxTrackAudio);
-  if (nullptr == audio)
+  audio = FindChild<KaxTrackAudio>(&track);
+  if (!audio)
     return 8000.0;
 
-  sfreq = FINDFIRST(audio, KaxAudioSamplingFreq);
-  if (nullptr == sfreq)
+  sfreq = FindChild<KaxAudioSamplingFreq>(audio);
+  if (!sfreq)
     return 8000.0;
 
   return float(*sfreq);
@@ -510,12 +515,12 @@ kt_get_a_osfreq(KaxTrackEntry &track) {
   KaxTrackAudio *audio;
   KaxAudioOutputSamplingFreq *osfreq;
 
-  audio = FINDFIRST(&track, KaxTrackAudio);
-  if (nullptr == audio)
+  audio = FindChild<KaxTrackAudio>(&track);
+  if (!audio)
     return 8000.0;
 
-  osfreq = FINDFIRST(audio, KaxAudioOutputSamplingFreq);
-  if (nullptr == osfreq)
+  osfreq = FindChild<KaxAudioOutputSamplingFreq>(audio);
+  if (!osfreq)
     return 8000.0;
 
   return float(*osfreq);
@@ -526,12 +531,12 @@ kt_get_a_bps(KaxTrackEntry &track) {
   KaxTrackAudio *audio;
   KaxAudioBitDepth *bps;
 
-  audio = FINDFIRST(&track, KaxTrackAudio);
-  if (nullptr == audio)
+  audio = FindChild<KaxTrackAudio>(&track);
+  if (!audio)
     return -1;
 
-  bps = FINDFIRST(audio, KaxAudioBitDepth);
-  if (nullptr == bps)
+  bps = FindChild<KaxAudioBitDepth>(audio);
+  if (!bps)
     return -1;
 
   return uint32(*bps);
@@ -542,12 +547,12 @@ kt_get_v_pixel_width(KaxTrackEntry &track) {
   KaxTrackVideo *video;
   KaxVideoPixelWidth *width;
 
-  video = FINDFIRST(&track, KaxTrackVideo);
-  if (nullptr == video)
+  video = FindChild<KaxTrackVideo>(&track);
+  if (!video)
     return 0;
 
-  width = FINDFIRST(video, KaxVideoPixelWidth);
-  if (nullptr == width)
+  width = FindChild<KaxVideoPixelWidth>(video);
+  if (!width)
     return 0;
 
   return uint32(*width);
@@ -558,12 +563,12 @@ kt_get_v_pixel_height(KaxTrackEntry &track) {
   KaxTrackVideo *video;
   KaxVideoPixelHeight *height;
 
-  video = FINDFIRST(&track, KaxTrackVideo);
-  if (nullptr == video)
+  video = FindChild<KaxTrackVideo>(&track);
+  if (!video)
     return 0;
 
-  height = FINDFIRST(video, KaxVideoPixelHeight);
-  if (nullptr == height)
+  height = FindChild<KaxVideoPixelHeight>(video);
+  if (!height)
     return 0;
 
   return uint32(*height);
@@ -582,29 +587,29 @@ find_ebml_element_by_id(EbmlMaster *master,
 
 void
 fix_mandatory_elements(EbmlElement *master) {
-  if (nullptr != dynamic_cast<KaxInfo *>(master))
+  if (dynamic_cast<KaxInfo *>(master))
     fix_mandatory_segmentinfo_elements(master);
 
-  else if (nullptr != dynamic_cast<KaxTracks *>(master))
+  else if (dynamic_cast<KaxTracks *>(master))
     fix_mandatory_segment_tracks_elements(master);
 
-  else if (nullptr != dynamic_cast<KaxTags *>(master))
+  else if (dynamic_cast<KaxTags *>(master))
     fix_mandatory_tag_elements(master);
 
-  else if (nullptr != dynamic_cast<KaxChapters *>(master))
+  else if (dynamic_cast<KaxChapters *>(master))
     fix_mandatory_chapter_elements(master);
 }
 
 void
 remove_voids_from_master(EbmlElement *element) {
   EbmlMaster *master = dynamic_cast<EbmlMaster *>(element);
-  if (nullptr == master)
+  if (!master)
     return;
 
   size_t idx = 0;
   while (master->ListSize() > idx) {
     element = (*master)[idx];
-    if (nullptr != dynamic_cast<EbmlVoid *>(element))
+    if (dynamic_cast<EbmlVoid *>(element))
       master->Remove(idx);
 
     else {
