@@ -24,7 +24,7 @@
 using namespace libebml;
 using namespace libmatroska;
 
-#define can_be_cast(c, e) (dynamic_cast<c *>(e) != nullptr)
+#define can_be_cast(c, e) (dynamic_cast<c *>(e))
 
 bool is_valid_utf8_string(const std::string &c);
 UTFstring cstrutf8_to_UTFstring(const std::string &c);
@@ -104,16 +104,13 @@ int kt_get_v_pixel_height(KaxTrackEntry &track);
 #define INVALID_FILEPOS_T 0
 #endif
 
-#define FINDFIRST(p, c)   (static_cast<c *>(((EbmlMaster *)p)->FindFirstElt(EBML_INFO(c), false)))
-#define FINDNEXT(p, c, e) (static_cast<c *>(((EbmlMaster *)p)->FindNextElt(*e, false)))
-
 template <typename type>type &
 GetEmptyChild(EbmlMaster &master) {
   EbmlElement *e;
   EbmlMaster *m;
 
   e = master.FindFirstElt(EBML_INFO(type), true);
-  if ((m = dynamic_cast<EbmlMaster *>(e)) != nullptr) {
+  if ((m = dynamic_cast<EbmlMaster *>(e))) {
     while (m->ListSize() > 0) {
       delete (*m)[0];
       m->Remove(0);
@@ -128,7 +125,7 @@ GetNextEmptyChild(EbmlMaster &master,
                   const type &past_elt) {
   EbmlMaster *m;
   EbmlElement *e = master.FindNextElt(past_elt, true);
-  if ((m = dynamic_cast<EbmlMaster *>(e)) != nullptr) {
+  if ((m = dynamic_cast<EbmlMaster *>(e))) {
     while (m->ListSize() > 0) {
       delete (*m)[0];
       m->Remove(0);
@@ -142,7 +139,7 @@ template <typename type>type &
 AddEmptyChild(EbmlMaster &master) {
   EbmlMaster *m;
   EbmlElement *e = new type;
-  if ((m = dynamic_cast<EbmlMaster *>(e)) != nullptr) {
+  if ((m = dynamic_cast<EbmlMaster *>(e))) {
     while (m->ListSize() > 0) {
       delete (*m)[0];
       m->Remove(0);
@@ -153,6 +150,32 @@ AddEmptyChild(EbmlMaster &master) {
   return *(static_cast<type *>(e));
 }
 
+template <typename A> A*
+FindChild(EbmlMaster const *m) {
+  return static_cast<A *>(m->FindFirstElt(EBML_INFO(A)));
+}
+
+template <typename A> A*
+FindChild(EbmlElement const *e) {
+  auto m = dynamic_cast<EbmlMaster const *>(e);
+  assert(m);
+  return static_cast<A *>(m->FindFirstElt(EBML_INFO(A)));
+}
+
+template <typename A> A*
+FindNextChild(EbmlMaster const *m,
+              EbmlElement const *p) {
+  return static_cast<A *>(m->FindNextElt(*p));
+}
+
+template <typename A> A*
+FindNextChild(EbmlElement const *e,
+              EbmlElement const *p) {
+  auto m = dynamic_cast<EbmlMaster const *>(e);
+  assert(m);
+  return static_cast<A *>(m->FindNextElt(*p));
+}
+
 template<typename A> A &
 GetChild(EbmlMaster *m) {
   return GetChild<A>(*m);
@@ -171,19 +194,35 @@ GetChildAs(EbmlMaster *m) {
 template <typename A>A &
 GetFirstOrNextChild(EbmlMaster &master,
                     A *previous_child) {
-  return nullptr == previous_child ? GetChild<A>(master) : GetNextChild<A>(master, *previous_child);
+  return !previous_child ? GetChild<A>(master) : GetNextChild<A>(master, *previous_child);
 }
 
 template <typename A>A &
 GetFirstOrNextChild(EbmlMaster *master,
                     A *previous_child) {
-  return nullptr == previous_child ? GetChild<A>(*master) : GetNextChild<A>(*master, *previous_child);
+  return !previous_child ? GetChild<A>(*master) : GetNextChild<A>(*master, *previous_child);
+}
+
+template<typename T>
+memory_cptr
+find_and_clone_binary(EbmlElement &parent) {
+  auto child = FindChild<T>(static_cast<EbmlMaster &>(parent));
+  if (child)
+    return memory_c::clone(child->GetBuffer(), child->GetSize());
+  return memory_cptr{};
+}
+
+template<typename T>
+memory_cptr
+find_and_clone_binary(EbmlElement *parent) {
+  return find_and_clone_binary<T>(*parent);
 }
 
 EbmlElement *empty_ebml_master(EbmlElement *e);
 EbmlElement *create_ebml_element(const EbmlCallbacks &callbacks, const EbmlId &id);
 EbmlMaster *sort_ebml_master(EbmlMaster *e);
 void remove_voids_from_master(EbmlElement *element);
+void move_children(EbmlMaster &source, EbmlMaster &destination);
 
 const EbmlCallbacks *find_ebml_callbacks(const EbmlCallbacks &base, const EbmlId &id);
 const EbmlCallbacks *find_ebml_callbacks(const EbmlCallbacks &base, const char *debug_name);
@@ -208,7 +247,7 @@ provide_default_for_child(EbmlMaster *master,
   provide_default_for_child<A>(*master, default_value);
 }
 
-typedef counted_ptr<EbmlElement> ebml_element_cptr;
-typedef counted_ptr<EbmlMaster> ebml_master_cptr;
+typedef std::shared_ptr<EbmlElement> ebml_element_cptr;
+typedef std::shared_ptr<EbmlMaster> ebml_master_cptr;
 
 #endif // __MTX_COMMON_EBML_H
