@@ -14,9 +14,7 @@
 #ifndef __MTX_COMMON_HACKS_H
 #define __MTX_COMMON_HACKS_H
 
-#include "common/os.h"
-
-#include <string>
+#include "common/common_pch.h"
 
 // Some hacks that are configurable via command line but which should ONLY!
 // be used by the author.
@@ -42,5 +40,6 @@
 
 void engage_hacks(const std::string &hacks);
 bool hack_engaged(unsigned int id);
+void init_hacks();
 
 #endif // __MTX_COMMON_HACKS_H
