@@ -45,11 +45,11 @@ std::string
 kax_analyzer_data_c::to_string() const {
   const EbmlCallbacks *callbacks = find_ebml_callbacks(EBML_INFO(KaxSegment), m_id);
 
-  if ((nullptr == callbacks) && (EBML_ID(EbmlVoid) == m_id))
+  if (!callbacks && (EBML_ID(EbmlVoid) == m_id))
     callbacks = &EBML_CLASS_CALLBACK(EbmlVoid);
 
   std::string name;
-  if (nullptr != callbacks)
+  if (callbacks)
     name = EBML_INFO_NAME(*callbacks);
 
   else {
@@ -95,7 +95,7 @@ kax_analyzer_c::close_file() {
 
 void
 kax_analyzer_c::reopen_file(const open_mode mode) {
-  if (nullptr != m_file)
+  if (m_file)
     return;
 
   m_file   = new mm_file_io_c(m_file_name, mode);
@@ -214,7 +214,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
   int64_t file_size = m_file->get_size();
   show_progress_start(file_size);
 
-  m_segment.clear();
+  m_segment.reset();
   m_data.clear();
 
   m_file->setFilePointer(0);
@@ -222,7 +222,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
 
   // Find the EbmlHead element. Must be the first one.
   EbmlElement *l0 = m_stream->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
-  if (nullptr == l0)
+  if (!l0)
     throw mtx::kax_analyzer_x(Y("Not a valid Matroska file (no EBML head found)"));
 
   // Don't verify its data for now.
@@ -232,7 +232,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
   while (1) {
     // Next element must be a segment
     l0 = m_stream->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
-    if (nullptr == l0)
+    if (!l0)
       throw mtx::kax_analyzer_x(Y("Not a valid Matroska file (no segment/level 0 element found)"));
 
     if (EbmlId(*l0) == EBML_ID(KaxSegment))
@@ -242,7 +242,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
     delete l0;
   }
 
-  m_segment            = counted_ptr<KaxSegment>(static_cast<KaxSegment *>(l0));
+  m_segment            = std::shared_ptr<KaxSegment>(static_cast<KaxSegment *>(l0));
   int upper_lvl_el     = 0;
   bool aborted         = false;
   bool cluster_found   = false;
@@ -250,7 +250,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
 
   // We've got our segment, so let's find all level 1 elements.
   EbmlElement *l1 = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFFFFFFFFFLL, true, 1);
-  while ((nullptr != l1) && (0 >= upper_lvl_el)) {
+  while (l1 && (0 >= upper_lvl_el)) {
     m_data.push_back(kax_analyzer_data_c::create(EbmlId(*l1), l1->GetElementPosition(), l1->ElementSize(true)));
 
     cluster_found   |= is_id(l1, KaxCluster);
@@ -266,9 +266,9 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
       break;
 
     l1 = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFL, true);
-  } // while (l1 != nullptr)
+  } // while (l1)
 
-  if (nullptr != l1)
+  if (l1)
     delete l1;
 
   if (!aborted && !parse_fully)
@@ -283,7 +283,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
     return true;
   }
 
-  m_segment.clear();
+  m_segment.reset();
   m_data.clear();
 
   return false;
@@ -301,7 +301,7 @@ kax_analyzer_c::read_element(kax_analyzer_data_c *element_data) {
   const EbmlCallbacks *callbacks = find_ebml_callbacks(EBML_INFO(KaxSegment), element_data->m_id);
 
   if (!e || !callbacks || (EbmlId(*e) != EBML_INFO_ID(*callbacks))) {
-    e.clear();
+    e.reset();
     return e;
   }
 
@@ -383,7 +383,7 @@ kax_analyzer_c::adjust_segment_size() {
   if (!m_segment->IsFiniteSize())
     return;
 
-  counted_ptr<KaxSegment> new_segment = counted_ptr<KaxSegment>(new KaxSegment);
+  std::shared_ptr<KaxSegment> new_segment = std::shared_ptr<KaxSegment>(new KaxSegment);
   m_file->setFilePointer(m_segment->GetElementPosition());
   new_segment->WriteHead(*m_file, m_segment->HeadSize() - 4);
 
@@ -487,7 +487,7 @@ kax_analyzer_c::handle_void_elements(size_t data_idx) {
       if (!e)
         return false;
 
-      counted_ptr<EbmlElement> af_e(e);
+      std::shared_ptr<EbmlElement> af_e(e);
 
       // Again the test for maximum size length.
       if (8 == e->GetSizeLength())
@@ -540,7 +540,7 @@ kax_analyzer_c::handle_void_elements(size_t data_idx) {
 
     remove_from_meta_seeks(EbmlId(*e));
     merge_void_elements();
-    add_to_meta_seek(e.get_object());
+    add_to_meta_seek(e.get());
     merge_void_elements();
 
     return false;
@@ -589,8 +589,8 @@ kax_analyzer_c::remove_from_meta_seeks(EbmlId id) {
     // Read the element from the m_file. Remember its size so that a new
     // EbmlVoid element can be constructed afterwards.
     ebml_element_cptr element = read_element(data_idx);
-    KaxSeekHead *seek_head    = dynamic_cast<KaxSeekHead *>(element.get_object());
-    if (nullptr == seek_head)
+    KaxSeekHead *seek_head    = dynamic_cast<KaxSeekHead *>(element.get());
+    if (!seek_head)
       throw uer_error_unknown;
 
     int64_t old_size = seek_head->ElementSize(true);
@@ -818,14 +818,14 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
 
     // Read the seek head, index the element and see how much space it needs.
     ebml_element_cptr element = read_element(data_idx);
-    KaxSeekHead *seek_head    = dynamic_cast<KaxSeekHead *>(element.get_object());
-    if (nullptr == seek_head)
+    KaxSeekHead *seek_head    = dynamic_cast<KaxSeekHead *>(element.get());
+    if (!seek_head)
       throw uer_error_unknown;
 
     if (-1 == first_seek_head_idx)
       first_seek_head_idx = data_idx;
 
-    seek_head->IndexThis(*e, *m_segment.get_object());
+    seek_head->IndexThis(*e, *m_segment.get());
     seek_head->UpdateSize(true);
 
     // We can use this seek head if it is at the end of the m_file, or if there
@@ -862,12 +862,12 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
   if (-1 != first_seek_head_idx) {
     // Read the first seek head...
     ebml_element_cptr element = read_element(first_seek_head_idx);
-    KaxSeekHead *seek_head    = dynamic_cast<KaxSeekHead *>(element.get_object());
-    if (nullptr == seek_head)
+    KaxSeekHead *seek_head    = dynamic_cast<KaxSeekHead *>(element.get());
+    if (!seek_head)
       throw uer_error_unknown;
 
     // ...index our element...
-    seek_head->IndexThis(*e, *m_segment.get_object());
+    seek_head->IndexThis(*e, *m_segment.get());
     seek_head->UpdateSize(true);
 
     // ...write the seek head at the end of the m_file...
@@ -881,8 +881,8 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
     adjust_segment_size();
 
     // Create a new seek head and write it to the m_file.
-    counted_ptr<KaxSeekHead> forward_seek_head(new KaxSeekHead);
-    forward_seek_head->IndexThis(*seek_head, *m_segment.get_object());
+    std::shared_ptr<KaxSeekHead> forward_seek_head(new KaxSeekHead);
+    forward_seek_head->IndexThis(*seek_head, *m_segment.get());
     forward_seek_head->UpdateSize(true);
 
     m_file->setFilePointer(m_data[first_seek_head_idx]->m_pos);
@@ -899,8 +899,8 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
   }
 
   // We don't have a seek head to copy. Create one before the first chapter if possible.
-  counted_ptr<KaxSeekHead> new_seek_head(new KaxSeekHead);
-  new_seek_head->IndexThis(*e, *m_segment.get_object());
+  std::shared_ptr<KaxSeekHead> new_seek_head(new KaxSeekHead);
+  new_seek_head->IndexThis(*e, *m_segment.get());
   new_seek_head->UpdateSize(true);
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
@@ -941,14 +941,14 @@ kax_analyzer_c::read_all(const EbmlCallbacks &callbacks) {
   size_t i;
 
   for (i = 0; m_data.size() > i; ++i) {
-    kax_analyzer_data_c &data = *m_data[i].get_object();
+    kax_analyzer_data_c &data = *m_data[i].get();
     if (EBML_INFO_ID(callbacks) != data.m_id)
       continue;
 
     m_file->setFilePointer(data.m_pos);
     int upper_lvl_el     = 0;
     EbmlElement *element = es.FindNextElement(EBML_CLASS_CONTEXT(KaxSegment), upper_lvl_el, 0xFFFFFFFFL, true);
-    if (nullptr == element)
+    if (!element)
       continue;
 
     if (EbmlId(*element) != EBML_INFO_ID(callbacks)) {
@@ -959,7 +959,7 @@ kax_analyzer_c::read_all(const EbmlCallbacks &callbacks) {
     EbmlElement *l2 = nullptr;
     element->Read(*m_stream, EBML_INFO_CONTEXT(callbacks), upper_lvl_el, l2, true);
 
-    if (!master.is_set())
+    if (!master)
       master = ebml_master_cptr(static_cast<EbmlMaster *>(element));
     else {
       EbmlMaster *src = static_cast<EbmlMaster *>(element);
@@ -971,8 +971,8 @@ kax_analyzer_c::read_all(const EbmlCallbacks &callbacks) {
     }
   }
 
-  if (master.is_set() && (master->ListSize() == 0))
-    master.clear();
+  if (master && (master->ListSize() == 0))
+    master.reset();
 
   return master;
 }
@@ -1007,7 +1007,7 @@ kax_analyzer_c::read_meta_seek(uint64_t pos,
   int upper_lvl_el = 0;
   EbmlElement *l1  = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFL, true, 1);
 
-  if (nullptr == l1)
+  if (!l1)
     return;
 
   if (!is_id(l1, KaxSeekHead)) {
@@ -1025,10 +1025,10 @@ kax_analyzer_c::read_meta_seek(uint64_t pos,
       continue;
 
     KaxSeek *seek      = static_cast<KaxSeek *>((*master)[i]);
-    KaxSeekID *seek_id = FINDFIRST(seek, KaxSeekID);
+    KaxSeekID *seek_id = FindChild<KaxSeekID>(seek);
     int64_t seek_pos   = seek->Location() + m_segment->GetElementPosition() + m_segment->HeadSize();
 
-    if ((0 == pos) || (nullptr == seek_id))
+    if ((0 == pos) || !seek_id)
       continue;
 
     if (positions_found[seek_pos])
