@@ -14,7 +14,7 @@
 #ifndef __MTX_COMMON_MATH_H
 #define __MTX_COMMON_MATH_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #define irnd(a) ((int64_t)((double)(a) + 0.5))
 #define iabs(a) ((a) < 0 ? (a) * -1 : (a))
@@ -23,4 +23,6 @@ uint32_t round_to_nearest_pow2(uint32_t value);
 
 int int_log2(uint32_t value);
 
+typedef boost::rational<int64_t> int64_rational_c;
+
 #endif  // __MTX_COMMON_MATH_H
