@@ -16,11 +16,8 @@
 
 #include "common/common_pch.h"
 
-#include <cassert>
 #include <deque>
 
-#include "common/error.h"
-
 namespace mtx {
   namespace mem {
     class exception: public mtx::exception {
@@ -47,7 +44,7 @@ namespace mtx {
 
 inline void
 safefree(void *p) {
-  if (nullptr != p)
+  if (p)
     free(p);
 }
 
@@ -81,7 +78,7 @@ _safestrdup(const char *s,
 unsigned char *_saferealloc(void *mem, size_t size, const char *file, int line);
 
 class memory_c;
-typedef counted_ptr<memory_c> memory_cptr;
+typedef std::shared_ptr<memory_c> memory_cptr;
 typedef std::vector<memory_cptr> memories_c;
 
 class memory_c {
@@ -138,11 +135,11 @@ public:
   }
 
   bool is_unique() const throw() {
-    return (its_counter ? its_counter->count == 1 : true);
+    return its_counter ? its_counter->count == 1 : true;
   }
 
   bool is_allocated() const throw() {
-    return (nullptr != its_counter) && (nullptr != its_counter->ptr);
+    return its_counter && its_counter->ptr;
   }
 
   memory_cptr clone() const {
@@ -285,7 +282,7 @@ class memory_slice_cursor_c {
   inline unsigned char get_char() {
     assert(m_pos < m_size);
 
-    memory_c &slice = *(*m_slice).get_object();
+    memory_c &slice = *m_slice->get();
     unsigned char c = *(slice.get_buffer() + m_pos_in_slice);
 
     ++m_pos_in_slice;
@@ -357,15 +354,6 @@ private:
   memory_slice_cursor_c(const memory_slice_cursor_c &) { }
 };
 
-struct buffer_t {
-  unsigned char *m_buffer;
-  size_t m_size;
-
-  buffer_t();
-  buffer_t(unsigned char *buffer, size_t m_size);
-  ~buffer_t();
-};
-
 memory_cptr lace_memory_xiph(const std::vector<memory_cptr> &blocks);
 std::vector<memory_cptr> unlace_memory_xiph(memory_cptr &buffer);
 
