@@ -634,7 +634,7 @@ mpeg4::p10::avcc_to_nalus(const unsigned char *buffer,
   } catch (...) {
   }
 
-  return memory_cptr(nullptr);
+  return memory_cptr{};
 }
 
 mpeg4::p10::avc_es_parser_c::avc_es_parser_c()
@@ -704,7 +704,7 @@ mpeg4::p10::avc_es_parser_c::add_bytes(unsigned char *buffer,
   int previous_pos             = -1;
   uint64_t previous_parsed_pos = m_parsed_position;
 
-  if (m_unparsed_buffer.is_set() && (0 != m_unparsed_buffer->get_size()))
+  if (m_unparsed_buffer && (0 != m_unparsed_buffer->get_size()))
     cursor.add_slice(m_unparsed_buffer);
   cursor.add_slice(buffer, size);
 
@@ -753,18 +753,18 @@ mpeg4::p10::avc_es_parser_c::add_bytes(unsigned char *buffer,
     cursor.copy(m_unparsed_buffer->get_buffer(), previous_pos, new_size);
 
   } else
-    m_unparsed_buffer.clear();
+    m_unparsed_buffer.reset();
 }
 
 void
 mpeg4::p10::avc_es_parser_c::flush() {
-  if (m_unparsed_buffer.is_set() && (5 <= m_unparsed_buffer->get_size())) {
+  if (m_unparsed_buffer && (5 <= m_unparsed_buffer->get_size())) {
     m_parsed_position += m_unparsed_buffer->get_size();
     int marker_size = get_uint32_be(m_unparsed_buffer->get_buffer()) == NALU_START_CODE ? 4 : 3;
     handle_nalu(memory_c::clone(m_unparsed_buffer->get_buffer() + marker_size, m_unparsed_buffer->get_size() - marker_size));
   }
 
-  m_unparsed_buffer.clear();
+  m_unparsed_buffer.reset();
   if (m_have_incomplete_frame) {
     m_frames.push_back(m_incomplete_frame);
     m_have_incomplete_frame = false;
@@ -875,7 +875,7 @@ mpeg4::p10::avc_es_parser_c::handle_slice_nalu(memory_cptr &nalu) {
     flush_incomplete_frame();
 
   if (m_have_incomplete_frame) {
-    memory_c &mem = *(m_incomplete_frame.m_data.get_object());
+    memory_c &mem = *(m_incomplete_frame.m_data.get());
     int offset    = mem.get_size();
     mem.resize(offset + m_nalu_size_length + nalu->get_size());
     write_nalu_size(mem.get_buffer() + offset, nalu->get_size());
@@ -1197,22 +1197,27 @@ mpeg4::p10::avc_es_parser_c::get_most_often_used_duration()
     if (current->second > most_often->second)
       most_often = current;
 
-  int64_t best   = m_duration_frequency.end() == most_often ? -1 : most_often->first;
-  int64_t result = best;
+  // No duration at all!? No frame?
+  if (m_duration_frequency.end() == most_often) {
+    mxdebug_if(m_debug_timecodes, boost::format("Duration frequency: none found, using 25 FPS\n"));
+    return 1000000000ll / 25;
+  }
 
-  for (auto common_default_duration : s_common_default_durations)
-    if (std::abs(result - common_default_duration) < 20000) {
-      result = common_default_duration;
-      break;
-    }
+  auto best = std::make_pair(most_often->first, std::numeric_limits<uint64_t>::max());
 
-  mxdebug_if(m_debug_timecodes, boost::format("Duration frequency. Result: %1%. Best before adjustment: %2%. All: %3%\n")
-             % result % best
+  for (auto common_default_duration : s_common_default_durations) {
+    uint64_t diff = std::abs(most_often->first - common_default_duration);
+    if ((diff < 20000) && (diff < best.second))
+      best = std::make_pair(common_default_duration, diff);
+  }
+
+  mxdebug_if(m_debug_timecodes, boost::format("Duration frequency. Result: %1%, diff %2%. Best before adjustment: %3%. All: %4%\n")
+             % best.first % best.second % most_often->first
              % boost::accumulate(m_duration_frequency, std::string(""), [](std::string const &accu, std::pair<int64_t, int64_t> const &pair) {
                  return accu + (boost::format(" <%1% %2%>") % pair.first % pair.second).str();
                }));
 
-  return result;
+  return best.first;
 }
 
 void
@@ -1291,9 +1296,9 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
   }
 
   if (!simple_picture_order)
-    br::sort(m_frames, [](const avc_frame_t &f1, const avc_frame_t &f2) { return f1.m_presentation_order < f2.m_presentation_order; });
+    brng::sort(m_frames, [](const avc_frame_t &f1, const avc_frame_t &f2) { return f1.m_presentation_order < f2.m_presentation_order; });
 
-  br::sort(m_provided_timecodes);
+  brng::sort(m_provided_timecodes);
 
   frames_begin               = m_frames.begin();
   frames_end                 = m_frames.end();
@@ -1322,14 +1327,14 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
   m_max_timecode = m_frames.back().m_end;
   m_provided_timecodes.erase(m_provided_timecodes.begin(), provided_timecode_itr);
 
-  mxdebug_if(m_debug_timecodes, boost::format("CLEANUP frames <pres_ord dec_ord has_prov_tc tc>: %1%\n")
+  mxdebug_if(m_debug_timecodes, boost::format("CLEANUP frames <pres_ord dec_ord has_prov_tc tc dur>: %1%\n")
              % boost::accumulate(m_frames, std::string(""), [](std::string const &accu, avc_frame_t const &frame) {
                  return accu + (boost::format(" <%1% %2% %3% %4% %5%>") % frame.m_presentation_order % frame.m_decode_order % frame.m_has_provided_timecode % frame.m_start % (frame.m_end - frame.m_start)).str();
                }));
 
 
   if (!simple_picture_order)
-    br::sort(m_frames, [](const avc_frame_t &f1, const avc_frame_t &f2) { return f1.m_decode_order < f2.m_decode_order; });
+    brng::sort(m_frames, [](const avc_frame_t &f1, const avc_frame_t &f2) { return f1.m_decode_order < f2.m_decode_order; });
 
   frames_begin       = m_frames.begin();
   frames_end         = m_frames.end();
