@@ -15,9 +15,7 @@
 #ifndef __MTX_COMMON_MPEG4_P2_H
 #define __MTX_COMMON_MPEG4_P2_H
 
-#include "common/os.h"
-
-#include "common/memory.h"
+#include "common/common_pch.h"
 
 /** Start code for a MPEG-4 part 2 (?) video object plain */
 #define MPEGVIDEO_VOP_START_CODE                  0x000001b6
@@ -104,11 +102,11 @@ struct video_frame_t {
   bool is_coded;
 
   video_frame_t()
-    : data(NULL)
+    : data(nullptr)
     , size(0)
     , pos(0)
     , type(FRAME_TYPE_I)
-    , priv(NULL)
+    , priv(nullptr)
     , timecode(0)
     , duration(0)
     , bref(0)
