@@ -15,10 +15,7 @@
 
 #include "common/ebml.h"
 #include "common/endian.h"
-#include "common/mm_io.h"
 #include "common/locale.h"
-#include "common/output.h"
-#include "common/smart_pointers.h"
 #include "common/strings/formatting.h"
 #include "common/strings/utf8.h"
 
@@ -40,7 +37,7 @@ std::string g_stdio_charset;
 static bool s_mm_stdio_redirected = false;
 
 charset_converter_cptr g_cc_stdio = charset_converter_cptr(new charset_converter_c);
-counted_ptr<mm_io_c> g_mm_stdio   = counted_ptr<mm_io_c>(new mm_stdio_c);
+std::shared_ptr<mm_io_c> g_mm_stdio   = std::shared_ptr<mm_io_c>(new mm_stdio_c);
 
 void
 redirect_stdio(const mm_io_cptr &stdio) {
@@ -70,7 +67,7 @@ mxmsg(unsigned int level,
   if (level == MXMSG_ERROR) {
     if (s_saw_cr_after_nl)
       g_mm_stdio->puts("\n");
-    if (!ba::starts_with(message, Y("Error:")))
+    if (!balg::starts_with(message, Y("Error:")))
       g_mm_stdio->puts(g_cc_stdio->native(Y("Error: ")));
 
   } else if (level == MXMSG_WARNING)
@@ -251,30 +248,30 @@ dump_ebml_elements(EbmlElement *element,
     indent_str += " ";
 
   if (with_values) {
-    if (nullptr != dynamic_cast<EbmlUInteger *>(element))
+    if (dynamic_cast<EbmlUInteger *>(element))
       value_str = to_string(uint64(*static_cast<EbmlUInteger *>(element)));
 
-    else if (nullptr != dynamic_cast<EbmlSInteger *>(element))
+    else if (dynamic_cast<EbmlSInteger *>(element))
       value_str = to_string(int64(*static_cast<EbmlSInteger *>(element)));
 
-    else if (nullptr != dynamic_cast<EbmlFloat *>(element))
+    else if (dynamic_cast<EbmlFloat *>(element))
       value_str = to_string(double(*static_cast<EbmlFloat *>(element)), 9);
 
-    else if (nullptr != dynamic_cast<EbmlUnicodeString *>(element))
+    else if (dynamic_cast<EbmlUnicodeString *>(element))
       value_str = UTFstring_to_cstrutf8(UTFstring(*static_cast<EbmlUnicodeString *>(element)));
 
-    else if (nullptr != dynamic_cast<EbmlString *>(element))
+    else if (dynamic_cast<EbmlString *>(element))
       value_str = std::string(*static_cast<EbmlString *>(element));
 
-    else if (nullptr != dynamic_cast<EbmlDate *>(element))
+    else if (dynamic_cast<EbmlDate *>(element))
       value_str = to_string(static_cast<EbmlDate *>(element)->GetEpochDate());
 
     else
       value_str = (boost::format("(type: %1%)") %
-                   (  nullptr != dynamic_cast<EbmlBinary *>(element) ? "binary"
-                    : nullptr != dynamic_cast<EbmlMaster *>(element) ? "master"
-                    : nullptr != dynamic_cast<EbmlVoid *>(element)   ? "void"
-                    :                                               "unknown")).str();
+                   (  dynamic_cast<EbmlBinary *>(element) ? "binary"
+                    : dynamic_cast<EbmlMaster *>(element) ? "master"
+                    : dynamic_cast<EbmlVoid *>(element)   ? "void"
+                    :                                       "unknown")).str();
 
     value_str = " " + value_str;
   }
@@ -282,7 +279,7 @@ dump_ebml_elements(EbmlElement *element,
   mxinfo(boost::format("%1%%2%%3%\n") % indent_str % EBML_NAME(element) % value_str);
 
   EbmlMaster *master = dynamic_cast<EbmlMaster *>(element);
-  if (nullptr == master)
+  if (!master)
     return;
 
   for (i = 0; master->ListSize() > i; ++i)
