@@ -65,6 +65,7 @@ translation_c::initialize_available_translations() {
   ms_available_translations.push_back(translation_c("ja_JP", "ja",    "japanese",   "Japanese",            "日本語",      true));
   ms_available_translations.push_back(translation_c("lt_LT", "lt",    "lithuanian", "Lithuanian",          "Lietuvių",    false));
   ms_available_translations.push_back(translation_c("nl_NL", "nl",    "dutch",      "Dutch",               "Nederlands",  false));
+  ms_available_translations.push_back(translation_c("pl_PL", "pl",    "polish",     "Polish",              "Polski",      false));
   ms_available_translations.push_back(translation_c("ru_RU", "ru",    "russian",    "Russian",             "Русский",     false));
   ms_available_translations.push_back(translation_c("tr_TR", "tr",    "turkish",    "Turkish",             "Türkçe",      false));
   ms_available_translations.push_back(translation_c("uk_UA", "uk",    "ukrainian",  "Ukrainian",           "Український", false));
@@ -83,9 +84,9 @@ translation_c::look_up_translation(const std::string &locale) {
     int idx                                = 0;
 
     while (i != ms_available_translations.end()) {
-      if (   ba::iequals(locale_country_lang, i->get_locale())
+      if (   balg::iequals(locale_country_lang, i->get_locale())
 #if defined(SYS_WINDOWS)
-          || ba::iequals(locale_country_lang, i->m_windows_locale_sysname)
+          || balg::iequals(locale_country_lang, i->m_windows_locale_sysname)
 #endif
            )
         return idx;
@@ -130,14 +131,14 @@ translation_c::get_default_ui_locale() {
 # else  // SYS_WINDOWS
 
   char *data = setlocale(LC_MESSAGES, nullptr);
-  if (nullptr != data) {
+  if (data) {
     std::string previous_locale = data;
     if (debugging_requested("locale"))
       mxinfo(boost::format("[get_default_ui_locale previous %1%]\n") % previous_locale);
     setlocale(LC_MESSAGES, "");
     data = setlocale(LC_MESSAGES, nullptr);
 
-    if (nullptr != data)
+    if (data)
       locale = data;
 
     if (debugging_requested("locale"))
@@ -265,15 +266,15 @@ init_locales(std::string locale) {
     locale_string_c loc_default(default_locale);
     std::string loc_req_with_default_codeset(locale_string_c(locale).set_codeset_and_modifier(loc_default).str());
 
-    if (setlocale(LC_MESSAGES, loc_req_with_default_codeset.c_str()) != nullptr)
+    if (setlocale(LC_MESSAGES, loc_req_with_default_codeset.c_str()))
       chosen_locale = loc_req_with_default_codeset;
 
-    else if (setlocale(LC_MESSAGES, locale.c_str()) != nullptr)
+    else if (setlocale(LC_MESSAGES, locale.c_str()))
       chosen_locale = locale;
 
     else {
       std::string loc_req_with_utf8 = locale_string_c(locale).set_codeset_and_modifier(locale_string_c("dummy.UTF-8")).str();
-      if (setlocale(LC_MESSAGES, loc_req_with_utf8.c_str()) != nullptr)
+      if (setlocale(LC_MESSAGES, loc_req_with_utf8.c_str()))
         chosen_locale = loc_req_with_utf8;
     }
 
@@ -288,7 +289,7 @@ init_locales(std::string locale) {
   // Hard fallback to "C" locale if no suitable locale was
   // selected. This can happen if the system has no locales for
   // "en_US" or "en_US.UTF-8" compiled.
-  if (chosen_locale.empty() && (setlocale(LC_MESSAGES, "C") != nullptr))
+  if (chosen_locale.empty() && setlocale(LC_MESSAGES, "C"))
     chosen_locale = "C";
 
   if (chosen_locale.empty())
