@@ -14,10 +14,9 @@
 #include "common/common_pch.h"
 
 #if defined(HAVE_CURL_EASY_H)
-# include <boost/property_tree/ptree.hpp>
-# include <boost/property_tree/xml_parser.hpp>
 # include <sstream>
 
+# include "common/compression.h"
 # include "common/curl.h"
 #endif  // defined(HAVE_CURL_EASY_H)
 
@@ -26,7 +25,7 @@
 #include "common/strings/parsing.h"
 #include "common/version.h"
 
-#define VERSIONNAME "Piper"
+#define VERSIONNAME "Kenya Kane"
 
 version_number_t::version_number_t()
   : valid(false)
@@ -63,14 +62,14 @@ version_number_t::version_number_t(const std::string &s)
                                           ")?",
                                           boost::regex::perl | boost::regex::mod_x);
 
-  boost::match_results<std::string::const_iterator> matches;
+  boost::smatch matches;
   if (!boost::regex_search(s, matches, s_version_number_re))
     return;
 
   size_t idx;
   for (idx = 1; 5 >= idx; ++idx)
     if (!matches[idx].str().empty())
-      parse_uint(matches[idx].str(), parts[idx - 1]);
+      parse_number(matches[idx].str(), parts[idx - 1]);
 
   valid = true;
 
@@ -156,45 +155,92 @@ get_current_version() {
 }
 
 #if defined(HAVE_CURL_EASY_H)
-mtx_release_version_t
-get_latest_release_version() {
-  if (debugging_requested("version_check"))
-    mxinfo(boost::format("Update check started with URL %1%\n") % MTX_VERSION_CHECK_URL);
+static mtx::xml::document_cptr
+retrieve_and_parse_xml(std::string const &url) {
+  bool debug = debugging_requested("version_check|releases_info|curl");
 
-  mtx_release_version_t release;
   std::string data;
-  CURLcode result = retrieve_via_curl(MTX_VERSION_CHECK_URL, data);
+  auto result = url_retriever_c().set_timeout(10, 20).retrieve(url, data);
 
   if (0 != result) {
-    if (debugging_requested("version_check"))
-      mxinfo(boost::format("Update check CURL error: %1%\n") % static_cast<unsigned int>(result));
-    return release;
+    mxdebug_if(debug, boost::format("CURL error for %2%: %1%\n") % static_cast<unsigned int>(result) % url);
+    return mtx::xml::document_cptr();
   }
 
-  if (debugging_requested("version_check"))
-    mxinfo(boost::format("Update check OK; data length %1%\n") % data.length());
-
   try {
-    std::stringstream data_in(data);
-    boost::property_tree::ptree pt;
-    boost::property_tree::read_xml(data_in, pt);
+    data = compressor_c::create_from_file_name(url)->decompress(data);
 
-    release.latest_source              = version_number_t(pt.get("mkvtoolnix-releases.latest-source.version",      std::string("")));
-    release.latest_windows_build       = version_number_t(pt.get("mkvtoolnix-releases.latest-windows-pre.version", std::string(""))
-                                                          + " build " +
-                                                          pt.get("mkvtoolnix-releases.latest-windows-pre.build",   std::string("")));
-    release.source_download_url        =                  pt.get("mkvtoolnix-releases.latest-source.url",          std::string(""));
-    release.windows_build_download_url =                  pt.get("mkvtoolnix-releases.latest-windows-pre.url",     std::string(""));
-    release.valid                      = release.latest_source.valid;
+    mtx::xml::document_cptr doc(new pugi::xml_document);
+    std::stringstream sdata(data);
+    auto xml_result = doc->load(sdata);
 
-  } catch (boost::property_tree::ptree_error &error) {
-    release.valid = false;
+    if (xml_result) {
+      mxdebug_if(debug, boost::format("Doc loaded fine from %1%\n") % url);
+      return doc;
+
+    } else
+      mxdebug_if(debug, boost::format("Doc load error for %1%: %1% at %2%\n") % url % xml_result.description() % xml_result.offset);
+
+  } catch (mtx::compression_x &ex) {
+    mxdebug_if(debug, boost::format("Decompression exception for %2%: %1%\n") % ex.what() % url);
   }
 
-  if (debugging_requested("version_check"))
-    mxinfo(boost::format("update check: current %1% latest source %2% latest winpre %3%\n")
-           % release.current_version.to_string() % release.latest_source.to_string() % release.latest_windows_build.to_string());
+  return mtx::xml::document_cptr();
+}
+
+mtx_release_version_t
+get_latest_release_version() {
+  bool debug      = debugging_requested("version_check|curl");
+  std::string url = MTX_VERSION_CHECK_URL;
+  debugging_requested("version_check_url", &url);
+
+  mxdebug_if(debug, boost::format("Update check started with URL %1%\n") % url);
+
+  mtx_release_version_t release;
+
+  auto doc = retrieve_and_parse_xml(url + ".gz");
+#if defined(HAVE_BZLIB_H)
+  if (!doc)
+    doc = retrieve_and_parse_xml(url + ".bz2");
+#endif  // HAVE_BZLIB_H
+  if (!doc)
+    doc = retrieve_and_parse_xml(url);
+  if (!doc)
+    return release;
+
+  release.latest_source                   = version_number_t(doc->select_single_node("/mkvtoolnix-releases/latest-source/version").node().child_value());
+  release.latest_windows_build            = version_number_t((boost::format("%1% build %2%")
+                                                             % doc->select_single_node("/mkvtoolnix-releases/latest-windows-pre/version").node().child_value()
+                                                             % doc->select_single_node("/mkvtoolnix-releases/latest-windows-pre/build").node().child_value()).str());
+  release.valid                           = release.latest_source.valid;
+  release.urls["general"]                 = doc->select_single_node("/mkvtoolnix-releases/latest-source/url").node().child_value();
+  release.urls["source_code"]             = doc->select_single_node("/mkvtoolnix-releases/latest-source/source-code-url").node().child_value();
+  release.urls["windows_pre_build"]       = doc->select_single_node("/mkvtoolnix-releases/latest-windows-pre/url").node().child_value();
+  for (auto arch : std::vector<std::string>{ "x86", "amd64" })
+    for (auto package : std::vector<std::string>{ "installer", "portable" })
+      release.urls[std::string{"windows_"} + arch + "_" + package] = doc->select_single_node((std::string{"/mkvtoolnix-releases/latest-windows-binary/"} + package + "-url/" + arch).c_str()).node().child_value();
+
+  if (debug) {
+    std::stringstream urls;
+    brng::for_each(release.urls, [&](std::pair<std::string, std::string> const &kv) { urls << " " << kv.first << ":" << kv.second; });
+    mxdebug(boost::format("update check: current %1% latest source %2% latest winpre %3% URLs%4%\n")
+            % release.current_version.to_string() % release.latest_source.to_string() % release.latest_windows_build.to_string() % urls);
+  }
 
   return release;
 }
+
+mtx::xml::document_cptr
+get_releases_info() {
+  std::string url = MTX_RELEASES_INFO_URL;
+  debugging_requested("releases_info_url", &url);
+
+#if defined(HAVE_BZLIB_H)
+  auto doc = retrieve_and_parse_xml(url + ".bz2");
+  if (doc)
+    return doc;
+#endif  // HAVE_BZLIB_H
+
+  return retrieve_and_parse_xml(url + ".gz");
+}
 #endif  // defined(HAVE_CURL_EASY_H)
