@@ -92,7 +92,7 @@ handle_attachments(KaxAttachments *atts,
   size_t i;
   for (i = 0; atts->ListSize() > i; ++i) {
     KaxAttached *att = dynamic_cast<KaxAttached *>((*atts)[i]);
-    assert(nullptr != att);
+    assert(att);
 
     attachment_t attachment = attachment_t::parse_new(*att);
     if (!attachment.valid)
@@ -143,7 +143,7 @@ extract_attachments(const std::string &file_name,
   }
 
   ebml_master_cptr attachments_m(analyzer->read_all(EBML_INFO(KaxAttachments)));
-  KaxAttachments *attachments = dynamic_cast<KaxAttachments *>(attachments_m.get_object());
+  KaxAttachments *attachments = dynamic_cast<KaxAttachments *>(attachments_m.get());
   if (attachments)
     handle_attachments(attachments, tracks);
 }
