@@ -72,7 +72,7 @@ get_global_tag(const char *name,
                int64_t tuid,
                KaxTags &tags) {
   KaxTag *tag = find_tag_for_track(-1, tuid, 0, tags);
-  if (nullptr == tag)
+  if (!tag)
     return "";
 
   return get_simple_tag_value(name, *tag);
@@ -153,7 +153,7 @@ write_cuesheet(std::string file_name,
   print_if_global("DISCID",         "REM DISCID %1%\n");
 
   KaxTag *tag = find_tag_for_track(-1, tuid, 0, tags);
-  if (nullptr != tag)
+  if (tag)
     print_comments("", *tag, out);
 
   out.puts(boost::format("FILE \"%1%\" WAVE\n") % file_name);
@@ -164,7 +164,7 @@ write_cuesheet(std::string file_name,
 
     out.puts(boost::format("  TRACK %|1$02d| AUDIO\n") % (i + 1));
     tag = find_tag_for_track(i + 1, tuid, get_chapter_uid(atom), tags);
-    if (nullptr == tag)
+    if (!tag)
       continue;
 
     print_if_available("TITLE",               "    TITLE \"%1%\"\n");
@@ -211,25 +211,24 @@ extract_cuesheet(const std::string &file_name,
   KaxChapters all_chapters;
   ebml_master_cptr chapters_m(analyzer->read_all(EBML_INFO(KaxChapters)));
   ebml_master_cptr tags_m(    analyzer->read_all(EBML_INFO(KaxTags)));
-  KaxChapters *chapters = dynamic_cast<KaxChapters *>(chapters_m.get_object());
-  KaxTags *all_tags     = dynamic_cast<KaxTags *>(    tags_m.get_object());
+  KaxChapters *chapters = dynamic_cast<KaxChapters *>(chapters_m.get());
+  KaxTags *all_tags     = dynamic_cast<KaxTags *>(    tags_m.get());
 
-  if ((nullptr != chapters) && (nullptr != all_tags)) {
-    size_t i;
-    for (i = 0; i < chapters->ListSize(); i++) {
-      if (dynamic_cast<KaxEditionEntry *>((*chapters)[i]) == nullptr)
-        continue;
+  if (!chapters || !all_tags)
+    return;
 
-      KaxEditionEntry *eentry = dynamic_cast<KaxEditionEntry *>((*chapters)[i]);
-      size_t k;
-      for (k = 0; k < eentry->ListSize(); k++)
-        if (dynamic_cast<KaxChapterAtom *>((*eentry)[k]) != nullptr)
-          all_chapters.PushElement(*(*eentry)[k]);
-    }
+  for (auto chapter_entry : *chapters) {
+    if (!dynamic_cast<KaxEditionEntry *>(chapter_entry))
+      continue;
 
-    write_cuesheet(file_name, all_chapters, *all_tags, -1, *g_mm_stdio);
-
-    while (all_chapters.ListSize() > 0)
-      all_chapters.Remove(0);
+    auto eentry = static_cast<KaxEditionEntry *>(chapter_entry);
+    for (auto edition_entry : *eentry)
+      if (dynamic_cast<KaxChapterAtom *>(edition_entry))
+        all_chapters.PushElement(*edition_entry);
   }
+
+  write_cuesheet(file_name, all_chapters, *all_tags, -1, *g_mm_stdio);
+
+  while (all_chapters.ListSize() > 0)
+    all_chapters.Remove(0);
 }
