@@ -150,7 +150,7 @@ extract_cli_parser_c::set_cuesheet() {
 void
 extract_cli_parser_c::set_blockadd() {
   assert_mode(options_c::em_tracks);
-  if (!parse_int(m_next_arg, m_extract_blockadd_level) || (-1 > m_extract_blockadd_level))
+  if (!parse_number(m_next_arg, m_extract_blockadd_level) || (-1 > m_extract_blockadd_level))
     mxerror(boost::format(Y("Invalid BlockAddition level in argument '%1%'.\n")) % m_next_arg);
 }
 
@@ -202,7 +202,7 @@ extract_cli_parser_c::set_extraction_mode() {
   };
 
   int i;
-  for (i = 0; nullptr != s_mode_map[i].name; ++i)
+  for (i = 0; s_mode_map[i].name; ++i)
     if (m_current_arg == s_mode_map[i].name) {
       m_options.m_extraction_mode = s_mode_map[i].extraction_mode;
       return;
@@ -220,7 +220,7 @@ extract_cli_parser_c::add_extraction_spec() {
 
   boost::regex s_track_id_re("^(\\d+)(:(.+))?$", boost::regex::perl);
 
-  boost::match_results<std::string::const_iterator> matches;
+  boost::smatch matches;
   if (!boost::regex_search(m_current_arg, matches, s_track_id_re)) {
     if (options_c::em_attachments == m_options.m_extraction_mode)
       mxerror(boost::format(Y("Invalid attachment ID/file name specification in argument '%1%'.\n")) % m_current_arg);
@@ -230,7 +230,7 @@ extract_cli_parser_c::add_extraction_spec() {
 
   track_spec_t track;
 
-  parse_int(matches[1].str(), track.tid);
+  parse_number(matches[1].str(), track.tid);
 
   std::string output_file_name;
   if (matches[3].matched)
