@@ -21,10 +21,8 @@
 #include "common/matroska.h"
 #include "common/mm_io.h"
 #include "common/strings/parsing.h"
-#include "common/tags/writer.h"
 #include "common/translation.h"
 #include "common/version.h"
-#include "common/xml/element_mapping.h"
 #include "extract/extract_cli_parser.h"
 #include "extract/mkvextract.h"
 
@@ -57,7 +55,7 @@ show_element(EbmlElement *l,
   level_buffer[level] = 0;
 
   mxinfo(boost::format("(%1%) %2%+ %3%") % NAME % level_buffer % info);
-  if (nullptr != l)
+  if (l)
     mxinfo(boost::format(Y(" at %1%")) % l->GetElementPosition());
   mxinfo("\n");
 }
@@ -69,7 +67,7 @@ show_error(const std::string &error) {
 
 static void
 setup() {
-  mtx_common_init();
+  mtx_common_init("mkvextract");
 
   set_process_priority(-1);
 
