@@ -11,10 +11,7 @@
 #ifndef __EXTRACT_OPTIONS_H
 #define __EXTRACT_OPTIONS_H
 
-#include "common/os.h"
-
-#include <string>
-#include <vector>
+#include "common/common_pch.h"
 
 class options_c {
 public:
