@@ -33,8 +33,8 @@ xtr_avi_c::create_file(xtr_base_c *master,
                        KaxTrackEntry &track) {
   init_content_decoder(track);
 
-  KaxCodecPrivate *priv = FINDFIRST(&track, KaxCodecPrivate);
-  if (nullptr == priv)
+  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+  if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
   m_default_duration = kt_get_default_duration(track);
@@ -43,18 +43,18 @@ xtr_avi_c::create_file(xtr_base_c *master,
 
   m_fps = (double)1000000000.0 / (double)m_default_duration;
 
-  if (nullptr != master)
+  if (master)
     mxerror(boost::format(Y("Cannot write track %1% with the CodecID '%2%' to the file '%3%' because "
                             "track %4% with the CodecID '%5%' is already being written to the same file.\n"))
             % m_tid % m_codec_id % m_file_name % master->m_tid % master->m_codec_id);
 
   try {
     m_out = mm_file_io_c::open(m_file_name.c_str(), MODE_CREATE);
-    m_avi = AVI_open_output_file(m_out.get_object());
+    m_avi = AVI_open_output_file(m_out.get());
   } catch (mtx::mm_io::exception &) {
   }
 
-  if (nullptr == m_avi)
+  if (!m_avi)
     mxerror(boost::format(Y("The file '%1%' could not be opened for writing (%2%).\n")) % m_file_name % AVI_strerror());
 
   std::string writing_app = "mkvextract";
