@@ -30,8 +30,8 @@ xtr_mpeg1_2_video_c::create_file(xtr_base_c *master,
 
   xtr_base_c::create_file(master, track);
 
-  KaxCodecPrivate *priv = FINDFIRST(&track, KaxCodecPrivate);
-  if (nullptr != priv)
+  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+  if (priv)
     m_seq_hdr = decode_codec_private(priv);
 }
 
@@ -52,7 +52,7 @@ xtr_mpeg1_2_video_c::handle_frame(memory_cptr &frame,
   if (references_valid)
     keyframe = (0 == bref);
 
-  if (keyframe && m_seq_hdr.is_set()) {
+  if (keyframe && m_seq_hdr) {
     bool seq_hdr_found = false;
     size_t size        = frame->get_size();
 
