@@ -13,21 +13,21 @@
 #ifndef __XTR_TTA_H
 #define __XTR_TTA_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "xtr_base.h"
+#include "extract/xtr_base.h"
 
 class xtr_tta_c: public xtr_base_c {
 public:
-  vector<int64_t> m_frame_sizes;
+  std::vector<int64_t> m_frame_sizes;
   int64_t m_previous_duration;
   int m_bps, m_channels, m_sfreq;
-  string m_temp_file_name;
+  std::string m_temp_file_name;
 
   static const double ms_tta_frame_time;
 
 public:
-  xtr_tta_c(const string &codec_id, int64_t tid, track_spec_t &tspec);
+  xtr_tta_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
