@@ -76,7 +76,6 @@ xtr_wavpack4_c::xtr_wavpack4_c(const std::string &codec_id,
   : xtr_base_c(codec_id, tid, tspec)
   , m_number_of_samples(0)
   , m_extract_blockadd_level(tspec.extract_blockadd_level)
-  , m_corr_out(nullptr)
 {
 }
 
@@ -87,11 +86,11 @@ xtr_wavpack4_c::create_file(xtr_base_c *master,
 
   init_content_decoder(track);
 
-  KaxCodecPrivate *priv = FINDFIRST(&track, KaxCodecPrivate);
+  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
   if (priv)
     mpriv = decode_codec_private(priv);
 
-  if ((nullptr == priv) || (2 > mpriv->get_size()))
+  if (!priv || (2 > mpriv->get_size()))
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
   memcpy(m_version, mpriv->get_buffer(), 2);
 
@@ -181,14 +180,14 @@ xtr_wavpack4_c::handle_frame(memory_cptr &frame,
   }
 
   // support hybrid mode data
-  if (m_corr_out.is_set() && (nullptr != additions)) {
-    KaxBlockMore *block_more = FINDFIRST(additions, KaxBlockMore);
+  if (m_corr_out && (additions)) {
+    KaxBlockMore *block_more = FindChild<KaxBlockMore>(additions);
 
-    if (nullptr == block_more)
+    if (!block_more)
       return;
 
-    KaxBlockAdditional *block_addition = FINDFIRST(block_more, KaxBlockAdditional);
-    if (nullptr == block_addition)
+    KaxBlockAdditional *block_addition = FindChild<KaxBlockAdditional>(block_more);
+    if (!block_addition)
       return;
 
     data_size = block_addition->GetSize();
@@ -224,7 +223,7 @@ xtr_wavpack4_c::finish_file() {
   m_out->setFilePointer(12);
   m_out->write_uint32_le(m_number_of_samples);
 
-  if (m_corr_out.is_set()) {
+  if (m_corr_out) {
     m_corr_out->setFilePointer(12);
     m_corr_out->write_uint32_le(m_number_of_samples);
   }
