@@ -79,7 +79,8 @@
 #include "common/strings/formatting.h"
 #include "common/translation.h"
 #include "common/version.h"
-#include "common/xml/element_mapping.h"
+#include "common/xml/ebml_chapters_converter.h"
+#include "common/xml/ebml_tags_converter.h"
 #include "info/mkvinfo.h"
 #include "info/info_cli_parser.h"
 
@@ -110,7 +111,7 @@ kax_track_t::kax_track_t()
   , mkvmerge_track_id(0)
 {
 }
-typedef counted_ptr<kax_track_t> kax_track_cptr;
+typedef std::shared_ptr<kax_track_t> kax_track_cptr;
 
 track_info_t::track_info_t()
   : m_size(0)
@@ -243,7 +244,7 @@ add_track(kax_track_cptr t) {
 
 kax_track_t *
 find_track(int tnum) {
-  return s_tracks_by_number[tnum].get_object();
+  return s_tracks_by_number[tnum].get();
 }
 
 #define UTF2STR(s)                 UTFstring_to_cstrutf8(UTFstring(s))
@@ -280,18 +281,18 @@ _show_element(EbmlElement *l,
     return;
 
   ui_show_element(level, info,
-                    nullptr == l          ? -1
+                    !l                 ? -1
                   :                      static_cast<int64_t>(l->GetElementPosition()),
-                    nullptr == l          ? -1
+                    !l                 ? -1
                   : !l->IsFiniteSize() ? -2
                   :                      static_cast<int64_t>(l->GetSizeLength() + EBML_ID_LENGTH(static_cast<const EbmlId &>(*l)) + l->GetSize()));
 
-  if ((nullptr == l) || !skip)
+  if (!l || !skip)
     return;
 
   // Dump unknown elements recursively.
   EbmlMaster *m = dynamic_cast<EbmlMaster *>(l);
-  if (nullptr != m) {
+  if (m) {
     size_t i;
     for (i = 0; i < m->ListSize(); i++)
       show_unknown_element((*m)[i], level + 1);
@@ -511,8 +512,8 @@ handle_info(EbmlStream *&es,
   EbmlElement *element_found = nullptr;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  KaxTimecodeScale *tc_scale = FINDFIRST(m1, KaxTimecodeScale);
-  if (nullptr != tc_scale)
+  KaxTimecodeScale *tc_scale = FindChild<KaxTimecodeScale>(m1);
+  if (tc_scale)
     s_tc_scale = uint64(*tc_scale);
 
   size_t i1;
@@ -545,8 +546,7 @@ handle_info(EbmlStream *&es,
       char buffer[40];
       KaxDateUTC &dateutc = *static_cast<KaxDateUTC *>(l2);
       temptime = dateutc.GetEpochDate();
-      if ((gmtime_r(&temptime, &tmutc) != nullptr) &&
-          (asctime_r(&tmutc, buffer) != nullptr)) {
+      if (gmtime_r(&temptime, &tmutc) && asctime_r(&tmutc, buffer)) {
         buffer[strlen(buffer) - 1] = 0;
         show_element(l2, 2, boost::format(Y("Date: %1% UTC")) % buffer);
       } else
@@ -635,7 +635,7 @@ handle_audio_track(EbmlStream *&es,
     } else if (!is_global(es, l4, 4))
       show_unknown_element(l4, 4);
 
-  } // while (l4 != nullptr)
+  } // while (l4)
 }
 
 void
@@ -737,7 +737,7 @@ handle_video_track(EbmlStream *&es,
     } else if (!is_global(es, l4, 4))
       show_unknown_element(l4, 4);
 
-  } // while (l4 != nullptr)
+  } // while (l4)
 }
 
 void
@@ -932,7 +932,7 @@ handle_tracks(EbmlStream *&es,
 
           auto existing_track = find_track(track->tnum);
           size_t track_id     = s_mkvmerge_track_id;
-          if (nullptr == existing_track) {
+          if (!existing_track) {
             track->mkvmerge_track_id = s_mkvmerge_track_id;
             ++s_mkvmerge_track_id;
             add_track(track);
@@ -1158,12 +1158,12 @@ handle_seek_head(EbmlStream *&es,
         } else if (!is_global(es, l3, 3))
           show_unknown_element(l3, 3);
 
-      } // while (l3 != nullptr)
+      } // while (l3)
 
     } else if (!is_global(es, l2, 2))
       show_unknown_element(l2, 2);
 
-  } // while (l2 != nullptr)
+  } // while (l2)
 
   l2 = element_found;
 }
@@ -1256,23 +1256,23 @@ handle_cues(EbmlStream *&es,
                 } else if (!is_global(es, l5, 5))
                   show_unknown_element(l5, 5);
 
-              } // while (l5 != nullptr)
+              } // while (l5)
 #endif // MATROSKA_VERSION >= 2
 
             } else if (!is_global(es, l4, 4))
               show_unknown_element(l4, 4);
 
-          } // while (l4 != nullptr)
+          } // while (l4)
 
         } else if (!is_global(es, l3, 3))
           show_unknown_element(l3, 3);
 
-      } // while (l3 != nullptr)
+      } // while (l3)
 
     } else if (!is_global(es, l2, 2))
       show_unknown_element(l2, 2);
 
-  } // while (l2 != nullptr)
+  } // while (l2)
 
   l2 = element_found;
 }
@@ -1325,12 +1325,12 @@ handle_attachments(EbmlStream *&es,
         } else if (!is_global(es, l3, 3))
           show_unknown_element(l3, 3);
 
-      } // while (l3 != nullptr)
+      } // while (l3)
 
     } else if (!is_global(es, l2, 2))
       show_unknown_element(l2, 2);
 
-  } // while (l2 != nullptr)
+  } // while (l2)
 
   l2 = element_found;
 }
@@ -1482,12 +1482,12 @@ handle_block_group(EbmlStream *&es,
             } else if (!is_global(es, l5, 5))
               show_unknown_element(l5, 5);
 
-          } // while (l5 != nullptr)
+          } // while (l5)
 
         } else if (!is_global(es, l4, 4))
           show_unknown_element(l4, 4);
 
-      } // while (l4 != nullptr)
+      } // while (l4)
 
     } else if (is_id(l3, KaxSlices)) {
       show_element(l3, 3, Y("Slices"));
@@ -1528,17 +1528,17 @@ handle_block_group(EbmlStream *&es,
             } else if (!is_global(es, l5, 5))
               show_unknown_element(l5, 5);
 
-          } // while (l5 != nullptr)
+          } // while (l5)
 
         } else if (!is_global(es, l4, 4))
           show_unknown_element(l4, 4);
 
-      } // while (l4 != nullptr)
+      } // while (l4)
 
     } else if (!is_global(es, l3, 3))
       show_unknown_element(l3, 3);
 
-  } // while (l3 != nullptr)
+  } // while (l3)
 
   if (g_options.m_show_summary) {
     std::string position;
@@ -1710,8 +1710,8 @@ handle_cluster(EbmlStream *&es,
   EbmlElement *element_found = nullptr;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  KaxClusterTimecode *cluster_tc = FINDFIRST(m1, KaxClusterTimecode);
-  cluster->InitTimecode(nullptr == cluster_tc ? 0 : uint64(*cluster_tc), s_tc_scale);
+  KaxClusterTimecode *cluster_tc = FindChild<KaxClusterTimecode>(m1);
+  cluster->InitTimecode(!cluster_tc ? 0 : uint64(*cluster_tc), s_tc_scale);
 
   size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1741,7 +1741,7 @@ handle_cluster(EbmlStream *&es,
     else if (!is_global(es, l2, 2))
       show_unknown_element(l2, 2);
 
-  } // while (l2 != nullptr)
+  } // while (l2)
 
   l2 = element_found;
 }
@@ -1750,60 +1750,38 @@ void
 handle_elements_rec(EbmlStream *es,
                     int level,
                     EbmlElement *e,
-                    const parser_element_t *mapping) {
+                    mtx::xml::ebml_converter_c const &converter) {
   static boost::format s_bf_handle_elements_rec("%1%: %2%");
+  static std::vector<std::string> const s_output_as_timecode{ "ChapterTimeStart", "ChapterTimeEnd" };
 
-  bool found = false;
-  int elt_idx;
-  for (elt_idx = 0; nullptr != mapping[elt_idx].name; ++elt_idx)
-    if (EbmlId(*e) == mapping[elt_idx].id) {
-      found = true;
-      break;
-    }
+  std::string elt_name = converter.get_tag_name(*e);
 
-  if (!found) {
-    show_unknown_element(e, level);
-    return;
-  }
+  if (dynamic_cast<EbmlMaster *>(e)) {
+    show_element(e, level, elt_name);
+    auto m = static_cast<EbmlMaster *>(e);
+    for (auto child : *m)
+      handle_elements_rec(es, level + 1, child, converter);
 
-  std::string elt_name = mapping[elt_idx].name;
-  EbmlMaster *m;
+  } else if (dynamic_cast<EbmlUInteger *>(e)) {
+    if (brng::find(s_output_as_timecode, elt_name) != s_output_as_timecode.end())
+      show_element(e, level, s_bf_handle_elements_rec % elt_name % format_timecode(uint64(*static_cast<EbmlUInteger *>(e))));
+    else
+      show_element(e, level, s_bf_handle_elements_rec % elt_name % uint64(*static_cast<EbmlUInteger *>(e)));
 
-  switch (mapping[elt_idx].type) {
-    case EBMLT_MASTER:
-      show_element(e, level, elt_name);
-      m = dynamic_cast<EbmlMaster *>(e);
-      assert(m != nullptr);
+  } else if (dynamic_cast<EbmlSInteger *>(e))
+    show_element(e, level, s_bf_handle_elements_rec % elt_name % int64(*static_cast<EbmlSInteger *>(e)));
 
-      size_t i;
-      for (i = 0; m->ListSize() > i; ++i)
-        handle_elements_rec(es, level + 1, (*m)[i], mapping);
-      break;
+  else if (dynamic_cast<EbmlString *>(e))
+    show_element(e, level, s_bf_handle_elements_rec % elt_name % std::string(*static_cast<EbmlString *>(e)));
 
-    case EBMLT_UINT:
-    case EBMLT_BOOL:
-      show_element(e, level, s_bf_handle_elements_rec % elt_name % uint64(*dynamic_cast<EbmlUInteger *>(e)));
-      break;
+  else if (dynamic_cast<EbmlUnicodeString *>(e))
+    show_element(e, level, s_bf_handle_elements_rec % elt_name % UTF2STR(UTFstring(*static_cast<EbmlUnicodeString *>(e)).c_str()));
 
-    case EBMLT_STRING:
-      show_element(e, level, s_bf_handle_elements_rec % elt_name % std::string(*dynamic_cast<EbmlString *>(e)));
-      break;
+  else if (dynamic_cast<EbmlBinary *>(e))
+    show_element(e, level, s_bf_handle_elements_rec % elt_name % format_binary(*static_cast<EbmlBinary *>(e)));
 
-    case EBMLT_USTRING:
-      show_element(e, level, s_bf_handle_elements_rec % elt_name % UTF2STR(UTFstring(*static_cast<EbmlUnicodeString *>(e)).c_str()));
-      break;
-
-    case EBMLT_TIME:
-      show_element(e, level, s_bf_handle_elements_rec % elt_name % format_timecode(uint64(*dynamic_cast<EbmlUInteger *>(e))));
-      break;
-
-    case EBMLT_BINARY:
-      show_element(e, level, s_bf_handle_elements_rec % elt_name % format_binary(*static_cast<EbmlBinary *>(e)));
-      break;
-
-    default:
-      assert(false);
-  }
+  else
+    assert(false);
 }
 
 void
@@ -1818,9 +1796,10 @@ handle_chapters(EbmlStream *&es,
   EbmlElement *element_found = nullptr;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
+  mtx::xml::ebml_chapters_converter_c converter;
   size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
-    handle_elements_rec(es, 2, (*m1)[i1], chapter_elements);
+    handle_elements_rec(es, 2, (*m1)[i1], converter);
 
   l2 = element_found;
 }
@@ -1837,9 +1816,10 @@ handle_tags(EbmlStream *&es,
   EbmlElement *element_found = nullptr;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
+  mtx::xml::ebml_tags_converter_c converter;
   size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
-    handle_elements_rec(es, 2, (*m1)[i1], tag_elements);
+    handle_elements_rec(es, 2, (*m1)[i1], converter);
 
   l2 = element_found;
 }
@@ -1854,7 +1834,7 @@ handle_ebml_head(EbmlElement *l0,
     int upper_lvl_el = 0;
     EbmlElement *e   = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
 
-    if (nullptr == e)
+    if (!e)
       return;
 
     e->ReadData(*in);
@@ -1945,7 +1925,7 @@ process_file(const std::string &file_name) {
 
     // Find the EbmlHead element. Must be the first one.
     l0 = es->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
-    if (nullptr == l0) {
+    if (!l0) {
       show_error(Y("No EBML head found."));
       delete es;
 
@@ -1959,7 +1939,7 @@ process_file(const std::string &file_name) {
     while (1) {
       // NEXT element must be a segment
       l0 = es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
-      if (nullptr == l0) {
+      if (!l0) {
         show_error(Y("No segment/level 0 element found."));
         return false;
       }
@@ -1980,8 +1960,8 @@ process_file(const std::string &file_name) {
 
     kax_file_cptr kax_file = kax_file_cptr(new kax_file_c(in));
 
-    while (nullptr != (l1 = kax_file->read_next_level1_element())) {
-      counted_ptr<EbmlElement> af_l1(l1);
+    while ((l1 = kax_file->read_next_level1_element())) {
+      std::shared_ptr<EbmlElement> af_l1(l1);
 
       if (is_id(l1, KaxInfo))
         handle_info(es, upper_lvl_el, l1, l2, l3);
@@ -2023,7 +2003,7 @@ process_file(const std::string &file_name) {
         break;
       if (!in_parent(l0))
         break;
-    } // while (l1 != nullptr)
+    } // while (l1)
 
     delete l0;
     delete es;
@@ -2040,7 +2020,7 @@ process_file(const std::string &file_name) {
 
 void
 setup(const std::string &locale) {
-  mtx_common_init();
+  mtx_common_init("mkvinfo");
 
   init_locales(locale);
 
