@@ -73,7 +73,7 @@ avi_reader_c::probe_file(mm_io_c *in,
     return false;
   }
 
-  ba::to_lower(data);
+  balg::to_lower(data);
   return (data.substr(0, 4) == "riff") && (data.substr(8, 4) == "avi ");
 }
 
@@ -98,7 +98,7 @@ avi_reader_c::avi_reader_c(const track_info_c &ti,
 void
 avi_reader_c::read_headers() {
   try {
-    if (!avi_reader_c::probe_file(m_in.get_object(), m_size))
+    if (!avi_reader_c::probe_file(m_in.get(), m_size))
       throw mtx::input::invalid_format_x();
 
   } catch (mtx::mm_io::exception &) {
@@ -107,7 +107,7 @@ avi_reader_c::read_headers() {
 
   show_demuxer_info();
 
-  if (nullptr == (m_avi = AVI_open_input_file(m_in.get_object(), 1)))
+  if (!(m_avi = AVI_open_input_file(m_in.get(), 1)))
     throw mtx::input::invalid_format_x();
 
   m_fps              = AVI_frame_rate(m_avi);
@@ -121,7 +121,7 @@ avi_reader_c::read_headers() {
 }
 
 avi_reader_c::~avi_reader_c() {
-  if (nullptr != m_avi)
+  if (m_avi)
     AVI_close(m_avi);
 
   m_ti.m_private_data = nullptr;
@@ -224,7 +224,7 @@ avi_reader_c::create_video_packetizer() {
   }
 
   m_ti.m_private_data = reinterpret_cast<unsigned char *>(m_avi->bitmap_info_header);
-  if (nullptr != m_ti.m_private_data)
+  if (m_ti.m_private_data)
     m_ti.m_private_size = get_uint32_le(&m_avi->bitmap_info_header->bi_size);
 
   mxverb(4, boost::format("track extra data size: %1%\n") % (m_ti.m_private_size - sizeof(alBITMAPINFOHEADER)));
@@ -266,7 +266,7 @@ avi_reader_c::create_video_packetizer() {
 
 void
 avi_reader_c::create_mpeg1_2_packetizer() {
-  counted_ptr<M2VParser> m2v_parser(new M2VParser);
+  std::shared_ptr<M2VParser> m2v_parser(new M2VParser);
 
   m2v_parser->SetProbeMode();
   if ((0 != m_ti.m_private_size) && (m_ti.m_private_size < sizeof(alBITMAPINFOHEADER)))
@@ -301,14 +301,14 @@ avi_reader_c::create_mpeg1_2_packetizer() {
     mxerror_tid(m_ti.m_fname, 0, Y("Could not extract the sequence header from this MPEG-1/2 track.\n"));
 
   MPEG2SequenceHeader seq_hdr = m2v_parser->GetSequenceHeader();
-  counted_ptr<MPEGFrame> frame(m2v_parser->ReadFrame());
-  if (!frame.is_set())
+  std::shared_ptr<MPEGFrame> frame(m2v_parser->ReadFrame());
+  if (!frame)
     mxerror_tid(m_ti.m_fname, 0, Y("Could not extract the sequence header from this MPEG-1/2 track.\n"));
 
   int display_width      = ((0 >= seq_hdr.aspectRatio) || (1 == seq_hdr.aspectRatio)) ? seq_hdr.width : static_cast<int>(seq_hdr.height * seq_hdr.aspectRatio);
 
   MPEGChunk *raw_seq_hdr = m2v_parser->GetRealSequenceHeader();
-  if (nullptr != raw_seq_hdr) {
+  if (raw_seq_hdr) {
     m_ti.m_private_data  = raw_seq_hdr->GetPointer();
     m_ti.m_private_size  = raw_seq_hdr->GetSize();
   } else {
@@ -343,7 +343,7 @@ avi_reader_c::create_mpeg4_p10_packetizer() {
     uint32_t extra_data_size = get_uint32_le(&m_avi->bitmap_info_header->bi_size) - sizeof(alBITMAPINFOHEADER);
     if (0 < extra_data_size) {
       memory_cptr avc_extra_nalus = mpeg4::p10::avcc_to_nalus(reinterpret_cast<unsigned char *>(m_avi->bitmap_info_header + 1), extra_data_size);
-      if (avc_extra_nalus.is_set())
+      if (avc_extra_nalus)
         ptzr->add_extra_data(avc_extra_nalus);
     }
 
@@ -410,7 +410,7 @@ avi_reader_c::create_srt_packetizer(int idx) {
   avi_subs_demuxer_t &demuxer = m_subtitle_demuxers[idx];
   int id                      = idx + 1 + AVI_audio_tracks(m_avi);
 
-  srt_parser_c *parser        = new srt_parser_c(demuxer.m_text_io.get_object(), m_ti.m_fname, id);
+  srt_parser_c *parser        = new srt_parser_c(demuxer.m_text_io.get(), m_ti.m_fname, id);
   demuxer.m_subs              = subtitles_cptr(parser);
 
   parser->parse();
@@ -426,7 +426,7 @@ avi_reader_c::create_ssa_packetizer(int idx) {
   avi_subs_demuxer_t &demuxer    = m_subtitle_demuxers[idx];
   int id                         = idx + 1 + AVI_audio_tracks(m_avi);
 
-  ssa_parser_c *parser           = new ssa_parser_c(this, demuxer.m_text_io.get_object(), m_ti.m_fname, id);
+  ssa_parser_c *parser           = new ssa_parser_c(this, demuxer.m_text_io.get(), m_ti.m_fname, id);
   demuxer.m_subs                 = subtitles_cptr(parser);
 
   charset_converter_cptr cc_utf8 = map_has_key(m_ti.m_sub_charsets, id)           ? charset_converter_c::init(m_ti.m_sub_charsets[id])
