@@ -16,16 +16,8 @@
 
 #include "common/common_pch.h"
 
-#include <stdio.h>
-
-#include "common/error.h"
-#include "common/mm_io.h"
-#include "merge/pr_generic.h"
-
-class hdsub_reader_c: public generic_reader_c {
+class hdsub_reader_c {
 public:
-  hdsub_reader_c(track_info_c &n_ti): generic_reader_c(n_ti) { };
-
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
