@@ -76,8 +76,11 @@ mpeg_ps_reader_c::read_headers() {
   try {
     uint8_t byte;
 
-    m_in.clear();               // Close the source file first before opening it a second time.
-    m_in            = mm_multi_file_io_c::open_multi(m_ti.m_fname, m_ti.m_disable_multi_file);
+    if (!m_ti.m_disable_multi_file) {
+      m_in.reset();               // Close the source file first before opening it a second time.
+      m_in = mm_multi_file_io_c::open_multi(m_ti.m_fname, false);
+    }
+
     m_size          = m_in->get_size();
     uint32_t header = m_in->read_uint32_be();
     bool done       = m_in->eof();
@@ -166,7 +169,9 @@ mpeg_ps_reader_c::read_headers() {
 
   if (verbose) {
     show_demuxer_info();
-    static_cast<mm_multi_file_io_c &>(*m_in).display_other_file_info();
+    auto multi_in = get_underlying_input_as_multi_file_io();
+    if (multi_in)
+      multi_in->display_other_file_info();
   }
 }
 
@@ -559,7 +564,7 @@ mpeg_ps_reader_c::new_stream_v_mpeg_1_2(mpeg_ps_id_t id,
                                         unsigned char *buf,
                                         unsigned int length,
                                         mpeg_ps_track_ptr &track) {
-  counted_ptr<M2VParser> m2v_parser(new M2VParser);
+  std::shared_ptr<M2VParser> m2v_parser(new M2VParser);
 
   m2v_parser->SetProbeMode();
   m2v_parser->WriteData(buf, length);
@@ -590,8 +595,8 @@ mpeg_ps_reader_c::new_stream_v_mpeg_1_2(mpeg_ps_id_t id,
   }
 
   MPEG2SequenceHeader seq_hdr = m2v_parser->GetSequenceHeader();
-  counted_ptr<MPEGFrame> frame(m2v_parser->ReadFrame());
-  if (!frame.is_set())
+  std::shared_ptr<MPEGFrame> frame(m2v_parser->ReadFrame());
+  if (!frame)
     throw false;
 
   track->fourcc         = FOURCC('M', 'P', 'G', '0' + m2v_parser->GetMPEGVersion());
@@ -609,7 +614,7 @@ mpeg_ps_reader_c::new_stream_v_mpeg_1_2(mpeg_ps_id_t id,
   track->v_dheight  = track->v_height;
 
   MPEGChunk *raw_seq_hdr = m2v_parser->GetRealSequenceHeader();
-  if (nullptr != raw_seq_hdr) {
+  if (raw_seq_hdr) {
     track->raw_seq_hdr      = (unsigned char *)safememdup(raw_seq_hdr->GetPointer(), raw_seq_hdr->GetSize());
     track->raw_seq_hdr_size = raw_seq_hdr->GetSize();
   }
@@ -1198,7 +1203,7 @@ mpeg_ps_reader_c::read(generic_packetizer_c *requested_ptzr,
         continue;
       }
 
-      mpeg_ps_track_t *track = tracks[id2idx[new_id.idx()]].get_object();
+      mpeg_ps_track_t *track = tracks[id2idx[new_id.idx()]].get();
 
       mxverb(3,
              boost::format("mpeg_ps: packet for 0x%|1$02x|(%|2$02x|) length %3% at %4% timecode %5%\n")
@@ -1278,7 +1283,9 @@ void
 mpeg_ps_reader_c::identify() {
   std::vector<std::string> verbose_info;
 
-  static_cast<mm_multi_file_io_c &>(*m_in).create_verbose_identification_info(verbose_info);
+  auto multi_in = get_underlying_input_as_multi_file_io();
+  if (multi_in)
+    multi_in->create_verbose_identification_info(verbose_info);
 
   id_result_container(verbose_info);
 
@@ -1313,4 +1320,3 @@ mpeg_ps_reader_c::identify() {
                     verbose_info);
   }
 }
-
