@@ -259,9 +259,9 @@ public:
 
 // ---------------------------------------------------------------------------------
 
-static counted_ptr<std::vector<std::string> >
+static std::shared_ptr<std::vector<std::string> >
 extract_vorbis_comments(const memory_cptr &mem) {
-  counted_ptr<std::vector<std::string> > comments(new std::vector<std::string>);
+  std::shared_ptr<std::vector<std::string> > comments(new std::vector<std::string>);
   mm_mem_io_c in(mem->get_buffer(), mem->get_size());
   uint32_t i, n, len;
 
@@ -323,7 +323,7 @@ ogm_reader_c::ogm_reader_c(const track_info_c &ti,
 
 void
 ogm_reader_c::read_headers() {
-  if (!ogm_reader_c::probe_file(m_in.get_object(), m_size))
+  if (!ogm_reader_c::probe_file(m_in.get(), m_size))
     throw mtx::input::invalid_format_x();
 
   ogg_sync_init(&oy);
@@ -347,10 +347,10 @@ ogm_reader_c::find_demuxer(int serialno) {
     if (sdemuxers[i]->serialno == serialno) {
       if (sdemuxers[i]->in_use)
         return sdemuxers[i];
-      return ogm_demuxer_cptr(nullptr);
+      return ogm_demuxer_cptr{};
     }
 
-  return ogm_demuxer_cptr(nullptr);
+  return ogm_demuxer_cptr{};
 }
 
 /*
@@ -409,7 +409,7 @@ ogm_reader_c::create_packetizer(int64_t tid) {
 
   ptzr                = dmx->create_packetizer();
 
-  if (nullptr != ptzr)
+  if (ptzr)
     dmx->ptzr         = add_packetizer(ptzr);
 
   m_ti.m_language.clear();
@@ -446,7 +446,7 @@ ogm_reader_c::handle_new_stream_and_packets(ogg_page *og) {
 
   handle_new_stream(og);
   dmx = find_demuxer(ogg_page_serialno(og));
-  if (dmx.is_set())
+  if (dmx)
     process_header_packets(dmx);
 }
 
@@ -581,7 +581,7 @@ ogm_reader_c::process_page(ogg_page *og) {
   int64_t granulepos;
 
   dmx = find_demuxer(ogg_page_serialno(og));
-  if (!dmx.is_set() || !dmx->in_use)
+  if (!dmx || !dmx->in_use)
     return;
 
   granulepos = ogg_page_granulepos(og);
@@ -604,7 +604,7 @@ ogm_reader_c::process_header_page(ogg_page *og) {
   ogm_demuxer_cptr dmx;
 
   dmx = find_demuxer(ogg_page_serialno(og));
-  if (!dmx.is_set() ||dmx->headers_read)
+  if (!dmx ||dmx->headers_read)
     return;
 
   ogg_stream_pagein(&dmx->os, og);
@@ -726,13 +726,13 @@ ogm_reader_c::identify() {
     id_result_track(i, sdemuxers[i]->get_type(), sdemuxers[i]->get_codec(), verbose_info);
   }
 
-  if (nullptr != m_chapters)
+  if (m_chapters.get())
     id_result_chapters(count_chapter_atoms(*m_chapters));
 }
 
 void
 ogm_reader_c::handle_stream_comments() {
-  counted_ptr<std::vector<std::string> > comments;
+  std::shared_ptr<std::vector<std::string> > comments;
   std::string title;
 
   bool charset_warning_printed = false;
@@ -792,7 +792,7 @@ ogm_reader_c::handle_stream_comments() {
       } else if (comment[0] == "TITLE")
         title = comment[1];
 
-      else if (ba::starts_with(comment[0], "CHAPTER"))
+      else if (balg::starts_with(comment[0], "CHAPTER"))
         chapter_strings.push_back((*comments)[j]);
     }
 
@@ -811,19 +811,19 @@ ogm_reader_c::handle_stream_comments() {
     bool chapters_set = false;
     if (!chapter_strings.empty() && !m_ti.m_no_chapters) {
       try {
-        counted_ptr<mm_mem_io_c> out(new mm_mem_io_c(nullptr, 0, 1000));
+        std::shared_ptr<mm_mem_io_c> out(new mm_mem_io_c(nullptr, 0, 1000));
 
         out->write_bom("UTF-8");
         for (j = 0; j < chapter_strings.size(); j++)
           out->puts(cch->utf8(chapter_strings[j]) + std::string("\n"));
         out->set_file_name(m_ti.m_fname);
 
-        counted_ptr<mm_text_io_c> text_out(new mm_text_io_c(out.get_object(), false));
+        std::shared_ptr<mm_text_io_c> text_out(new mm_text_io_c(out.get(), false));
 
-        m_chapters   = parse_chapters(text_out.get_object(), 0, -1, 0, m_ti.m_chapter_language);
+        m_chapters   = parse_chapters(text_out.get(), 0, -1, 0, m_ti.m_chapter_language);
         chapters_set = true;
 
-        align_chapter_edition_uids(m_chapters);
+        align_chapter_edition_uids(m_chapters.get());
       } catch (...) {
       }
     }
