@@ -25,15 +25,23 @@ private:
   ssa_parser_cptr m_subs;
 
 public:
-  ssa_reader_c(track_info_c &_ti) throw (error_c);
+  ssa_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~ssa_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("SSA/ASS subtitles") : "SSA/ASS subtitles";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
   virtual int get_progress();
+  virtual bool is_simple_subtitle_container() {
+    return true;
+  }
 
-  static int probe_file(mm_text_io_c *io, uint64_t size);
+  static int probe_file(mm_text_io_c *in, uint64_t size);
 };
 
 #endif  // __R_SSA_H
