@@ -32,7 +32,7 @@
                      : tolower(c) == 'd' ? 13        \
                      : tolower(c) == 'e' ? 14        \
                      :                     15)
-#define ishexdigit(s) (isdigit(s) || (strchr("abcdefABCDEF", s) != nullptr))
+#define ishexdigit(s) (isdigit(s) || strchr("abcdefABCDEF", s))
 
 const std::string vobsub_reader_c::id_string("# VobSub index file, v");
 
@@ -69,7 +69,7 @@ vobsub_reader_c::vobsub_reader_c(const track_info_c &ti,
 void
 vobsub_reader_c::read_headers() {
   try {
-    m_idx_file = mm_text_io_cptr(new mm_text_io_c(m_in.get_object(), false));
+    m_idx_file = mm_text_io_cptr(new mm_text_io_c(m_in.get(), false));
   } catch (...) {
     throw mtx::input::open_x();
   }
@@ -90,7 +90,7 @@ vobsub_reader_c::read_headers() {
   len      = id_string.length();
 
   std::string line;
-  if (!m_idx_file->getline2(line) || !ba::istarts_with(line, id_string) || (line.length() < (len + 1)))
+  if (!m_idx_file->getline2(line) || !balg::istarts_with(line, id_string) || (line.length() < (len + 1)))
     mxerror_fn(m_ti.m_fname, Y("No version number found.\n"));
 
   version = line[len] - '0';
@@ -193,7 +193,7 @@ vobsub_reader_c::parse_headers() {
       } else
         language = "";
 
-      if (nullptr != track) {
+      if (track) {
         if (track->entries.empty())
           delete track;
         else {
@@ -214,7 +214,7 @@ vobsub_reader_c::parse_headers() {
     if (!strncasecmp(sline, "alt:", 4) || !strncasecmp(sline, "langidx:", 8))
       continue;
 
-    if (ba::istarts_with(line, "delay:")) {
+    if (balg::istarts_with(line, "delay:")) {
       line.erase(0, 6);
       strip(line);
 
@@ -230,15 +230,15 @@ vobsub_reader_c::parse_headers() {
       delay += timestamp * factor;
     }
 
-    if ((7 == version) && ba::istarts_with(line, "timestamp:")) {
-      if (nullptr == track)
+    if ((7 == version) && balg::istarts_with(line, "timestamp:")) {
+      if (!track)
         mxerror_fn(m_ti.m_fname, Y("The .idx file does not contain an 'id: ...' line to indicate the language.\n"));
 
       strip(line);
       shrink_whitespace(line);
       std::vector<std::string> parts = split(line.c_str(), " ");
 
-      if ((4 != parts.size()) || (13 > parts[1].length()) || !ba::iequals(parts[2], "filepos:")) {
+      if ((4 != parts.size()) || (13 > parts[1].length()) || !balg::iequals(parts[2], "filepos:")) {
         mxwarn_fn(m_ti.m_fname, boost::format(Y("Line %1%: The line seems to be a subtitle entry but the format couldn't be recognized. This entry will be skipped.\n")) % line_no);
         continue;
       }
@@ -305,7 +305,7 @@ vobsub_reader_c::parse_headers() {
     idx_data += "\n";
   }
 
-  if (nullptr != track) {
+  if (track) {
     if (track->entries.size() == 0)
       delete track;
     else {
@@ -336,7 +336,7 @@ vobsub_reader_c::deliver_packet(unsigned char *buf,
                                 int64_t timecode,
                                 int64_t default_duration,
                                 generic_packetizer_c *ptzr) {
-  if ((nullptr == buf) || (0 == size)) {
+  if (!buf || (0 == size)) {
     safefree(buf);
     return -1;
   }
