@@ -38,7 +38,7 @@ subtitles_c::process(generic_packetizer_c *p) {
 // ------------------------------------------------------------
 
 #define SRT_RE_VALUE         "\\s*(-?)\\s*(\\d+)"
-#define SRT_RE_TIMECODE      SRT_RE_VALUE ":" SRT_RE_VALUE ":" SRT_RE_VALUE "[,\\.]" SRT_RE_VALUE
+#define SRT_RE_TIMECODE      SRT_RE_VALUE ":" SRT_RE_VALUE ":" SRT_RE_VALUE "[,\\.:]" SRT_RE_VALUE
 #define SRT_RE_TIMECODE_LINE "^" SRT_RE_TIMECODE "\\s*-+>\\s*" SRT_RE_TIMECODE "\\s*"
 #define SRT_RE_COORDINATES   "([XY]\\d+:\\d+\\s*){4}\\s*$"
 
@@ -53,12 +53,12 @@ srt_parser_c::probe(mm_text_io_c *io) {
     } while (s.empty());
 
     int64_t dummy;
-    if (!parse_int(s, dummy))
+    if (!parse_number(s, dummy))
       return false;
 
     s = io->getline();
     boost::regex timecode_re(SRT_RE_TIMECODE_LINE, boost::regex::perl);
-    boost::match_results<std::string::const_iterator> matches;
+    boost::smatch matches;
     if (!boost::regex_search(s, timecode_re))
       return false;
 
@@ -126,26 +126,26 @@ srt_parser_c::parse() {
         break;
       }
       state = STATE_TIME;
-      parse_uint(s, subtitle_number);
+      parse_number(s, subtitle_number);
 
     } else if (STATE_TIME == state) {
-      boost::match_results<std::string::const_iterator> matches;
+      boost::smatch matches;
       if (!boost::regex_search(s, matches, timecode_re)) {
         mxwarn_tid(m_file_name, m_tid, boost::format(Y("Error in line %1%: expected a SRT timecode line but found something else. Aborting this file.\n")) % line_number);
         break;
       }
 
-      int s_h, s_min, s_sec, e_h, e_min, e_sec;
+      int s_h = 0, s_min = 0, s_sec = 0, e_h = 0, e_min = 0, e_sec = 0;
 
       //        1         2       3      4        5     6             7    8
       // "\\s*(-?)\\s*(\\d+):\\s(-?)*(\\d+):\\s*(-?)(\\d+)[,\\.]\\s*(-?)(\\d+)?"
 
-      parse_int(matches[ 2].str(), s_h);
-      parse_int(matches[ 4].str(), s_min);
-      parse_int(matches[ 6].str(), s_sec);
-      parse_int(matches[10].str(), e_h);
-      parse_int(matches[12].str(), e_min);
-      parse_int(matches[14].str(), e_sec);
+      parse_number(matches[ 2].str(), s_h);
+      parse_number(matches[ 4].str(), s_min);
+      parse_number(matches[ 6].str(), s_sec);
+      parse_number(matches[10].str(), e_h);
+      parse_number(matches[12].str(), e_min);
+      parse_number(matches[14].str(), e_sec);
 
       std::string s_rest = matches[ 8].str();
       std::string e_rest = matches[16].str();
@@ -224,7 +224,7 @@ srt_parser_c::parse() {
 
     } else if (boost::regex_match(s, number_re)) {
       state = STATE_TIME;
-      parse_uint(s, subtitle_number);
+      parse_number(s, subtitle_number);
 
     } else {
       if (!subtitles.empty())
@@ -245,8 +245,8 @@ srt_parser_c::parse() {
 
 bool
 ssa_parser_c::probe(mm_text_io_c *io) {
-  boost::regex script_info_re("^\\s*\\[script\\s+info\\]",   boost::regex::perl | boost::regbase::icase);
-  boost::regex styles_re(     "^\\s*\\[V4\\+?\\s+Styles\\]", boost::regex::perl | boost::regbase::icase);
+  boost::regex script_info_re("^\\s*\\[script\\s+info\\]",   boost::regex::perl | boost::regex::icase);
+  boost::regex styles_re(     "^\\s*\\[V4\\+?\\s+Styles\\]", boost::regex::perl | boost::regex::icase);
 
   try {
     int line_number = 0;
@@ -286,12 +286,12 @@ ssa_parser_c::ssa_parser_c(generic_reader_c *reader,
 
 void
 ssa_parser_c::parse() {
-  boost::regex sec_styles_ass_re("^\\s*\\[V4\\+\\s+Styles\\]", boost::regex::perl | boost::regbase::icase);
-  boost::regex sec_styles_re(    "^\\s*\\[V4\\s+Styles\\]",    boost::regex::perl | boost::regbase::icase);
-  boost::regex sec_info_re(      "^\\s*\\[Script\\s+Info\\]",  boost::regex::perl | boost::regbase::icase);
-  boost::regex sec_events_re(    "^\\s*\\[Events\\]",          boost::regex::perl | boost::regbase::icase);
-  boost::regex sec_graphics_re(  "^\\s*\\[Graphics\\]",        boost::regex::perl | boost::regbase::icase);
-  boost::regex sec_fonts_re(     "^\\s*\\[Fonts\\]",           boost::regex::perl | boost::regbase::icase);
+  boost::regex sec_styles_ass_re("^\\s*\\[V4\\+\\s+Styles\\]", boost::regex::perl | boost::regex::icase);
+  boost::regex sec_styles_re(    "^\\s*\\[V4\\s+Styles\\]",    boost::regex::perl | boost::regex::icase);
+  boost::regex sec_info_re(      "^\\s*\\[Script\\s+Info\\]",  boost::regex::perl | boost::regex::icase);
+  boost::regex sec_events_re(    "^\\s*\\[Events\\]",          boost::regex::perl | boost::regex::icase);
+  boost::regex sec_graphics_re(  "^\\s*\\[Graphics\\]",        boost::regex::perl | boost::regex::icase);
+  boost::regex sec_fonts_re(     "^\\s*\\[Fonts\\]",           boost::regex::perl | boost::regex::icase);
 
   int num                        = 0;
   ssa_section_e section          = SSA_SECTION_NONE;
@@ -335,7 +335,7 @@ ssa_parser_c::parse() {
       add_to_global = false;
 
     } else if (SSA_SECTION_EVENTS == section) {
-      if (ba::istarts_with(line, "Format: ")) {
+      if (balg::istarts_with(line, "Format: ")) {
         // Analyze the format string.
         m_format = split(&line.c_str()[strlen("Format: ")]);
         strip(m_format);
@@ -343,12 +343,12 @@ ssa_parser_c::parse() {
         // Let's see if "Actor" is used in the format instead of "Name".
         size_t i;
         for (i = 0; m_format.size() > i; ++i)
-          if (ba::iequals(m_format[i], "actor")) {
+          if (balg::iequals(m_format[i], "actor")) {
             name_field = "Actor";
             break;
           }
 
-      } else if (ba::istarts_with(line, "Dialogue: ")) {
+      } else if (balg::istarts_with(line, "Dialogue: ")) {
         if (m_format.empty())
           throw mtx::input::extended_x(Y("ssa_reader: Invalid format. Could not find the \"Format\" line in the \"[Events]\" section."));
 
@@ -405,7 +405,7 @@ ssa_parser_c::parse() {
       }
 
     } else if ((SSA_SECTION_FONTS == section) || (SSA_SECTION_GRAPHICS == section)) {
-      if (ba::istarts_with(line, "fontname:")) {
+      if (balg::istarts_with(line, "fontname:")) {
         add_attachment_maybe(attachment_name, attachment_data_uu, section);
 
         line.erase(0, strlen("fontname:"));
@@ -455,7 +455,7 @@ ssa_parser_c::parse_time(std::string &stime) {
     return -1;
 
   std::string s = stime.substr(0, pos);
-  if (!parse_int(s, th))
+  if (!parse_number(s, th))
     return -1;
   stime.erase(0, pos + 1);
 
@@ -464,7 +464,7 @@ ssa_parser_c::parse_time(std::string &stime) {
     return -1;
 
   s = stime.substr(0, pos);
-  if (!parse_int(s, tm))
+  if (!parse_number(s, tm))
     return -1;
   stime.erase(0, pos + 1);
 
@@ -473,11 +473,11 @@ ssa_parser_c::parse_time(std::string &stime) {
     return -1;
 
   s = stime.substr(0, pos);
-  if (!parse_int(s, ts))
+  if (!parse_number(s, ts))
     return -1;
   stime.erase(0, pos + 1);
 
-  if (!parse_int(stime, tds))
+  if (!parse_number(stime, tds))
     return -1;
 
   return (tds * 10 + ts * 1000 + tm * 60 * 1000 + th * 60 * 60 * 1000) * 1000000;
