@@ -22,7 +22,6 @@
 #endif
 #include <stdlib.h>
 #include <stdio.h>
-#include <string.h>
 #include <time.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -35,6 +34,7 @@
 #include <iostream>
 #include <list>
 #include <sstream>
+#include <tuple>
 #include <typeinfo>
 
 #include <matroska/KaxChapters.h>
@@ -54,11 +54,11 @@
 #include "common/segmentinfo.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
-#include "common/tags/tags.h"
-#include "common/tags/parser.h"
 #include "common/unique_numbers.h"
 #include "common/version.h"
 #include "common/webm.h"
+#include "common/xml/ebml_segmentinfo_converter.h"
+#include "common/xml/ebml_tags_converter.h"
 #include "merge/cluster_helper.h"
 #include "merge/mkvmerge.h"
 #include "merge/output_control.h"
@@ -117,6 +117,10 @@ set_usage() {
   usage_text += Y("  --split timecodes:A[,B...]\n"
                   "                           Create a new file after each timecode A, B\n"
                   "                           etc.\n");
+  usage_text += Y("  --split parts:start1-end1[,[+]start2-end2,...]\n"
+                  "                           Keep ranges of timecodes start-end, either in\n"
+                  "                           separate files or append to previous range's file\n"
+                  "                           if prefixed with '+'.\n");
   usage_text += Y("  --split-max-files <n>    Create at most n files.\n");
   usage_text += Y("  --link                   Link splitted files.\n");
   usage_text += Y("  --link-to-previous <SID> Link the first file to the given SID.\n");
@@ -316,8 +320,7 @@ create_track_number(generic_reader_c *reader,
   if (found) {
     found = false;
     for (i = 0; i < g_packetizers.size(); i++)
-      if ((g_packetizers[i].packetizer != nullptr) &&
-          (g_packetizers[i].packetizer->get_track_num() == tnum)) {
+      if (g_packetizers[i].packetizer && (g_packetizers[i].packetizer->get_track_num() == tnum)) {
         tnum = s_track_number;
         break;
       }
@@ -345,23 +348,35 @@ guess_mime_type_and_report(std::string file_name) {
 static void
 handle_segmentinfo() {
   // segment families
-  KaxSegmentFamily *family = FINDFIRST(g_kax_info_chap, KaxSegmentFamily);
-  while (nullptr != family) {
+  KaxSegmentFamily *family = FindChild<KaxSegmentFamily>(g_kax_info_chap.get());
+  while (family) {
     g_segfamily_uids.add_family_uid(*family);
-    family = FINDNEXT(g_kax_info_chap, KaxSegmentFamily, family);
+    family = FindNextChild<KaxSegmentFamily>(g_kax_info_chap.get(), family);
   }
 
-  EbmlBinary *uid = FINDFIRST(g_kax_info_chap, KaxSegmentUID);
-  if (nullptr != uid)
+  EbmlBinary *uid = FindChild<KaxSegmentUID>(g_kax_info_chap.get());
+  if (uid)
     g_forced_seguids.push_back(bitvalue_cptr(new bitvalue_c(*uid)));
 
-  uid = FINDFIRST(g_kax_info_chap, KaxNextUID);
-  if (nullptr != uid)
+  uid = FindChild<KaxNextUID>(g_kax_info_chap.get());
+  if (uid)
     g_seguid_link_next = bitvalue_cptr(new bitvalue_c(*uid));
 
-  uid = FINDFIRST(g_kax_info_chap, KaxPrevUID);
-  if (nullptr != uid)
+  uid = FindChild<KaxPrevUID>(g_kax_info_chap.get());
+  if (uid)
     g_seguid_link_previous = bitvalue_cptr(new bitvalue_c(*uid));
+
+  auto segment_filename = FindChild<KaxSegmentFilename>(g_kax_info_chap.get());
+  if (segment_filename)
+    g_segment_filename = UTFstring_to_cstrutf8(*segment_filename);
+
+  auto next_segment_filename = FindChild<KaxNextFilename>(g_kax_info_chap.get());
+  if (next_segment_filename)
+    g_next_segment_filename = UTFstring_to_cstrutf8(*next_segment_filename);
+
+  auto previous_segment_filename = FindChild<KaxPrevFilename>(g_kax_info_chap.get());
+  if (previous_segment_filename)
+    g_previous_segment_filename = UTFstring_to_cstrutf8(*previous_segment_filename);
 }
 
 static void
@@ -430,27 +445,27 @@ parse_number_with_unit(const std::string &s,
                        const std::string &subject,
                        const std::string &argument,
                        std::string display_s = "") {
-  boost::regex re1("(-?\\d+\\.?\\d*)(s|ms|us|ns|fps|p|i)?",  boost::regex::perl | boost::regbase::icase);
-  boost::regex re2("(-?\\d+)/(-?\\d+)(s|ms|us|ns|fps|p|i)?", boost::regex::perl | boost::regbase::icase);
+  boost::regex re1("(-?\\d+\\.?\\d*)(s|ms|us|ns|fps|p|i)?",  boost::regex::perl | boost::regex::icase);
+  boost::regex re2("(-?\\d+)/(-?\\d+)(s|ms|us|ns|fps|p|i)?", boost::regex::perl | boost::regex::icase);
 
   std::string unit, s_n, s_d;
-  int64_t n, d;
+  int64_t n = 0, d = 0;
   double d_value = 0.0;
   bool is_fraction = false;
 
   if (display_s.empty())
     display_s = s;
 
-  boost::match_results<std::string::const_iterator> matches;
-  if (boost::regex_match(s, matches, re1, boost::match_default)) {
-    parse_double(matches[1], d_value);
+  boost::smatch matches;
+  if (boost::regex_match(s, matches, re1)) {
+    parse_number(matches[1], d_value);
     if (matches.size() > 2)
       unit = matches[2];
     d = 1;
 
-  } else if (boost::regex_match(s, matches, re2, boost::match_default)) {
-    parse_int(matches[1], n);
-    parse_int(matches[2], d);
+  } else if (boost::regex_match(s, matches, re2)) {
+    parse_number(matches[1], n);
+    parse_number(matches[2], d);
     if (matches.size() > 3)
       unit = matches[3];
     is_fraction = true;
@@ -459,7 +474,7 @@ parse_number_with_unit(const std::string &s,
     mxerror(boost::format(Y("'%1%' is not a valid %2% in '%3% %4%'.\n")) % s % subject % argument % display_s);
 
   int64_t multiplier = 1000000000;
-  ba::to_lower(unit);
+  balg::to_lower(unit);
 
   if (unit == "ms")
     multiplier = 1000000;
@@ -496,23 +511,18 @@ parse_number_with_unit(const std::string &s,
 */
 void
 parse_and_add_tags(const std::string &file_name) {
-  KaxTags *tags = new KaxTags;
+  auto tags = mtx::xml::ebml_tags_converter_c::parse_file(file_name);
 
-  parse_xml_tags(file_name, tags);
-
-  while (tags->ListSize() > 0) {
-    KaxTag *tag = dynamic_cast<KaxTag *>((*tags)[0]);
-    if (nullptr != tag) {
-      fix_mandatory_tag_elements(tag);
+  for (auto element : *tags) {
+    auto tag = dynamic_cast<KaxTag *>(element);
+    if (tag) {
       if (!tag->CheckMandatory())
         mxerror(boost::format(Y("Error parsing the tags in '%1%': some mandatory elements are missing.\n")) % file_name);
       add_tags(tag);
     }
-
-    tags->Remove(0);
   }
 
-  delete tags;
+  tags->RemoveAll();
 }
 
 /** \brief Parse the \c --xtracks arguments
@@ -525,7 +535,7 @@ parse_arg_tracks(std::string s,
                  const std::string &opt) {
   tracks.clear();
 
-  if (ba::starts_with(s, "!")) {
+  if (balg::starts_with(s, "!")) {
     s.erase(0, 1);
     tracks.set_reversed();
   }
@@ -536,7 +546,7 @@ parse_arg_tracks(std::string s,
   size_t i;
   for (i = 0; i < elements.size(); i++) {
     int64_t tid;
-    if (!parse_int(elements[i], tid))
+    if (!parse_number(elements[i], tid))
       mxerror(boost::format(Y("Invalid track ID in '%1% %2%'.\n")) % opt % s);
     tracks.add(tid);
   }
@@ -563,7 +573,7 @@ parse_arg_sync(std::string s,
     mxerror(boost::format(Y("Invalid sync option. No track ID specified in '%1% %2%'.\n")) % opt % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '%1% %2%'.\n")) % opt % s);
 
   s = parts[1];
@@ -624,7 +634,7 @@ parse_arg_aspect_ratio(const std::string &s,
     mxerror(boost::format(Y("%1%: missing track ID in '%2% %3%'.\n")) % msg % opt % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("%1%: invalid track ID in '%2% %3%'.\n")) % msg % opt % s);
 
   dprop.width  = -1;
@@ -673,7 +683,7 @@ parse_arg_display_dimensions(const std::string s,
   std::vector<std::string> dims = split(parts[1], "x", 2);
   int64_t id = 0;
   int w, h;
-  if ((dims.size() != 2) || !parse_int(parts[0], id) || !parse_int(dims[0], w) || !parse_int(dims[1], h) || (0 >= w) || (0 >= h))
+  if ((dims.size() != 2) || !parse_number(parts[0], id) || !parse_number(dims[0], w) || !parse_number(dims[1], h) || (0 >= w) || (0 >= h))
     mxerror(boost::format(Y("Display dimensions: not given in the form <TID>:<width>x<height>, e.g. 1:640x480 (argument was '%1%').\n")) % s);
 
   dprop.aspect_ratio          = -1.0;
@@ -700,14 +710,14 @@ parse_arg_cropping(const std::string &s,
     mxerror(boost::format(err_msg) % s);
 
   int64_t id = 0;
-  if (!parse_int(v[0], id))
+  if (!parse_number(v[0], id))
     mxerror(boost::format(err_msg) % s);
 
   v = split(v[1], ",");
   if (v.size() != 4)
     mxerror(boost::format(err_msg) % s);
 
-  if (!parse_int(v[0], crop.left) || !parse_int(v[1], crop.top) || !parse_int(v[2], crop.right) || !parse_int(v[3], crop.bottom))
+  if (!parse_number(v[0], crop.left) || !parse_number(v[1], crop.top) || !parse_number(v[2], crop.right) || !parse_number(v[3], crop.bottom))
     mxerror(boost::format(err_msg) % s);
 
   ti.m_pixel_crop_list[id] = crop;
@@ -742,7 +752,7 @@ parse_arg_stereo_mode(const std::string &s,
     mxerror(boost::format(errmsg) % stereo_mode_c::max_index() % stereo_mode_c::displayable_modes_list() % s);
 
   int64_t id = 0;
-  if (!parse_int(v[0], id))
+  if (!parse_number(v[0], id))
     mxerror(boost::format(errmsg) % stereo_mode_c::max_index() % stereo_mode_c::displayable_modes_list() % s);
 
   stereo_mode_c::mode mode = stereo_mode_c::parse_mode(v[1]);
@@ -752,7 +762,7 @@ parse_arg_stereo_mode(const std::string &s,
   }
 
   int index;
-  if (!parse_int(v[1], index) || !stereo_mode_c::valid_index(index))
+  if (!parse_number(v[1], index) || !stereo_mode_c::valid_index(index))
     mxerror(boost::format(errmsg) % stereo_mode_c::max_index() % stereo_mode_c::displayable_modes_list() % s);
 
   ti.m_stereo_mode_list[id] = static_cast<stereo_mode_c::mode>(index);
@@ -767,7 +777,7 @@ static void
 parse_arg_split_duration(const std::string &arg) {
   std::string s = arg;
 
-  if (ba::istarts_with(s, "duration:"))
+  if (balg::istarts_with(s, "duration:"))
     s.erase(0, strlen("duration:"));
 
   int64_t split_after;
@@ -786,7 +796,7 @@ static void
 parse_arg_split_timecodes(const std::string &arg) {
   std::string s = arg;
 
-  if (ba::istarts_with(s, "timecodes:"))
+  if (balg::istarts_with(s, "timecodes:"))
     s.erase(0, 10);
 
   std::vector<std::string> timecodes = split(s, ",");
@@ -798,6 +808,63 @@ parse_arg_split_timecodes(const std::string &arg) {
   }
 }
 
+static void
+parse_arg_split_parts(const std::string &arg) {
+  std::string s = arg;
+
+  if (balg::istarts_with(s, "parts:"))
+    s.erase(0, 6);
+
+  if (s.empty())
+      mxerror(boost::format(Y("Missing start/end specifications for '--split' in '--split %1%'.\n")) % arg);
+
+  std::vector<std::tuple<int64_t, int64_t, bool> > split_points;
+  for (auto const &part_spec : split(s, ",")) {
+    auto pair = split(part_spec, "-");
+    if (pair.size() != 2)
+      mxerror(boost::format(Y("Invalid start/end specification for '--split' in '--split %1%' (curent part: %2%).\n")) % arg % part_spec);
+
+    bool create_new_file = true;
+    if (pair[0].substr(0, 1) == "+") {
+      if (!split_points.empty())
+        create_new_file = false;
+      pair[0].erase(0, 1);
+    }
+
+    int64_t start;
+    if (pair[0].empty())
+      start = split_points.empty() ? 0 : std::get<1>(split_points.back());
+    else if (!parse_timecode(pair[0], start))
+      mxerror(boost::format(Y("Invalid start time for '--split' in '--split %1%' (current part: %2%). Additional error message: %3%.\n")) % arg % part_spec % timecode_parser_error);
+
+    int64_t end;
+    if (pair[1].empty())
+      end = std::numeric_limits<int64_t>::max();
+    else if (!parse_timecode(pair[1], end))
+      mxerror(boost::format(Y("Invalid end time for '--split' in '--split %1%' (current part: %2%). Additional error message: %3%.\n")) % arg % part_spec % timecode_parser_error);
+
+    if (end <= start)
+      mxerror(boost::format(Y("Invalid end time for '--split' in '--split %1%' (current part: %2%). The end time must be bigger than the start time.\n")) % arg % part_spec);
+
+    if (!split_points.empty() && (start < std::get<1>(split_points.back())))
+      mxerror(boost::format(Y("Invalid start time for '--split' in '--split %1%' (current part: %2%). The start time must be bigger than or equal to the previous part's end time.\n")) % arg % part_spec);
+
+    split_points.push_back(std::make_tuple(start, end, create_new_file));
+  }
+
+  int64_t previous_end = 0;
+
+  for (auto &split_point : split_points) {
+    if (previous_end < std::get<0>(split_point))
+      g_cluster_helper->add_split_point(split_point_t{ previous_end, split_point_t::SPT_PARTS, true, true, std::get<2>(split_point) });
+    g_cluster_helper->add_split_point(split_point_t{ std::get<0>(split_point), split_point_t::SPT_PARTS, true, false, std::get<2>(split_point) });
+    previous_end = std::get<1>(split_point);
+  }
+
+  if (std::get<1>(split_points.back()) < std::numeric_limits<int64_t>::max())
+    g_cluster_helper->add_split_point(split_point_t{ std::get<1>(split_points.back()), split_point_t::SPT_PARTS, true, true });
+}
+
 /** \brief Parse the size format to \c --split
 
   This function is called by ::parse_split if the format specifies
@@ -808,7 +875,7 @@ parse_arg_split_size(const std::string &arg) {
   std::string s       = arg;
   std::string err_msg = Y("Invalid split size in '--split %1%'.\n");
 
-  if (ba::istarts_with(s, "size:"))
+  if (balg::istarts_with(s, "size:"))
     s.erase(0, strlen("size:"));
 
   if (s.empty())
@@ -829,8 +896,8 @@ parse_arg_split_size(const std::string &arg) {
   if (1 != modifier)
     s.erase(s.size() - 1);
 
-  int64_t split_after;
-  if (!parse_int(s, split_after))
+  int64_t split_after = 0;
+  if (!parse_number(s, split_after))
     mxerror(boost::format(err_msg) % arg);
 
   g_cluster_helper->add_split_point(split_point_t(split_after * modifier, split_point_t::SPT_SIZE, false));
@@ -860,15 +927,18 @@ parse_arg_split(const std::string &arg) {
   std::string s = arg;
 
   // HH:MM:SS
-  if (ba::istarts_with(s, "duration:"))
+  if (balg::istarts_with(s, "duration:"))
     parse_arg_split_duration(arg);
 
-  else if (ba::istarts_with(s, "size:"))
+  else if (balg::istarts_with(s, "size:"))
     parse_arg_split_size(arg);
 
-  else if (ba::istarts_with(s, "timecodes:"))
+  else if (balg::istarts_with(s, "timecodes:"))
     parse_arg_split_timecodes(arg);
 
+  else if (balg::istarts_with(s, "parts:"))
+    parse_arg_split_parts(arg);
+
   else if ((   (s.size() == 8)
             || (s.size() == 12))
            && (':' == s[2]) && (':' == s[5])
@@ -889,6 +959,8 @@ parse_arg_split(const std::string &arg) {
     else
       mxerror(boost::format(err_msg) % arg);
   }
+
+  g_cluster_helper->dump_split_points();
 }
 
 /** \brief Parse the \c --default-track argument
@@ -904,7 +976,7 @@ parse_arg_default_track(const std::string &s,
   int64_t id           = 0;
 
   strip(parts);
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '--default-track %1%'.\n")) % s);
 
   try {
@@ -930,7 +1002,7 @@ parse_arg_forced_track(const std::string &s,
   int64_t id                     = 0;
 
   strip(parts);
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '--forced-track %1%'.\n")) % s);
 
   try {
@@ -958,7 +1030,7 @@ parse_arg_cues(const std::string &s,
     mxerror(boost::format(Y("Invalid cues option. No track ID specified in '--cues %1%'.\n")) % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '--cues %1%'.\n")) % s);
 
   if (parts[1].empty())
@@ -988,7 +1060,7 @@ parse_arg_compression(const std::string &s,
     mxerror(boost::format(Y("Invalid compression option. No track ID specified in '--compression %1%'.\n")) % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '--compression %1%'.\n")) % s);
 
   if (parts[1].size() == 0)
@@ -1001,7 +1073,7 @@ parse_arg_compression(const std::string &s,
   available_compression_methods.push_back("analyze_header_removal");
 
   ti.m_compression_list[id] = COMPRESSION_UNSPECIFIED;
-  ba::to_lower(parts[1]);
+  balg::to_lower(parts[1]);
 
   if (parts[1] == "zlib")
     ti.m_compression_list[id] = COMPRESSION_ZLIB;
@@ -1057,7 +1129,7 @@ parse_arg_language(const std::string &s,
   }
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '--%1% %2%'.\n")) % opt % s);
 
   if (check) {
@@ -1089,7 +1161,7 @@ parse_arg_sub_charset(const std::string &s,
     mxerror(boost::format(Y("Invalid sub charset option. No track ID specified in '--sub-charset %1%'.\n")) % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '--sub-charset %1%'.\n")) % s);
 
   if (parts[1].empty())
@@ -1113,7 +1185,7 @@ parse_arg_tags(const std::string &s,
     mxerror(boost::format(Y("Invalid tags option. No track ID specified in '%1% %2%'.\n")) % opt % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("Invalid track ID specified in '%1% %2%'.\n")) % opt % s);
 
   if (parts[1].empty())
@@ -1137,7 +1209,7 @@ parse_arg_fourcc(const std::string &s,
     mxerror(boost::format(Y("FourCC: Missing track ID in '%1% %2%'.\n")) % opt % orig);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("FourCC: Invalid track ID in '%1% %2%'.\n")) % opt % orig);
 
   if (parts[1].size() != 4)
@@ -1164,10 +1236,10 @@ parse_arg_track_order(const std::string &s) {
     if (pair.size() != 2)
       mxerror(boost::format(Y("'%1%' is not a valid pair of file ID and track ID in '--track-order %2%'.\n")) % parts[i] % s);
 
-    if (!parse_int(pair[0], to.file_id))
+    if (!parse_number(pair[0], to.file_id))
       mxerror(boost::format(Y("'%1%' is not a valid file ID in '--track-order %2%'.\n")) % pair[0] % s);
 
-    if (!parse_int(pair[1], to.track_id))
+    if (!parse_number(pair[1], to.track_id))
       mxerror(boost::format(Y("'%1%' is not a valid file ID in '--track-order %2%'.\n")) % pair[1] % s);
 
     g_track_order.push_back(to);
@@ -1203,10 +1275,10 @@ parse_arg_append_to(const std::string &s) {
     std::vector<std::string> parts = split(entry, ":");
 
     if (   (parts.size() != 4)
-        || !parse_int(parts[0], mapping.src_file_id)
-        || !parse_int(parts[1], mapping.src_track_id)
-        || !parse_int(parts[2], mapping.dst_file_id)
-        || !parse_int(parts[3], mapping.dst_track_id)
+        || !parse_number(parts[0], mapping.src_file_id)
+        || !parse_number(parts[1], mapping.src_track_id)
+        || !parse_number(parts[2], mapping.dst_file_id)
+        || !parse_number(parts[3], mapping.dst_track_id)
         || (0 > mapping.src_file_id)
         || (0 > mapping.src_track_id)
         || (0 > mapping.dst_file_id)
@@ -1243,7 +1315,7 @@ parse_arg_default_duration(const std::string &s,
     mxerror(boost::format(Y("'%1%' is not a valid tuple of track ID and default duration in '--default-duration %1%'.\n")) % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("'%1%' is not a valid track ID in '--default-duration %2%'.\n")) % parts[0] % s);
 
   ti.m_default_durations[id] = parse_number_with_unit(parts[1], "default duration", "--default-duration");
@@ -1264,11 +1336,11 @@ parse_arg_nalu_size_length(const std::string &s,
     mxerror(boost::format(Y("'%1%' is not a valid tuple of track ID and NALU size length in '--nalu-size-length %1%'.\n")) % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("'%1%' is not a valid track ID in '--nalu-size-length %2%'.\n")) % parts[0] % s);
 
   int64_t nalu_size_length;
-  if (!parse_int(parts[1], nalu_size_length) || (2 > nalu_size_length) || (4 < nalu_size_length))
+  if (!parse_number(parts[1], nalu_size_length) || (2 > nalu_size_length) || (4 < nalu_size_length))
     mxerror(boost::format(Y("The NALU size length must be a number between 2 and 4 inclusively in '--nalu-size-length %1%'.\n")) % s);
 
   if ((3 == nalu_size_length) && !s_nalu_size_length_3_warning_printed) {
@@ -1292,11 +1364,11 @@ parse_arg_max_blockadd_id(const std::string &s,
     mxerror(boost::format(Y("'%1%' is not a valid pair of track ID and block additional in '--blockadd %1%'.\n")) % s);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id))
+  if (!parse_number(parts[0], id))
     mxerror(boost::format(Y("'%1%' is not a valid track ID in '--blockadd %2%'.\n")) % parts[0] % s);
 
   int64_t max_blockadd_id = 0;
-  if (!parse_int(parts[1], max_blockadd_id) || (max_blockadd_id < 0))
+  if (!parse_number(parts[1], max_blockadd_id) || (max_blockadd_id < 0))
     mxerror(boost::format(Y("'%1%' is not a valid block additional max in '--blockadd %2%'.\n")) % parts[1] % s);
 
   ti.m_max_blockadd_ids[id] = max_blockadd_id;
@@ -1314,7 +1386,7 @@ parse_arg_aac_is_sbr(const std::string &s,
   std::vector<std::string> parts = split(s, ":", 2);
 
   int64_t id = 0;
-  if (!parse_int(parts[0], id) || (id < 0))
+  if (!parse_number(parts[0], id) || (id < 0))
     mxerror(boost::format(Y("Invalid track ID specified in '--aac-is-sbr %1%'.\n")) % s);
 
   if ((parts.size() == 2) && (parts[1] != "0") && (parts[1] != "1"))
@@ -1340,7 +1412,7 @@ parse_arg_priority(const std::string &arg) {
 static void
 parse_arg_previous_segment_uid(const std::string &param,
                                const std::string &arg) {
-  if (g_seguid_link_previous.is_set())
+  if (g_seguid_link_previous)
     mxerror(boost::format(Y("The previous UID was already given in '%1% %2%'.\n")) % param % arg);
 
   try {
@@ -1353,7 +1425,7 @@ parse_arg_previous_segment_uid(const std::string &param,
 static void
 parse_arg_next_segment_uid(const std::string &param,
                            const std::string &arg) {
-  if (g_seguid_link_next.is_set())
+  if (g_seguid_link_next)
     mxerror(boost::format(Y("The next UID was already given in '%1% %2%'.\n")) % param % arg);
 
   try {
@@ -1382,14 +1454,14 @@ parse_arg_cluster_length(std::string arg) {
   if (0 <= idx) {
     arg.erase(idx);
     int64_t max_ms_per_cluster;
-    if (!parse_int(arg, max_ms_per_cluster) || (100 > max_ms_per_cluster) || (32000 < max_ms_per_cluster))
+    if (!parse_number(arg, max_ms_per_cluster) || (100 > max_ms_per_cluster) || (32000 < max_ms_per_cluster))
       mxerror(boost::format(Y("Cluster length '%1%' out of range (100..32000).\n")) % arg);
 
     g_max_ns_per_cluster     = max_ms_per_cluster * 1000000;
     g_max_blocks_per_cluster = 65535;
 
   } else {
-    if (!parse_int(arg, g_max_blocks_per_cluster) || (0 > g_max_blocks_per_cluster) || (65535 < g_max_blocks_per_cluster))
+    if (!parse_number(arg, g_max_blocks_per_cluster) || (0 > g_max_blocks_per_cluster) || (65535 < g_max_blocks_per_cluster))
       mxerror(boost::format(Y("Cluster length '%1%' out of range (0..65535).\n")) % arg);
 
     g_max_ns_per_cluster = 32000000000ull;
@@ -1466,8 +1538,6 @@ parse_arg_chapters(const std::string &param,
   if (g_chapter_file_name != "")
     mxerror(boost::format(Y("Only one chapter file allowed in '%1% %2%'.\n")) % param % arg);
 
-  delete g_kax_chapters;
-
   g_chapter_file_name = arg;
   g_kax_chapters      = parse_chapters(g_chapter_file_name, 0, -1, 0, g_chapter_language.c_str(), g_chapter_charset.c_str(), false, nullptr, &g_tags_from_cue_chapters);
 }
@@ -1479,7 +1549,7 @@ parse_arg_segmentinfo(const std::string &param,
     mxerror(boost::format(Y("Only one segment info file allowed in '%1% %2%'.\n")) % param % arg);
 
   g_segmentinfo_file_name = arg;
-  g_kax_info_chap         = parse_segmentinfo(arg, false);
+  g_kax_info_chap         = mtx::xml::ebml_segmentinfo_converter_c::parse_file(arg);
 
   handle_segmentinfo();
 }
@@ -1490,7 +1560,7 @@ parse_arg_timecode_scale(const std::string &arg) {
     mxerror(Y("'--timecode-scale' was used more than once.\n"));
 
   int64_t temp = 0;
-  if (!parse_int(arg, temp))
+  if (!parse_number(arg, temp))
     mxerror(Y("The argument to '--timecode-scale' must be a number.\n"));
 
   if (-1 == temp)
@@ -1518,7 +1588,7 @@ static void
 parse_arg_attachments(const std::string &param,
                       std::string arg,
                       track_info_c &ti) {
-  if (ba::starts_with(arg, "!")) {
+  if (balg::starts_with(arg, "!")) {
     arg.erase(0, 1);
     ti.m_attach_mode_list.set_reversed();
   }
@@ -1536,7 +1606,7 @@ parse_arg_attachments(const std::string &param,
       mxerror(boost::format(Y("The argument '%1%' to '%2%' is invalid: too many colons in element '%3%'.\n")) % arg % param % elements[i]);
 
     int64_t id;
-    if (!parse_int(pair[0], id))
+    if (!parse_number(pair[0], id))
       mxerror(boost::format(Y("The argument '%1%' to '%2%' is invalid: '%3%' is not a valid track ID.\n")) % arg % param % pair[0]);
 
     if (pair[1] == "all")
@@ -1572,6 +1642,8 @@ handle_file_name_arg(const std::string &this_arg,
     if (!end_found)
       mxerror(Y("The closing parenthesis ')' are missing.\n"));
 
+    ti->m_disable_multi_file = true;
+
   } else
     file_names.push_back(this_arg);
 
@@ -1652,12 +1724,17 @@ handle_file_name_arg(const std::string &this_arg,
    pass looks for '<tt>--output-file</tt>'. The fourth pass handles
    everything else.
 */
-static void
-parse_args(std::vector<std::string> args) {
+std::vector<std::string>
+parse_common_args(std::vector<std::string> args) {
   set_usage();
   while (handle_common_cli_args(args, ""))
     set_usage();
 
+  return args;
+}
+
+static void
+parse_args(std::vector<std::string> args) {
   // Check if only information about the file is wanted. In this mode only
   // two parameters are allowed: the --identify switch and the file.
   if ((   (2 == args.size())
@@ -1795,7 +1872,7 @@ parse_args(std::vector<std::string> args) {
       if ((no_next_arg) || (next_arg[0] == 0))
         mxerror(Y("'--split-max-files' lacks the number of files.\n"));
 
-      if (!parse_int(next_arg, g_split_max_num_files) || (2 > g_split_max_num_files))
+      if (!parse_number(next_arg, g_split_max_num_files) || (2 > g_split_max_num_files))
         mxerror(Y("Wrong argument to '--split-max-files'.\n"));
 
       sit++;
@@ -2202,22 +2279,18 @@ parse_args(std::vector<std::string> args) {
     mxerror(Y("No input files were given. No output will be created.\n"));
 }
 
-/** \brief Initialize global variables
-*/
-static void
-init_globals() {
-  clear_list_of_unique_uint32(UNIQUE_ALL_IDS);
-}
-
 /** \brief Global program initialization
 
    Both platform dependant and independant initialization is done here.
    For Unix like systems a signal handler is installed. The locale's
    \c LC_MESSAGES is set.
 */
-static void
-setup() {
-  mtx_common_init();
+static std::vector<std::string>
+setup(int argc,
+      char **argv) {
+  clear_list_of_unique_uint32(UNIQUE_ALL_IDS);
+
+  mtx_common_init("mkvmerge");
   g_kax_tracks = new KaxTracks();
 
 #if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
@@ -2225,7 +2298,11 @@ setup() {
   signal(SIGINT, sighandler);
 #endif
 
-  g_cluster_helper = new cluster_helper_c();
+  auto args = parse_common_args(command_line_utf8(argc, argv));
+
+  g_cluster_helper = new cluster_helper_c;
+
+  return args;
 }
 
 /** \brief Setup and high level program control
@@ -2237,10 +2314,9 @@ setup() {
 int
 main(int argc,
      char **argv) {
-  init_globals();
-  setup();
+  auto args = setup(argc, argv);
 
-  parse_args(command_line_utf8(argc, argv));
+  parse_args(args);
 
   int64_t start = get_current_time_millis();
 
