@@ -70,7 +70,6 @@
 #include "common/translation.h"
 #include "common/unique_numbers.h"
 #include "common/version.h"
-#include "common/xml/element_mapping.h"
 #include "input/r_aac.h"
 #include "input/r_aac_adif.h"
 #include "input/r_ac3.h"
@@ -78,7 +77,6 @@
 #include "input/r_avc.h"
 #include "input/r_avi.h"
 #include "input/r_cdxa.h"
-#include "input/r_corepicture.h"
 #include "input/r_dirac.h"
 #include "input/r_dts.h"
 #include "input/r_dv.h"
@@ -134,7 +132,7 @@ family_uids_c g_segfamily_uids;
 int64_t g_attachment_sizes_first            = 0;
 int64_t g_attachment_sizes_others           = 0;
 
-KaxInfo *g_kax_info_chap                    = nullptr;
+kax_info_cptr g_kax_info_chap;
 
 // Variables set by the command line parser.
 std::string g_outfile;
@@ -166,7 +164,7 @@ KaxTrackEntry *g_kax_last_entry             = nullptr;
 KaxCues *g_kax_cues                         = nullptr;
 KaxSeekHead *g_kax_sh_main                  = nullptr;
 KaxSeekHead *g_kax_sh_cues                  = nullptr;
-KaxChapters *g_kax_chapters                 = nullptr;
+kax_chapters_cptr g_kax_chapters;
 
 KaxTags *g_tags_from_cue_chapters           = nullptr;
 
@@ -179,6 +177,8 @@ std::string g_segmentinfo_file_name;
 std::string g_segment_title;
 bool g_segment_title_set                    = false;
 
+std::string g_segment_filename, g_previous_segment_filename, g_next_segment_filename;
+
 int64_t g_tags_size                         = 0;
 
 int g_file_num = 1;
@@ -258,7 +258,7 @@ operator<<(std::ostream &str,
 #if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
 void
 sighandler(int /* signum */) {
-  if (!s_out.is_set())
+  if (!s_out)
     mxerror(Y("mkvmerge was interrupted by a SIGINT (Ctrl+C?)\n"));
 
   mxwarn(Y("\nmkvmerge received a SIGINT (probably because the user pressed "
@@ -325,7 +325,7 @@ open_input_file(filelist_t &file) {
 
   } catch (...) {
     mxerror(boost::format(Y("The source file '%1%' could not be opened successfully, or retrieving its size by seeking to the end did not work.\n")) % file.name);
-    return mm_io_cptr(nullptr);
+    return mm_io_cptr{};
   }
 }
 
@@ -337,7 +337,7 @@ open_input_file(filelist_t &file) {
 void
 get_file_type(filelist_t &file) {
   mm_io_cptr af_io = open_input_file(file);
-  mm_io_c *io      = af_io.get_object();
+  mm_io_c *io      = af_io.get();
   int64_t size     = std::min(io->get_size(), static_cast<int64_t>(1 << 25));
 
   file_type_e type = FILE_TYPE_IS_UNKNOWN;
@@ -460,8 +460,6 @@ get_file_type(filelist_t &file) {
       type = FILE_TYPE_SSA;
     else if (vobsub_reader_c::probe_file(text_io, size))
       type = FILE_TYPE_VOBSUB;
-    else if (corepicture_reader_c::probe_file(text_io, size))
-      type = FILE_TYPE_COREPICTURE;
     else if (usf_reader_c::probe_file(text_io, size))
       type = FILE_TYPE_USF;
 
@@ -483,21 +481,33 @@ get_file_type(filelist_t &file) {
 /** \brief Selects a reader for displaying its progress information
 */
 static void
-display_progress() {
+display_progress(bool is_100percent = false) {
+  static boost::tribool s_no_progress{boost::logic::indeterminate};
   static int64_t s_previous_progress_on = 0;
   static int s_previous_percentage      = -1;
 
-  if (nullptr == s_display_reader) {
+  if (boost::logic::indeterminate(s_no_progress))
+    s_no_progress = debugging_requested("no_progress");
+
+  if (s_no_progress)
+    return;
+
+  if (is_100percent) {
+    mxinfo(boost::format(Y("Progress: 100%%%1%")) % "\r");
+    return;
+  }
+
+  if (!s_display_reader) {
     std::vector<filelist_t>::const_iterator i;
 
     const filelist_t *winner = nullptr;
     for (auto &current : g_files)
-      if (!current.appending && (0 != current.reader->get_num_packetizers()) && ((nullptr == winner) || (current.size > winner->size)))
+      if (!current.appending && (0 != current.reader->get_num_packetizers()) && (!winner || (current.size > winner->size)))
         winner = &current;
 
-    if (nullptr == winner) {
+    if (!winner) {
       for (auto &current : g_files)
-        if (!current.appending && ((nullptr == winner) || (current.size > winner->size)))
+        if (!current.appending && (!winner || (current.size > winner->size)))
           winner = &current;
     }
 
@@ -529,7 +539,7 @@ add_tags(KaxTag *tags) {
   if (tags->ListSize() == 0)
     return;
 
-  if (nullptr == s_kax_tags)
+  if (!s_kax_tags)
     s_kax_tags = new KaxTags;
 
   s_kax_tags->PushElement(*tags);
@@ -633,7 +643,7 @@ set_timecode_scale() {
 
 static void
 render_ebml_head(mm_io_c *out) {
-  if (nullptr == s_head)
+  if (!s_head)
     s_head = new EbmlHead;
 
   unsigned int doc_type_read_version                     = hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS) ? 1 : 2;
@@ -667,7 +677,7 @@ render_headers(mm_io_c *out) {
 
     s_kax_infos = &GetChild<KaxInfo>(*g_kax_segment);
 
-    if ((nullptr == g_video_packetizer) || (TIMECODE_SCALE_MODE_AUTO == g_timecode_scale_mode))
+    if (!g_video_packetizer || (TIMECODE_SCALE_MODE_AUTO == g_timecode_scale_mode))
       s_kax_duration = new KaxMyDuration(EbmlFloat::FLOAT_64);
     else
       s_kax_duration = new KaxMyDuration(EbmlFloat::FLOAT_32);
@@ -732,23 +742,23 @@ render_headers(mm_io_c *out) {
       }
 
       // Set the chaptertranslate elements
-      if (nullptr != g_kax_info_chap) {
+      if (g_kax_info_chap) {
         // copy the KaxChapterTranslates in the current KaxInfo
-        KaxChapterTranslate *chapter_translate = FINDFIRST(g_kax_info_chap, KaxChapterTranslate);
-        while (nullptr != chapter_translate) {
+        KaxChapterTranslate *chapter_translate = FindChild<KaxChapterTranslate>(g_kax_info_chap.get());
+        while (chapter_translate) {
           s_kax_infos->PushElement(*new KaxChapterTranslate(*chapter_translate));
-          chapter_translate = FINDNEXT(g_kax_info_chap, KaxChapterTranslate, chapter_translate);
+          chapter_translate = FindNextChild<KaxChapterTranslate>(g_kax_info_chap.get(), chapter_translate);
         }
       }
 
-      if (first_file && g_seguid_link_previous.is_set())
+      if (first_file && g_seguid_link_previous)
         GetChild<KaxPrevUID>(*s_kax_infos).CopyBuffer(g_seguid_link_previous->data(), 128 / 8);
 
       // The next segment UID is also set in finish_file(). This is not
       // redundant! It is set here as well in order to reserve enough space
       // for the KaxInfo structure in the file. If it is removed later then
       // an EbmlVoid element will be used for the freed space.
-      if (g_seguid_link_next.is_set())
+      if (g_seguid_link_next)
         GetChild<KaxNextUID>(*s_kax_infos).CopyBuffer(g_seguid_link_next->data(), 128 / 8);
 
       if (!g_no_linking && g_cluster_helper->splitting()) {
@@ -757,6 +767,19 @@ render_headers(mm_io_c *out) {
         if (!first_file)
           GetChild<KaxPrevUID>(*s_kax_infos).CopyBuffer(s_seguid_prev.data(), 128 / 8);
       }
+
+      if (!g_segment_filename.empty())
+        GetChildAs<KaxSegmentFilename, EbmlUnicodeString>(*s_kax_infos) = cstrutf8_to_UTFstring(g_segment_filename);
+
+      if (!g_next_segment_filename.empty())
+        GetChildAs<KaxNextFilename, EbmlUnicodeString>(*s_kax_infos)    = cstrutf8_to_UTFstring(g_next_segment_filename);
+
+      if (!g_previous_segment_filename.empty())
+        GetChildAs<KaxPrevFilename, EbmlUnicodeString>(*s_kax_infos)    = cstrutf8_to_UTFstring(g_previous_segment_filename);
+
+      g_segment_filename.clear();
+      g_next_segment_filename.clear();
+      g_previous_segment_filename.clear();
     }
 
     g_kax_segment->WriteHead(*out, 8);
@@ -785,7 +808,7 @@ render_headers(mm_io_c *out) {
       set_timecode_scale();
 
       for (i = 0; i < g_packetizers.size(); i++)
-        if (nullptr != g_packetizers[i].packetizer)
+        if (g_packetizers[i].packetizer)
           g_packetizers[i].packetizer->fix_headers();
 
     } else
@@ -845,7 +868,7 @@ rerender_track_headers() {
 */
 static void
 render_attachments(IOCallback *out) {
-  if (nullptr != s_kax_as)
+  if (s_kax_as)
     delete s_kax_as;
 
   s_kax_as           = new KaxAttachments();
@@ -853,7 +876,7 @@ render_attachments(IOCallback *out) {
 
   for (auto &attch : g_attachments) {
     if ((1 == g_file_num) || attch.to_all_files) {
-      kax_a = nullptr == kax_a ? &GetChild<KaxAttached>(*s_kax_as) : &GetNextChild<KaxAttached>(*s_kax_as, *kax_a);
+      kax_a = !kax_a ? &GetChild<KaxAttached>(*s_kax_as) : &GetNextChild<KaxAttached>(*s_kax_as, *kax_a);
 
       if (attch.description != "")
         GetChildAs<KaxFileDescription, EbmlUnicodeString>(kax_a) = cstrutf8_to_UTFstring(attch.description);
@@ -1023,8 +1046,8 @@ check_append_mapping() {
         break;
       }
 
-    if ((nullptr == src_ptzr) || (nullptr == dst_ptzr))
-      mxerror(boost::format("((nullptr == src_ptzr) || (nullptr == dst_ptzr)). %1%\n") % BUGMSG);
+    if (!src_ptzr || !dst_ptzr)
+      mxerror(boost::format("(!src_ptzr || !dst_ptzr). %1%\n") % BUGMSG);
 
     // And now try to connect the packetizers.
     result = src_ptzr->can_connect_to(dst_ptzr, error_message);
@@ -1100,29 +1123,27 @@ calc_max_chapter_size() {
     if (file.appending)
       continue;
 
-    KaxChapters *chapters = file.reader->m_chapters;
-    if (nullptr == chapters)
+    if (!file.reader->m_chapters)
       continue;
 
-    if (nullptr == g_kax_chapters)
-      g_kax_chapters = new KaxChapters;
+    if (!g_kax_chapters)
+      g_kax_chapters = kax_chapters_cptr{new KaxChapters};
 
-    move_chapters_by_edition(*g_kax_chapters, *chapters);
-    delete chapters;
-    file.reader->m_chapters = nullptr;
+    move_chapters_by_edition(*g_kax_chapters, *file.reader->m_chapters);
+    file.reader->m_chapters.reset();
   }
 
   // Step 2: Fix the mandatory elements and count the size of all chapters.
   s_max_chapter_size = 0;
-  if (nullptr != g_kax_chapters) {
-    fix_mandatory_chapter_elements(g_kax_chapters);
+  if (g_kax_chapters) {
+    fix_mandatory_chapter_elements(g_kax_chapters.get());
     g_kax_chapters->UpdateSize(true);
     s_max_chapter_size += g_kax_chapters->ElementSize();
   }
 
   for (auto &file : g_files) {
-    KaxChapters *chapters = file.reader->m_chapters;
-    if (nullptr == chapters)
+    KaxChapters *chapters = file.reader->m_chapters.get();
+    if (!chapters)
       continue;
 
     fix_mandatory_chapter_elements(chapters);
@@ -1213,9 +1234,6 @@ create_readers() {
         case FILE_TYPE_USF:
           file.reader = new usf_reader_c(*file.ti, input_file);
           break;
-        case FILE_TYPE_COREPICTURE:
-          file.reader = new corepicture_reader_c(*file.ti, input_file);
-          break;
         case FILE_TYPE_VC1:
           file.reader = new vc1_es_reader_c(*file.ti, input_file);
           break;
@@ -1335,7 +1353,7 @@ create_output_name() {
 
 void
 add_tags_from_cue_chapters() {
-  if ((nullptr == g_tags_from_cue_chapters) || ptzrs_in_header_order.empty())
+  if (!g_tags_from_cue_chapters || ptzrs_in_header_order.empty())
     return;
 
   bool found = false;
@@ -1362,7 +1380,7 @@ add_tags_from_cue_chapters() {
   for (i = 0; g_tags_from_cue_chapters->ListSize() > i; ++i)
     GetChildAs<KaxTagTrackUID, EbmlUInteger>(GetChild<KaxTagTargets>(*static_cast<KaxTag *>((*g_tags_from_cue_chapters)[i]))) = tuid;
 
-  if (nullptr == s_kax_tags)
+  if (!s_kax_tags)
     s_kax_tags = g_tags_from_cue_chapters;
   else {
     while (g_tags_from_cue_chapters->ListSize() > 0) {
@@ -1393,8 +1411,7 @@ render_chapter_void_placeholder() {
   if (outputting_webm()) {
     mxwarn(boost::format(Y("Chapters are not allowed in WebM compliant files. No chapters will be written into any output file.\n")));
 
-    delete g_kax_chapters;
-    g_kax_chapters     = nullptr;
+    g_kax_chapters.reset();
     s_max_chapter_size = 0;
 
     return;
@@ -1416,7 +1433,7 @@ render_chapter_void_placeholder() {
  */
 static void
 prepare_tags_for_rendering() {
-  if (nullptr == s_kax_tags)
+  if (!s_kax_tags)
     return;
 
   if (outputting_webm()) {
@@ -1446,7 +1463,9 @@ prepare_tags_for_rendering() {
 */
 void
 create_next_output_file() {
-  std::string this_outfile = g_cluster_helper->splitting() ? create_output_name() : g_outfile;
+  mxdebug_if(debugging_requested("splitting"), boost::format("Create next output file splitting? %1% discarding? %2%\n") % g_cluster_helper->splitting() % g_cluster_helper->discarding());
+
+  auto this_outfile   = g_cluster_helper->split_mode_produces_many_files() ? create_output_name() : g_outfile;
 
   g_kax_segment       = new KaxSegment();
   g_kax_cues          = new KaxCues();
@@ -1454,22 +1473,23 @@ create_next_output_file() {
 
   // Open the output file.
   try {
-    s_out = mm_write_buffer_io_c::open(this_outfile, 20 * 1024 * 1024);
+    s_out = !g_cluster_helper->discarding() ? mm_write_buffer_io_c::open(this_outfile, 20 * 1024 * 1024) : mm_io_cptr{ new mm_null_io_c{this_outfile} };
   } catch (...) {
     mxerror(boost::format(Y("The output file '%1%' could not be opened for writing (%2%).\n")) % this_outfile % strerror(errno));
   }
 
-  if (verbose)
+  if (verbose && !g_cluster_helper->discarding())
     mxinfo(boost::format(Y("The file '%1%' has been opened for writing.\n")) % this_outfile);
 
-  g_cluster_helper->set_output(s_out.get_object());
-  render_headers(s_out.get_object());
-  render_attachments(s_out.get_object());
+  g_cluster_helper->set_output(s_out.get());
+  render_headers(s_out.get());
+  render_attachments(s_out.get());
   render_chapter_void_placeholder();
   add_tags_from_cue_chapters();
   prepare_tags_for_rendering();
 
-  g_file_num++;
+  if (!g_cluster_helper->discarding())
+    ++g_file_num;
 }
 
 /** \brief Finishes and closes the current file
@@ -1482,7 +1502,9 @@ create_next_output_file() {
 */
 int64_t
 finish_file(bool last_file) {
-  mxinfo("\n");
+  bool do_output = verbose && !dynamic_cast<mm_null_io_c *>(s_out.get());
+  if (do_output)
+    mxinfo("\n");
 
   // Render the track headers a second time if the user has requested that.
   if (hack_engaged(ENGAGE_WRITE_HEADERS_TWICE)) {
@@ -1494,11 +1516,9 @@ finish_file(bool last_file) {
 
   // Render the cues.
   if (g_write_cues && g_cue_writing_requested) {
-    if (1 <= verbose)
-      mxinfo(Y("The cue entries (the index) are being written..."));
+    if (do_output)
+      mxinfo(Y("The cue entries (the index) are being written...\n"));
     g_kax_cues->Render(*s_out);
-    if (1 <= verbose)
-      mxinfo("\n");
   }
 
   // Now re-render the s_kax_duration and fill in the biggest timecode
@@ -1521,7 +1541,7 @@ finish_file(bool last_file) {
   int64_t info_size = s_kax_infos->ElementSize();
   int changed       = 0;
 
-  if (last_file && g_seguid_link_next.is_set()) {
+  if (last_file && g_seguid_link_next) {
     GetChild<KaxNextUID>(*s_kax_infos).CopyBuffer(g_seguid_link_next->data(), 128 / 8);
     changed = 1;
 
@@ -1567,7 +1587,7 @@ finish_file(bool last_file) {
   // that was resesrved at the beginning.
   KaxChapters *chapters_here = nullptr;
 
-  if (nullptr != g_kax_chapters) {
+  if (g_kax_chapters) {
     int64_t offset = g_no_linking ? g_cluster_helper->get_first_timecode_in_file() : 0;
     int64_t start  = g_cluster_helper->get_first_timecode_in_file();
     int64_t end    = start + g_cluster_helper->get_duration();
@@ -1575,9 +1595,12 @@ finish_file(bool last_file) {
     chapters_here  = copy_chapters(g_kax_chapters);
 
     if (g_cluster_helper->splitting())
-      chapters_here = select_chapters_in_timeframe(chapters_here, start, end, offset);
+      if (!select_chapters_in_timeframe(chapters_here, start, end, offset)) {
+        delete chapters_here;
+        chapters_here = nullptr;
+      }
 
-    if (nullptr != chapters_here) {
+    if (chapters_here) {
       merge_chapter_entries(*chapters_here);
       sort_ebml_master(chapters_here);
       s_kax_chapters_void->ReplaceWith(*chapters_here, *s_out, true, true);
@@ -1598,14 +1621,14 @@ finish_file(bool last_file) {
 
   // Render the tags if we have any.
   KaxTags *tags_here = nullptr;
-  if (nullptr != s_kax_tags) {
-    if (nullptr == s_chapters_in_this_file) {
+  if (s_kax_tags) {
+    if (!s_chapters_in_this_file) {
       KaxChapters temp_chapters;
       tags_here = select_tags_for_chapters(*s_kax_tags, temp_chapters);
     } else
       tags_here = select_tags_for_chapters(*s_kax_tags, *s_chapters_in_this_file);
 
-    if (nullptr != tags_here) {
+    if (tags_here) {
       fix_mandatory_tag_elements(tags_here);
       tags_here->UpdateSize();
       tags_here->Render(*s_out, true);
@@ -1617,26 +1640,26 @@ finish_file(bool last_file) {
   if (g_cue_writing_requested)
     g_kax_sh_main->IndexThis(*g_kax_cues, *g_kax_segment);
 
-  if (nullptr != tags_here) {
+  if (tags_here) {
     g_kax_sh_main->IndexThis(*tags_here, *g_kax_segment);
     delete tags_here;
   }
 
-  if (nullptr != s_chapters_in_this_file) {
+  if (s_chapters_in_this_file) {
     delete s_chapters_in_this_file;
     s_chapters_in_this_file = nullptr;
   }
 
-  if (nullptr != chapters_here) {
+  if (chapters_here) {
     if (!hack_engaged(ENGAGE_NO_CHAPTERS_IN_META_SEEK))
       g_kax_sh_main->IndexThis(*chapters_here, *g_kax_segment);
     delete chapters_here;
 
-  } else if (!g_cluster_helper->splitting() && (nullptr != g_kax_chapters))
+  } else if (!g_cluster_helper->splitting() && g_kax_chapters)
     if (!hack_engaged(ENGAGE_NO_CHAPTERS_IN_META_SEEK))
       g_kax_sh_main->IndexThis(*g_kax_chapters, *g_kax_segment);
 
-  if (nullptr != s_kax_as) {
+  if (s_kax_as) {
     g_kax_sh_main->IndexThis(*s_kax_as, *g_kax_segment);
     delete s_kax_as;
     s_kax_as = nullptr;
@@ -1654,12 +1677,12 @@ finish_file(bool last_file) {
   if (g_kax_segment->ForceSize(final_file_size - g_kax_segment->GetElementPosition() - g_kax_segment->HeadSize()))
     g_kax_segment->OverwriteHead(*s_out);
 
-  s_out.clear();
+  s_out.reset();
 
   // The tracks element must not be deleted.
   size_t i;
   for (i = 0; i < g_kax_segment->ListSize(); ++i)
-    if (nullptr == dynamic_cast<KaxTracks *>((*g_kax_segment)[i]))
+    if (!dynamic_cast<KaxTracks *>((*g_kax_segment)[i]))
       delete (*g_kax_segment)[i];
   g_kax_segment->RemoveAll();
 
@@ -1668,7 +1691,7 @@ finish_file(bool last_file) {
   delete s_kax_sh_void;
   delete g_kax_sh_main;
   delete s_void_after_track_headers;
-  if (nullptr != g_kax_sh_cues)
+  if (g_kax_sh_cues)
     delete g_kax_sh_cues;
   delete s_head;
 
@@ -1696,7 +1719,7 @@ append_track(packetizer_t &ptzr,
   filelist_t &src_file = g_files[amap.src_file_id];
   filelist_t &dst_file = g_files[amap.dst_file_id];
 
-  if (nullptr != deferred_file)
+  if (deferred_file)
     src_file.deferred_max_timecode_seen = deferred_file->reader->m_max_timecode_seen;
 
   // Find the generic_packetizer_c that we will be appending to the one
@@ -1715,7 +1738,7 @@ append_track(packetizer_t &ptzr,
   if (   !dst_file.done
       && (   (APPEND_MODE_FILE_BASED     == g_append_mode)
           || ((*gptzr)->get_track_type() == track_subtitle)
-          || (nullptr                       != src_file.reader->m_chapters))) {
+          || src_file.reader->m_chapters)) {
     dst_file.reader->read_all();
     dst_file.num_unfinished_packetizers     = 0;
     dst_file.old_num_unfinished_packetizers = 0;
@@ -1727,7 +1750,7 @@ append_track(packetizer_t &ptzr,
       && (track_subtitle == (*gptzr)->get_track_type())
       && (             0 == dst_file.reader->m_num_video_tracks)
       && (            -1 == src_file.deferred_max_timecode_seen)
-      && (          nullptr != g_video_packetizer)) {
+      && g_video_packetizer) {
 
     for (auto &file : g_files) {
       if (file.done)
@@ -1789,7 +1812,7 @@ append_track(packetizer_t &ptzr,
     // Intentionally left empty.
     ;
 
-  else if (ptzr.deferred && (nullptr != deferred_file))
+  else if (ptzr.deferred && deferred_file)
     timecode_adjustment = src_file.deferred_max_timecode_seen;
 
   else if (   (track_subtitle == ptzr.packetizer->get_track_type())
@@ -1797,11 +1820,11 @@ append_track(packetizer_t &ptzr,
     timecode_adjustment = src_file.deferred_max_timecode_seen;
 
   else if (   (ptzr.packetizer->get_track_type() == track_subtitle)
-           || (nullptr != src_file.reader->m_chapters)) {
-    if (nullptr == src_file.reader->m_ptzr_first_packet)
+           || (src_file.reader->m_chapters)) {
+    if (!src_file.reader->m_ptzr_first_packet)
       ptzr.status = ptzr.packetizer->read();
 
-    if (nullptr != src_file.reader->m_ptzr_first_packet) {
+    if (src_file.reader->m_ptzr_first_packet) {
       std::vector<append_spec_t>::const_iterator cmp_amap;
       mxforeach(cmp_amap, g_append_mapping)
         if (   (cmp_amap->src_file_id  == amap.src_file_id)
@@ -1834,16 +1857,15 @@ append_track(packetizer_t &ptzr,
   // Append some more chapters and adjust their timecodes by the highest
   // timecode seen in the previous file/the track that we've been searching
   // for above.
-  KaxChapters *chapters = src_file.reader->m_chapters;
-  if (nullptr != chapters) {
-    if (nullptr == g_kax_chapters)
-      g_kax_chapters = new KaxChapters;
+  KaxChapters *chapters = src_file.reader->m_chapters.get();
+  if (chapters) {
+    if (!g_kax_chapters)
+      g_kax_chapters = kax_chapters_cptr{new KaxChapters};
     else
       align_chapter_edition_uids(*g_kax_chapters, *chapters);
     adjust_chapter_timecodes(*chapters, timecode_adjustment);
     move_chapters_by_edition(*g_kax_chapters, *chapters);
-    delete chapters;
-    src_file.reader->m_chapters = nullptr;
+    src_file.reader->m_chapters.reset();
   }
 
   ptzr.deferred = false;
@@ -1878,7 +1900,7 @@ append_tracks_maybe() {
         break;
       }
 
-    if (nullptr == amap)
+    if (!amap)
       continue;
 
     append_track(ptzr, *amap);
@@ -1933,7 +1955,7 @@ main_loop() {
 
       ptzr.old_status = ptzr.status;
 
-      while (   !ptzr.pack.is_set()
+      while (   !ptzr.pack
              && (FILE_STATUS_MOREDATA == ptzr.status)
              && !ptzr.packetizer->packet_available())
         ptzr.status = ptzr.packetizer->read();
@@ -1942,10 +1964,10 @@ main_loop() {
           && (FILE_STATUS_MOREDATA == ptzr.old_status))
         ptzr.packetizer->force_duration_on_last_packet();
 
-      if (!ptzr.pack.is_set())
+      if (!ptzr.pack)
         ptzr.pack = ptzr.packetizer->get_packet();
 
-      if (!ptzr.pack.is_set() && (FILE_STATUS_DONE == ptzr.status))
+      if (!ptzr.pack && (FILE_STATUS_DONE == ptzr.status))
         ptzr.status = FILE_STATUS_DONE_AND_DRY;
 
       // Has this packetizer changed its status from "data available" to
@@ -1970,11 +1992,11 @@ main_loop() {
     // stuff it into the Matroska file.
     packetizer_t * winner = nullptr;
     for (auto &ptzr : g_packetizers) {
-      if (ptzr.pack.is_set()) {
-        if ((nullptr == winner) || !winner->pack.is_set())
+      if (ptzr.pack) {
+        if (!winner || !winner->pack)
           winner = &ptzr;
 
-        else if (ptzr.pack.is_set() && (ptzr.pack->assigned_timecode < winner->pack->assigned_timecode))
+        else if (ptzr.pack && (ptzr.pack->assigned_timecode < winner->pack->assigned_timecode))
           winner = &ptzr;
       }
     }
@@ -1982,14 +2004,14 @@ main_loop() {
     // Append the next track if appending is wanted.
     bool appended_a_track = append_tracks_maybe();
 
-    if ((nullptr != winner) && winner->pack.is_set()) {
+    if (winner && winner->pack) {
       packet_cptr pack = winner->pack;
 
       // Step 3: Add the winning packet to a cluster. Full clusters will be
       // rendered automatically.
       g_cluster_helper->add_packet(pack);
 
-      winner->pack = packet_cptr(nullptr);
+      winner->pack.reset();
 
       // display some progress information
       if (1 <= verbose)
@@ -2000,11 +2022,11 @@ main_loop() {
   }
 
   // Render all remaining packets (if there are any).
-  if ((nullptr != g_cluster_helper) && (0 < g_cluster_helper->get_packet_count()))
+  if (g_cluster_helper && (0 < g_cluster_helper->get_packet_count()))
     g_cluster_helper->render();
 
   if (1 <= verbose)
-    mxinfo(boost::format(Y("Progress: 100%%%1%")) % "\r");
+    display_progress(true);
 }
 
 /** \brief Deletes the file readers and other associated objects
@@ -2038,14 +2060,12 @@ cleanup() {
   delete g_tags_from_cue_chapters;
   g_tags_from_cue_chapters = nullptr;
 
-  delete g_kax_chapters;
-  g_kax_chapters = nullptr;
+  g_kax_chapters.reset();
 
   delete s_kax_as;
   s_kax_as = nullptr;
 
-  delete g_kax_info_chap;
-  g_kax_info_chap = nullptr;
+  g_kax_info_chap.reset();
 
   g_forced_seguids.clear();
 
