@@ -21,7 +21,7 @@
 
 #include "common/bitvalue.h"
 #include "common/file_types.h"
-#include "common/smart_pointers.h"
+#include "common/segmentinfo.h"
 #include "merge/mkvmerge.h"
 #include "merge/pr_generic.h"
 
@@ -129,7 +129,7 @@ struct attachment_t {
     id           = 0;
     ui_id        = 0;
     to_all_files = false;
-    data         = memory_cptr(nullptr);
+    data.reset();
   }
 };
 
@@ -165,13 +165,13 @@ extern std::string g_outfile;
 extern double g_timecode_scale;
 extern timecode_scale_mode_e g_timecode_scale_mode;
 
-typedef counted_ptr<bitvalue_c> g_bitvalue_cptr;
+typedef std::shared_ptr<bitvalue_c> g_bitvalue_cptr;
 
 extern bitvalue_cptr g_seguid_link_previous, g_seguid_link_next;
 extern std::deque<bitvalue_cptr> g_forced_seguids;
 extern family_uids_c g_segfamily_uids;
 
-extern KaxInfo *g_kax_info_chap;
+extern kax_info_cptr g_kax_info_chap;
 
 extern bool g_write_meta_seek_for_clusters;
 
@@ -188,10 +188,11 @@ extern KaxTracks *g_kax_tracks;
 extern KaxTrackEntry *g_kax_last_entry;
 extern KaxCues *g_kax_cues;
 extern KaxSeekHead *g_kax_sh_main, *g_kax_sh_cues;
-extern KaxChapters *g_kax_chapters;
+extern kax_chapters_cptr g_kax_chapters;
 extern int64_t g_tags_size;
 extern std::string g_segment_title;
 extern bool g_segment_title_set;
+extern std::string g_segment_filename, g_previous_segment_filename, g_next_segment_filename;
 extern std::string g_default_language;
 
 extern float g_video_fps;
