@@ -32,7 +32,7 @@ public:
   virtual ~multiple_timecodes_packet_extension_c() {
   }
 
-  virtual packet_extension_type_e get_type() {
+  virtual packet_extension_type_e get_type() const {
     return MULTIPLE_TIMECODES;
   }
 
@@ -59,7 +59,7 @@ public:
   }
 };
 
-typedef counted_ptr<multiple_timecodes_packet_extension_c> multiple_timecodes_packet_extension_cptr;
+typedef std::shared_ptr<multiple_timecodes_packet_extension_c> multiple_timecodes_packet_extension_cptr;
 
 class subtitle_number_packet_extension_c: public packet_extension_c {
 private:
@@ -71,7 +71,7 @@ public:
   {
   }
 
-  virtual packet_extension_type_e get_type() {
+  virtual packet_extension_type_e get_type() const {
     return SUBTITLE_NUMBER;
   }
 
@@ -80,6 +80,6 @@ public:
   }
 };
 
-typedef counted_ptr<subtitle_number_packet_extension_c> subtitle_number_packet_extension_cptr;
+typedef std::shared_ptr<subtitle_number_packet_extension_c> subtitle_number_packet_extension_cptr;
 
 #endif  // __PACKET_EXTENSIONS_H
