@@ -29,10 +29,10 @@
 #include "common/ebml.h"
 #include "common/hacks.h"
 #include "common/math.h"
+#include "common/mm_multi_file_io.h"
 #include "common/strings/formatting.h"
-#include "common/tags/tags.h"
-#include "common/tags/parser.h"
 #include "common/unique_numbers.h"
+#include "common/xml/ebml_tags_converter.h"
 #include "merge/mkvmerge.h"
 #include "merge/output_control.h"
 #include "merge/pr_generic.h"
@@ -48,12 +48,6 @@
     : map_has_key(container, -1)        ? -1        \
     :                                     -2
 
-
-int64_t packet_t::sm_packet_number_counter = 0;
-
-packet_t::~packet_t() {
-}
-
 // ---------------------------------------------------------------------
 
 std::vector<generic_packetizer_c *> ptzrs_in_header_order;
@@ -154,11 +148,8 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
     m_ti.m_tags_file_name = m_ti.m_all_tags[m_ti.m_id];
   else if (map_has_key(m_ti.m_all_tags, -1))
     m_ti.m_tags_file_name = m_ti.m_all_tags[-1];
-  if (m_ti.m_tags_file_name != "") {
-    delete m_ti.m_tags;
-    m_ti.m_tags = new KaxTags;
-    parse_xml_tags(m_ti.m_tags_file_name, m_ti.m_tags);
-  }
+  if (!m_ti.m_tags_file_name.empty())
+    m_ti.m_tags = mtx::xml::ebml_tags_converter_c::parse_file(m_ti.m_tags_file_name);
 
   // Let's see if the user has specified how this track should be compressed.
   if (map_has_key(m_ti.m_compression_list, m_ti.m_id))
@@ -247,7 +238,7 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   // If no external timecode file but a default duration has been
   // given then create a simple timecode factory that generates the
   // timecodes for the given FPS.
-  if (!m_timecode_factory.is_set() && (-1 != m_htrack_default_duration))
+  if (!m_timecode_factory && (-1 != m_htrack_default_duration))
     m_timecode_factory = timecode_factory_c::create_fps_factory(m_htrack_default_duration, m_ti.m_fname, m_ti.m_id);
 }
 
@@ -259,7 +250,7 @@ generic_packetizer_c::~generic_packetizer_c() {
 
 void
 generic_packetizer_c::set_tag_track_uid() {
-  if (nullptr == m_ti.m_tags)
+  if (!m_ti.m_tags)
     return;
 
   convert_old_tags(*m_ti.m_tags);
@@ -284,7 +275,7 @@ generic_packetizer_c::set_uid(uint32_t uid) {
   if (is_unique_uint32(uid, UNIQUE_TRACK_IDS)) {
     add_unique_uint32(uid, UNIQUE_TRACK_IDS);
     m_huid = uid;
-    if (nullptr != m_track_entry)
+    if (m_track_entry)
       GetChildAs<KaxTrackUID, EbmlUInteger>(m_track_entry) = m_huid;
 
     return 1;
@@ -306,7 +297,7 @@ generic_packetizer_c::set_track_type(int type,
 
   else if (track_video == type) {
     m_reader->m_num_video_tracks++;
-    if (nullptr == g_video_packetizer)
+    if (!g_video_packetizer)
       g_video_packetizer = this;
 
   } else
@@ -323,21 +314,21 @@ generic_packetizer_c::set_track_type(int type,
   else if (TFA_AUTOMATIC != tfa_mode)
     m_timecode_factory_application_mode = tfa_mode;
 
-  if (m_timecode_factory.is_set() && (track_video != type) && (track_audio != type))
+  if (m_timecode_factory && (track_video != type) && (track_audio != type))
     m_timecode_factory->set_preserve_duration(true);
 }
 
 void
 generic_packetizer_c::set_track_name(const std::string &name) {
   m_ti.m_track_name = name;
-  if ((nullptr != m_track_entry) && !name.empty())
+  if (m_track_entry && !name.empty())
     GetChildAs<KaxTrackName, EbmlUnicodeString>(m_track_entry) = cstrutf8_to_UTFstring(m_ti.m_track_name);
 }
 
 void
 generic_packetizer_c::set_codec_id(const std::string &id) {
   m_hcodec_id = id;
-  if ((nullptr != m_track_entry) && !id.empty())
+  if (m_track_entry && !id.empty())
     GetChildAs<KaxCodecID, EbmlString>(m_track_entry) = m_hcodec_id;
 }
 
@@ -346,7 +337,7 @@ generic_packetizer_c::set_codec_private(const unsigned char *cp,
                                         int length) {
   safefree(m_hcodec_private);
 
-  if (nullptr == cp) {
+  if (!cp) {
     m_hcodec_private        = nullptr;
     m_hcodec_private_length = 0;
     return;
@@ -355,21 +346,21 @@ generic_packetizer_c::set_codec_private(const unsigned char *cp,
   m_hcodec_private        = (unsigned char *)safememdup(cp, length);
   m_hcodec_private_length = length;
 
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChild<KaxCodecPrivate>(*m_track_entry).CopyBuffer((binary *)m_hcodec_private, m_hcodec_private_length);
 }
 
 void
 generic_packetizer_c::set_track_min_cache(int min_cache) {
   m_htrack_min_cache = min_cache;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxTrackMinCache, EbmlUInteger>(m_track_entry) = min_cache;
 }
 
 void
 generic_packetizer_c::set_track_max_cache(int max_cache) {
   m_htrack_max_cache = max_cache;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxTrackMaxCache, EbmlUInteger>(m_track_entry) = max_cache;
 }
 
@@ -380,14 +371,14 @@ generic_packetizer_c::set_track_default_duration(int64_t def_dur) {
 
   m_htrack_default_duration = (int64_t)(def_dur * m_ti.m_tcsync.numerator / m_ti.m_tcsync.denominator);
 
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxTrackDefaultDuration, EbmlUInteger>(m_track_entry) = m_htrack_default_duration;
 }
 
 void
 generic_packetizer_c::set_track_max_additionals(int max_add_block_ids) {
   m_htrack_max_add_block_ids = max_add_block_ids;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxMaxBlockAdditionID, EbmlUInteger>(m_track_entry) = max_add_block_ids;
 }
 
@@ -399,63 +390,63 @@ generic_packetizer_c::get_track_default_duration() {
 void
 generic_packetizer_c::set_track_forced_flag(bool forced_track) {
   m_ti.m_forced_track = forced_track;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxTrackFlagForced, EbmlUInteger>(m_track_entry) = forced_track ? 1 : 0;
 }
 
 void
 generic_packetizer_c::set_track_enabled_flag(bool enabled_track) {
   m_ti.m_enabled_track = enabled_track;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxTrackFlagEnabled, EbmlUInteger>(m_track_entry) = enabled_track ? 1 : 0;
 }
 
 void
 generic_packetizer_c::set_audio_sampling_freq(float freq) {
   m_haudio_sampling_freq = freq;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxAudioSamplingFreq, EbmlFloat>(GetChild<KaxTrackAudio>(m_track_entry)) = m_haudio_sampling_freq;
 }
 
 void
 generic_packetizer_c::set_audio_output_sampling_freq(float freq) {
   m_haudio_output_sampling_freq = freq;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxAudioOutputSamplingFreq, EbmlFloat>(GetChild<KaxTrackAudio>(m_track_entry)) = m_haudio_output_sampling_freq;
 }
 
 void
 generic_packetizer_c::set_audio_channels(int channels) {
   m_haudio_channels = channels;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxAudioChannels, EbmlUInteger>(GetChild<KaxTrackAudio>(*m_track_entry)) = m_haudio_channels;
 }
 
 void
 generic_packetizer_c::set_audio_bit_depth(int bit_depth) {
   m_haudio_bit_depth = bit_depth;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxAudioBitDepth, EbmlUInteger>(GetChild<KaxTrackAudio>(*m_track_entry)) = m_haudio_bit_depth;
 }
 
 void
 generic_packetizer_c::set_video_interlaced_flag(bool interlaced) {
   m_hvideo_interlaced_flag = interlaced ? 1 : 0;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxVideoFlagInterlaced, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_interlaced_flag;
 }
 
 void
 generic_packetizer_c::set_video_pixel_width(int width) {
   m_hvideo_pixel_width = width;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxVideoPixelWidth, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_pixel_width;
 }
 
 void
 generic_packetizer_c::set_video_pixel_height(int height) {
   m_hvideo_pixel_height = height;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxVideoPixelHeight, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_pixel_height;
 }
 
@@ -469,14 +460,14 @@ generic_packetizer_c::set_video_pixel_dimensions(int width,
 void
 generic_packetizer_c::set_video_display_width(int width) {
   m_hvideo_display_width = width;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxVideoDisplayWidth, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_display_width;
 }
 
 void
 generic_packetizer_c::set_video_display_height(int height) {
   m_hvideo_display_height = height;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxVideoDisplayHeight, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_display_height;
 }
 
@@ -531,7 +522,7 @@ generic_packetizer_c::set_as_default_track(int type,
 void
 generic_packetizer_c::set_language(const std::string &language) {
   m_ti.m_language = language;
-  if (nullptr != m_track_entry)
+  if (m_track_entry)
     GetChildAs<KaxTrackLanguage, EbmlString>(m_track_entry) = m_ti.m_language;
 }
 
@@ -550,7 +541,7 @@ generic_packetizer_c::set_video_pixel_cropping(int left,
   m_ti.m_pixel_cropping.bottom = bottom;
   m_ti.m_pixel_cropping_source = source;
 
-  if (nullptr != m_track_entry) {
+  if (m_track_entry) {
     KaxTrackVideo &video = GetChild<KaxTrackVideo>(m_track_entry);
 
     GetChildAs<KaxVideoPixelCropLeft,   EbmlUInteger>(video) = m_ti.m_pixel_cropping.left;
@@ -575,7 +566,7 @@ generic_packetizer_c::set_video_stereo_mode(stereo_mode_c::mode stereo_mode,
   m_ti.m_stereo_mode        = stereo_mode;
   m_ti.m_stereo_mode_source = source;
 
-  if ((nullptr != m_track_entry) && (stereo_mode_c::unspecified != stereo_mode))
+  if (m_track_entry && (stereo_mode_c::unspecified != stereo_mode))
     set_video_stereo_mode_impl(GetChild<KaxTrackVideo>(*m_track_entry), m_ti.m_stereo_mode);
 }
 
@@ -611,8 +602,8 @@ generic_packetizer_c::set_headers() {
   if (!found)
     ptzrs_in_header_order.push_back(this);
 
-  if (nullptr == m_track_entry) {
-    m_track_entry    = nullptr == g_kax_last_entry ? &GetChild<KaxTrackEntry>(g_kax_tracks) : &GetNextChild<KaxTrackEntry>(*g_kax_tracks, *g_kax_last_entry);
+  if (!m_track_entry) {
+    m_track_entry    = !g_kax_last_entry ? &GetChild<KaxTrackEntry>(g_kax_tracks) : &GetNextChild<KaxTrackEntry>(*g_kax_tracks, *g_kax_last_entry);
     g_kax_last_entry = m_track_entry;
     m_track_entry->SetGlobalTimecodeScale((int64_t)g_timecode_scale);
   }
@@ -630,7 +621,7 @@ generic_packetizer_c::set_headers() {
   if (!m_hcodec_id.empty())
     GetChildAs<KaxCodecID, EbmlString>(m_track_entry)     = m_hcodec_id;
 
-  if (nullptr != m_hcodec_private)
+  if (m_hcodec_private)
     GetChild<KaxCodecPrivate>(*m_track_entry).CopyBuffer((binary *)m_hcodec_private, m_hcodec_private_length);
 
   if (!outputting_webm()) {
@@ -644,7 +635,7 @@ generic_packetizer_c::set_headers() {
       GetChildAs<KaxMaxBlockAdditionID, EbmlUInteger>(m_track_entry) = m_htrack_max_add_block_ids;
   }
 
-  if (m_timecode_factory.is_set())
+  if (m_timecode_factory)
     m_htrack_default_duration = (int64_t)m_timecode_factory->get_default_duration(m_htrack_default_duration);
   if (-1.0 != m_htrack_default_duration)
     GetChildAs<KaxTrackDefaultDuration, EbmlUInteger>(m_track_entry) = m_htrack_default_duration;
@@ -759,7 +750,7 @@ generic_packetizer_c::set_headers() {
     m_track_entry->EnableLacing(false);
 
   set_tag_track_uid();
-  if (nullptr != m_ti.m_tags) {
+  if (m_ti.m_tags) {
     while (m_ti.m_tags->ListSize() != 0) {
       KaxTag *tag = (KaxTag *)(*m_ti.m_tags)[0];
       add_tags(tag);
@@ -782,7 +773,7 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
 
   ++m_num_packets;
 
-  if (nullptr == m_reader->m_ptzr_first_packet)
+  if (!m_reader->m_ptzr_first_packet)
     m_reader->m_ptzr_first_packet = this;
 
   // strip elements to be removed
@@ -790,12 +781,12 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
       && (pack->data_adds.size()  > static_cast<size_t>(m_htrack_max_add_block_ids)))
     pack->data_adds.resize(m_htrack_max_add_block_ids);
 
-  if (m_compressor.is_set()) {
+  if (m_compressor) {
     try {
-      m_compressor->compress(pack->data);
+      pack->data = m_compressor->compress(pack->data);
       size_t i;
       for (i = 0; pack->data_adds.size() > i; ++i)
-        m_compressor->compress(pack->data_adds[i]);
+        pack->data_adds[i] = m_compressor->compress(pack->data_adds[i]);
 
     } catch (mtx::compression_x &e) {
       mxerror_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Compression failed: %1%\n")) % e.error());
@@ -881,7 +872,7 @@ generic_packetizer_c::add_packet2(packet_cptr pack) {
   pack->timecode_before_factory = pack->timecode;
 
   m_packet_queue.push_back(pack);
-  if (!m_timecode_factory.is_set() || (TFA_IMMEDIATE == m_timecode_factory_application_mode))
+  if (!m_timecode_factory || (TFA_IMMEDIATE == m_timecode_factory_application_mode))
     apply_factory_once(pack);
   else
     apply_factory();
@@ -897,7 +888,7 @@ generic_packetizer_c::process_deferred_packets() {
 packet_cptr
 generic_packetizer_c::get_packet() {
   if (m_packet_queue.empty() || !m_packet_queue.front()->factory_applied)
-    return packet_cptr(nullptr);
+    return packet_cptr{};
 
   packet_cptr pack = m_packet_queue.front();
   m_packet_queue.pop_front();
@@ -913,7 +904,7 @@ generic_packetizer_c::get_packet() {
 
 void
 generic_packetizer_c::apply_factory_once(packet_cptr &packet) {
-  if (!m_timecode_factory.is_set()) {
+  if (!m_timecode_factory) {
     packet->assigned_timecode = packet->timecode;
     packet->gap_following     = false;
   } else
@@ -1110,7 +1101,7 @@ generic_packetizer_c::set_displacement_maybe(int64_t displacement) {
 
 bool
 generic_packetizer_c::contains_gap() {
-  return m_timecode_factory.is_set() ? m_timecode_factory->contains_gap() : false;
+  return m_timecode_factory ? m_timecode_factory->contains_gap() : false;
 }
 
 void
@@ -1146,7 +1137,6 @@ generic_reader_c::generic_reader_c(const track_info_c &ti,
   , m_size(in->get_size())
   , m_ptzr_first_packet(nullptr)
   , m_max_timecode_seen(0)
-  , m_chapters(nullptr)
   , m_appending(false)
   , m_num_video_tracks(0)
   , m_num_audio_tracks(0)
@@ -1178,8 +1168,6 @@ generic_reader_c::~generic_reader_c() {
 
   for (i = 0; i < m_reader_packetizers.size(); i++)
     delete m_reader_packetizers[i];
-
-  delete m_chapters;
 }
 
 void
@@ -1202,7 +1190,7 @@ generic_reader_c::demuxing_requested(char type,
                                 : 'T' == type ? &m_ti.m_track_tags
                                 :               nullptr;
 
-  if (nullptr == tracks)
+  if (!tracks)
     mxerror(boost::format(Y("pr_generic.cpp/generic_reader_c::demuxing_requested(): Invalid track type %1%.")) % type);
 
   return tracks->selected(id);
@@ -1489,6 +1477,15 @@ generic_reader_c::get_progress() {
   return 100 * m_in->getFilePointer() / m_size;
 }
 
+mm_multi_file_io_c *
+generic_reader_c::get_underlying_input_as_multi_file_io()
+  const {
+  mm_io_c *actual_in = m_in.get();
+  while (dynamic_cast<mm_proxy_io_c *>(actual_in))
+    actual_in = static_cast<mm_proxy_io_c *>(actual_in)->get_proxied();
+  return dynamic_cast<mm_multi_file_io_c *>(actual_in);
+}
+
 //
 //--------------------------------------------------------------------
 
@@ -1510,7 +1507,6 @@ track_info_c::track_info_c()
   , m_default_track(boost::logic::indeterminate)
   , m_forced_track(boost::logic::indeterminate)
   , m_enabled_track(boost::logic::indeterminate)
-  , m_tags(nullptr)
   , m_compression(COMPRESSION_UNSPECIFIED)
   , m_pixel_cropping_source(PARAMETER_SOURCE_NONE)
   , m_stereo_mode(stereo_mode_c::unspecified)
@@ -1533,7 +1529,6 @@ track_info_c::free_contents() {
     return;
 
   safefree(m_private_data);
-  delete m_tags;
 
   m_initialized = false;
 }
@@ -1590,7 +1585,7 @@ track_info_c::operator =(const track_info_c &src) {
 
   m_all_tags                   = src.m_all_tags;
   m_tags_file_name             = src.m_tags_file_name;
-  m_tags                       = nullptr != src.m_tags ? static_cast<KaxTags *>(src.m_tags->Clone()) : nullptr;
+  m_tags                       = src.m_tags ? kax_tags_cptr{ static_cast<KaxTags *>(src.m_tags->Clone()) } : kax_tags_cptr{};
 
   m_all_aac_is_sbr             = src.m_all_aac_is_sbr;
 
@@ -1658,4 +1653,3 @@ id_result_container_unsupported(const std::string &filename,
   } else
     mxerror(boost::format(Y("The file '%1%' is a non-supported file type (%2%).\n")) % filename % info);
 }
-
