@@ -26,13 +26,11 @@
 #include <matroska/KaxTracks.h>
 #include <matroska/KaxTags.h>
 
+#include "common/chapters/chapters.h"
 #include "common/compression.h"
-#include "common/error.h"
-#include "common/memory.h"
-#include "common/mm_io.h"
-#include "common/smart_pointers.h"
 #include "common/stereo_mode.h"
 #include "common/strings/editing.h"
+#include "common/tags/tags.h"
 #include "merge/item_selector.h"
 #include "merge/packet.h"
 #include "merge/timecode_factory.h"
@@ -270,7 +268,7 @@ public:
 
   std::map<int64_t, std::string> m_all_tags;     // As given on the command line
   std::string m_tags_file_name;        // For this very track
-  KaxTags *m_tags;                // For this very track
+  kax_tags_cptr m_tags;                // For this very track
 
   std::map<int64_t, bool> m_all_aac_is_sbr; // For AAC+/HE-AAC/SBR
 
@@ -338,6 +336,8 @@ public:
 #define show_packetizer_info(track_id, packetizer) \
   mxinfo_tid(m_ti.m_fname, track_id, boost::format(Y("Using the output module for the format '%1%'.\n")) % packetizer->get_format_name());
 
+class mm_multi_file_io_c;
+
 class generic_reader_c {
 public:
   track_info_c m_ti;
@@ -348,7 +348,7 @@ public:
   generic_packetizer_c *m_ptzr_first_packet;
   std::vector<int64_t> m_requested_track_ids, m_available_track_ids, m_used_track_ids;
   int64_t m_max_timecode_seen;
-  KaxChapters *m_chapters;
+  kax_chapters_cptr m_chapters;
   bool m_appending;
   int m_num_video_tracks, m_num_audio_tracks, m_num_subtitle_tracks;
 
@@ -415,6 +415,7 @@ protected:
 
   virtual std::string id_escape_string(const std::string &s);
 
+  virtual mm_multi_file_io_c *get_underlying_input_as_multi_file_io() const;
 };
 
 void id_result_container_unsupported(const std::string &filename, const std::string &info);
@@ -466,6 +467,13 @@ enum connection_result_e {
     error_message = (boost::format(Y("The CodecID of the two tracks is different: %1% and %2%")) % (a) % (b)).str(); \
     return CAN_CONNECT_NO_PARAMETERS;                                                                                \
   }
+#define connect_check_codec_private(b)                                                                                                                                \
+  if (   (!!this->m_ti.m_private_data != !!b->m_ti.m_private_data)                                                                                                    \
+      || (  this->m_ti.m_private_size !=   b->m_ti.m_private_size)                                                                                                    \
+      || (  this->m_ti.m_private_data &&   memcmp(this->m_ti.m_private_data, b->m_ti.m_private_data, this->m_ti.m_private_size))) {                                   \
+    error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % this->m_ti.m_private_size % b->m_ti.m_private_size).str(); \
+    return CAN_CONNECT_MAYBE_CODECPRIVATE;                                                                                                                            \
+  }
 
 typedef std::deque<packet_cptr>::iterator packet_cptr_di;
 
