@@ -15,7 +15,7 @@
 // * wxStaticText is not wrapping on Windows.
 // * Add "recent files" to the file menu.
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/dnd.h>
@@ -43,7 +43,10 @@
 #include "mmg/header_editor/unsigned_integer_value_page.h"
 #include "mmg/mmg_dialog.h"
 #include "mmg/mmg.h"
-#include "share/icons/32x32/mkvmergeGUI.xpm"
+
+#if !defined(SYS_WINDOWS)
+# include "share/icons/64x64/mkvmergeGUI.h"
+#endif
 
 class header_editor_drop_target_c: public wxFileDropTarget {
 private:
@@ -124,7 +127,7 @@ header_editor_frame_c::header_editor_frame_c(wxWindow *parent)
 
   m_status_bar_timer.SetOwner(this, ID_T_HE_STATUS_BAR);
 
-  SetIcon(wxIcon(mkvmergeGUI_xpm));
+  SetIcon(wx_get_png_or_icon(mkvmergeGUI));
   SetDropTarget(new header_editor_drop_target_c(this));
 
   set_status_bar(Z("Header editor ready."));
@@ -164,7 +167,7 @@ header_editor_frame_c::translate_ui() {
 
 void
 header_editor_frame_c::set_window_title() {
-  if (!m_analyzer.is_set())
+  if (!m_analyzer)
     SetTitle(Z("Header editor"));
   else
     SetTitle(wxString::Format(Z("Header editor: %s"), m_file_name.GetFullName().c_str()));
@@ -245,14 +248,14 @@ header_editor_frame_c::open_file(wxFileName file_name) {
     return false;
   }
 
-  m_e_segment_info.clear();
-  m_e_tracks.clear();
+  m_e_segment_info.reset();
+  m_e_tracks.reset();
 
   m_analyzer = wx_kax_analyzer_cptr(new wx_kax_analyzer_c(this, wxMB(file_name.GetFullPath())));
 
   if (!m_analyzer->process(kax_analyzer_c::parse_mode_fast)) {
     wxMessageBox(Z("This file could not be opened or parsed."), Z("File parsing failed"), wxOK | wxCENTER | wxICON_ERROR);
-    m_analyzer.clear();
+    m_analyzer.reset();
 
     return false;
   }
@@ -279,13 +282,13 @@ header_editor_frame_c::open_file(wxFileName file_name) {
 
   for (auto &data : m_analyzer->m_data)
     if (data->m_id == KaxInfo::ClassInfos.GlobalId) {
-      handle_segment_info(data.get_object());
+      handle_segment_info(data.get());
       break;
     }
 
   for (auto &data : m_analyzer->m_data)
     if (data->m_id == KaxTracks::ClassInfos.GlobalId) {
-      handle_tracks(data.get_object());
+      handle_tracks(data.get());
       break;
     }
 
@@ -310,7 +313,7 @@ header_editor_frame_c::handle_segment_info(kax_analyzer_data_c *data) {
   he_top_level_page_c *page = new he_top_level_page_c(this, YT("Segment information"), m_e_segment_info);
   page->init();
 
-  KaxInfo *info    = static_cast<KaxInfo *>(m_e_segment_info.get_object());
+  KaxInfo *info    = static_cast<KaxInfo *>(m_e_segment_info.get());
   he_value_page_c *child_page;
 
   child_page = new he_string_value_page_c(this, page, info, KaxTitle::ClassInfos, YT("Title"), YT("The title for the whole movie."));
@@ -348,21 +351,21 @@ header_editor_frame_c::handle_tracks(kax_analyzer_data_c *data) {
 
   he_track_type_page_c *last_track_page = nullptr;
 
-  KaxTracks *kax_tracks = static_cast<KaxTracks *>(m_e_tracks.get_object());
+  KaxTracks *kax_tracks = static_cast<KaxTracks *>(m_e_tracks.get());
   int track_type        = -1;
   size_t i;
   for (i = 0; kax_tracks->ListSize() > i; ++i) {
     KaxTrackEntry *k_track_entry = dynamic_cast<KaxTrackEntry *>((*kax_tracks)[i]);
-    if (nullptr == k_track_entry)
+    if (!k_track_entry)
       continue;
 
-    KaxTrackType *k_track_type = dynamic_cast<KaxTrackType *>(FINDFIRST(k_track_entry, KaxTrackType));
-    if (nullptr == k_track_type)
+    KaxTrackType *k_track_type = dynamic_cast<KaxTrackType *>(FindChild<KaxTrackType>(k_track_entry));
+    if (!k_track_type)
       continue;
 
     unsigned int track_number = 0;
-    KaxTrackNumber *k_track_number = dynamic_cast<KaxTrackNumber *>(FINDFIRST(k_track_entry, KaxTrackNumber));
-    if (nullptr != k_track_number)
+    KaxTrackNumber *k_track_number = dynamic_cast<KaxTrackNumber *>(FindChild<KaxTrackNumber>(k_track_entry));
+    if (k_track_number)
       track_number = uint64(*k_track_number);
 
     wxString title;
@@ -504,7 +507,7 @@ header_editor_frame_c::handle_tracks(kax_analyzer_data_c *data) {
     // m_tc_tree->ExpandAllChildren(page->m_page_id);
   }
 
-  if (nullptr != last_track_page)
+  if (last_track_page)
     last_track_page->set_is_last_track(true);
 }
 
@@ -570,7 +573,7 @@ header_editor_frame_c::on_file_close(wxCommandEvent &) {
 
   clear_pages();
 
-  m_analyzer.clear();
+  m_analyzer.reset();
 
   m_file_name.Clear();
 
@@ -708,7 +711,7 @@ he_page_base_c *
 header_editor_frame_c::find_page_for_item(wxTreeItemId id) {
   for (auto &page : m_pages)
     if (page->m_page_id == id)
-      return page.get_object();
+      return page.get();
 
   return nullptr;
 }
