@@ -14,7 +14,7 @@
 #ifndef __HEADER_EDITOR_FRAME_H
 #define __HEADER_EDITOR_FRAME_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/filename.h>
 #include <wx/frame.h>
@@ -73,7 +73,7 @@ public:
 
   wx_kax_analyzer_cptr m_analyzer;
 
-  counted_ptr<EbmlElement> m_e_segment_info, m_e_tracks;
+  std::shared_ptr<EbmlElement> m_e_segment_info, m_e_tracks;
 
   bool m_ignore_tree_selection_changes;
 
