@@ -11,7 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 
@@ -41,7 +41,7 @@ void
 he_language_value_page_c::translate_ui() {
   he_value_page_c::translate_ui();
 
-  if (nullptr == m_cb_language)
+  if (!m_cb_language)
     return;
 
   size_t i;
@@ -53,7 +53,7 @@ he_language_value_page_c::translate_ui() {
 
 wxControl *
 he_language_value_page_c::create_input_control() {
-  m_original_value = nullptr != m_element ? wxU(dynamic_cast<EbmlString *>(m_element)) : wxU("eng");
+  m_original_value = m_element ? wxU(dynamic_cast<EbmlString *>(m_element)) : wxU("eng");
   m_cb_language    = new wxMTX_COMBOBOX_TYPE(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, nullptr, wxCB_DROPDOWN | wxCB_READONLY);
 
   size_t i;
