@@ -14,9 +14,7 @@
 #ifndef __HE_PAGE_BASE_H
 #define __HE_PAGE_BASE_H
 
-#include "common/os.h"
-
-#include <vector>
+#include "common/common_pch.h"
 
 #include <wx/panel.h>
 #include <wx/treebase.h>
@@ -50,6 +48,6 @@ public:
   virtual void translate_ui() = 0;
   wxString get_title();
 };
-typedef counted_ptr<he_page_base_c> he_page_base_cptr;
+typedef std::shared_ptr<he_page_base_c> he_page_base_cptr;
 
 #endif // __HE_PAGE_BASE_H
