@@ -11,7 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/textctrl.h>
 
@@ -37,7 +37,7 @@ he_string_value_page_c::~he_string_value_page_c() {
 
 wxControl *
 he_string_value_page_c::create_input_control() {
-  if (nullptr != m_element)
+  if (m_element)
     m_original_value = UTFstring(*static_cast<EbmlUnicodeString *>(m_element)).c_str();
 
   m_tc_text = new wxTextCtrl(this, wxID_ANY, m_original_value);
