@@ -11,7 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/dialog.h>
 #include <wx/sizer.h>
@@ -46,7 +46,7 @@ he_top_level_page_c::do_modifications() {
   he_page_base_c::do_modifications();
 
   if (is_id(m_l1_element, KaxInfo))
-    fix_mandatory_segmentinfo_elements(m_l1_element.get_object());
+    fix_mandatory_segmentinfo_elements(m_l1_element.get());
 
   m_l1_element->UpdateSize(true);
 }
