@@ -11,7 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/datetime.h>
@@ -268,6 +268,11 @@ wxString
 format_tooltip(const wxString &s) {
   return format_paragraph(static_cast<const wchar_t *>(s.wc_str()), 0, L"", L"", 80);
 }
+#else
+wxString
+format_tooltip(const wxString &s) {
+  return s;
+}
 #endif
 
 wxString
@@ -335,36 +340,6 @@ default_track_checked(char type) {
   return -1;
 }
 
-void
-set_combobox_selection(wxComboBox *cb,
-                       const wxString wanted) {
-  int i, count;
-
-  cb->SetValue(wanted);
-  count = cb->GetCount();
-  for (i = 0; count > i; ++i)
-    if (cb->GetString(i) == wanted) {
-      cb->SetSelection(i);
-      break;
-    }
-}
-
-#if defined(USE_WXBITMAPCOMBOBOX)
-void
-set_combobox_selection(wxBitmapComboBox *cb,
-                       const wxString wanted) {
-  int i, count;
-
-  cb->SetValue(wanted);
-  count = cb->GetCount();
-  for (i = 0; count > i; ++i)
-    if (cb->GetString(i) == wanted) {
-      cb->SetSelection(i);
-      break;
-    }
-}
-#endif  // USE_WXBITMAPCOMBOBOX
-
 void
 wxdie(const wxString &errmsg) {
   wxMessageBox(errmsg, wxT("A serious error has occured"),
@@ -378,7 +353,7 @@ set_menu_item_strings(wxFrame *frame,
                       const wxString &title,
                       const wxString &help_text) {
   wxMenuItem *item = frame->GetMenuBar()->FindItem(id);
-  if (nullptr != item) {
+  if (item) {
 #if defined(HAVE_WXMENUITEM_SETITEMLABEL)
     item->SetItemLabel(title);
 #else
