@@ -11,14 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
-
-#include <errno.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#include <wx/wxprec.h>
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/clipbrd.h>
@@ -47,7 +40,7 @@
 
 job_run_dialog::job_run_dialog(wxWindow *,
                                std::vector<int> &n_jobs_to_start)
-  : wxDialog(nullptr, -1, Z("mkvmerge is running"), wxDefaultPosition, wxSize(400, 700), wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER | wxMINIMIZE_BOX | wxMAXIMIZE_BOX)
+  : wxDialog(nullptr, -1, Z("mkvmerge is running"), wxDefaultPosition, wxSize(700, 700), wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER | wxMINIMIZE_BOX | wxMAXIMIZE_BOX)
   , t_update(new wxTimer(this, 1))
   , out(nullptr)
   , process(nullptr)
@@ -151,7 +144,7 @@ job_run_dialog::start_next_job() {
     st_remaining_time_total->SetLabel(wxT("---"));
 
 #if defined(SYS_WINDOWS)
-    if (nullptr != m_taskbar_progress)
+    if (m_taskbar_progress)
       m_taskbar_progress->set_state(TBPF_NOPROGRESS);
 #endif
 
@@ -163,7 +156,7 @@ job_run_dialog::start_next_job() {
   st_remaining_time->SetLabel(Z("is being estimated"));
 
 #if defined(SYS_WINDOWS)
-  if (nullptr != m_taskbar_progress) {
+  if (m_taskbar_progress) {
     m_taskbar_progress->set_state(TBPF_NORMAL);
     m_taskbar_progress->set_value(current_job * 100, jobs_to_start.size() * 100);
   }
@@ -185,7 +178,7 @@ job_run_dialog::start_next_job() {
                           opt_file_name.c_str(), errno, wxUCS(strerror(errno)));
     jobs[ndx].status = JOBS_FAILED;
     mdlg->save_job_queue();
-    if (nullptr != process) {
+    if (process) {
       delete process;
       process = nullptr;
     }
@@ -232,7 +225,7 @@ job_run_dialog::start_next_job() {
 
 void
 job_run_dialog::process_input() {
-  if (nullptr == process)
+  if (!process)
     return;
 
   while (process->IsInputAvailable()) {
@@ -277,7 +270,7 @@ job_run_dialog::set_progress_value(long value) {
   g_jobs->SetValue(m_progress);
 
 #if defined(SYS_WINDOWS)
-  if (nullptr != m_taskbar_progress)
+  if (m_taskbar_progress)
     m_taskbar_progress->set_value(current_job * 100 + value, jobs_to_start.size() * 100);
 #endif
 }
@@ -324,7 +317,7 @@ job_run_dialog::on_abort(wxCommandEvent &) {
   abort = true;
 #if defined(SYS_WINDOWS)
   wxKill(pid, wxSIGKILL);
-  if (nullptr != m_taskbar_progress)
+  if (m_taskbar_progress)
     m_taskbar_progress->set_state(TBPF_ERROR);
 #else
   wxKill(pid, wxSIGTERM);
@@ -335,28 +328,40 @@ void
 job_run_dialog::on_end_process(wxProcessEvent &evt) {
   process_input();
 
-  int ndx       = jobs_to_start[current_job];
-  int exit_code = evt.GetExitCode();
+  int ndx         = jobs_to_start[current_job];
+  int exit_code   = evt.GetExitCode();
+  bool remove_job;
   wxString status;
 
   if (abort) {
     jobs[ndx].status = JOBS_ABORTED;
     status           = Z("aborted");
+    remove_job       = false;
   } else if (0 == exit_code) {
     jobs[ndx].status = JOBS_DONE;
     status           = Z("completed OK");
+    remove_job       = CJAR_NEVER != mdlg->options.clear_job_after_run_mode;
   } else if (1 == exit_code) {
     jobs[ndx].status = JOBS_DONE_WARNINGS;
     status           = Z("completed with warnings");
+    remove_job       = (CJAR_ALWAYS == mdlg->options.clear_job_after_run_mode) || (CJAR_WARNINGS == mdlg->options.clear_job_after_run_mode);
   } else {
     jobs[ndx].status = JOBS_FAILED;
     status           = Z("failed");
+    remove_job        = CJAR_ALWAYS == mdlg->options.clear_job_after_run_mode;
   }
 
   jobs[ndx].finished_on = wxGetUTCTime();
 
   add_to_log(wxString::Format(Z("Finished job ID %d on %s: status '%s'"), jobs[ndx].id, format_date_time(jobs[ndx].finished_on).c_str(), status.c_str()));
 
+  if (remove_job) {
+    jobs.erase(jobs.begin() + ndx, jobs.begin() + ndx + 1);
+    for (auto idx = 0u; jobs_to_start.size() > idx; ++idx)
+      if (jobs_to_start[idx] >= ndx)
+        jobs_to_start[idx]--;
+  }
+
   mdlg->save_job_queue();
   delete process;
   process = nullptr;
@@ -402,6 +407,8 @@ job_log_dialog::job_log_dialog(wxWindow *parent,
   siz_all->SetSizeHints(this);
   SetSizer(siz_all);
 
+  SetSize(wxSize(900, 500));
+
   ShowModal();
 }
 
@@ -511,6 +518,8 @@ job_dialog::job_dialog(wxWindow *parent):
   siz_all->SetSizeHints(this);
   SetSizer(siz_all);
 
+  SetSize(wxSize(800, 500));
+
   enable_buttons(false);
 
   b_start->Enable(!jobs.empty());
