@@ -14,11 +14,9 @@
 #ifndef __MMG_H
 #define __MMG_H
 
-#include <map>
-#include <vector>
-
-#include "common/os.h"
+#include "common/common_pch.h"
 
+#include <wx/wx.h>
 #include <wx/app.h>
 #include <wx/combobox.h>
 #include <wx/config.h>
@@ -29,7 +27,6 @@
 #include <ebml/EbmlUnicodeString.h>
 
 #include "common/iso639.h"
-#include "common/smart_pointers.h"
 #include "common/wx.h"
 #include "mmg/translation_table.h"
 
@@ -133,7 +130,7 @@ struct mmg_track_t {
 
   bool is_webm_compatible();
 };
-typedef counted_ptr<mmg_track_t> mmg_track_cptr;
+typedef std::shared_ptr<mmg_track_t> mmg_track_cptr;
 
 struct mmg_file_t;
 
@@ -151,7 +148,7 @@ struct mmg_attached_file_t {
   {
   }
 };
-typedef counted_ptr<mmg_attached_file_t> mmg_attached_file_cptr;
+typedef std::shared_ptr<mmg_attached_file_t> mmg_attached_file_cptr;
 
 struct mmg_file_t {
   wxString file_name, title;
@@ -169,7 +166,7 @@ struct mmg_file_t {
   {
   }
 };
-typedef counted_ptr<mmg_file_t> mmg_file_cptr;
+typedef std::shared_ptr<mmg_file_t> mmg_file_cptr;
 
 struct mmg_attachment_t {
   wxString file_name, stored_name, description, mime_type;
@@ -180,19 +177,27 @@ struct mmg_attachment_t {
   {
   }
 };
-typedef counted_ptr<mmg_attachment_t> mmg_attachment_cptr;
+typedef std::shared_ptr<mmg_attachment_t> mmg_attachment_cptr;
 
-typedef enum {
+enum output_directory_mode_e {
   ODM_FROM_FIRST_INPUT_FILE = 0,
   ODM_PREVIOUS              = 1,
   ODM_FIXED                 = 2,
-} output_directory_mode_e;
+};
+
+enum clear_job_after_run_mode_e {
+  CJAR_NEVER      = 0,
+  CJAR_SUCCESSFULL = 1,
+  CJAR_WARNINGS    = 2,
+  CJAR_ALWAYS      = 3,
+};
 
 struct mmg_options_t {
   wxString mkvmerge;
   wxString output_directory;
   bool autoset_output_filename;
   output_directory_mode_e output_directory_mode;
+  clear_job_after_run_mode_e clear_job_after_run_mode;
   bool ask_before_overwriting;
   bool on_top;
   bool filenew_after_add_to_jobqueue;
@@ -208,6 +213,7 @@ struct mmg_options_t {
   mmg_options_t()
     : autoset_output_filename(false)
     , output_directory_mode(ODM_FROM_FIRST_INPUT_FILE)
+    , clear_job_after_run_mode(CJAR_NEVER)
     , ask_before_overwriting(false)
     , on_top(false)
     , filenew_after_add_to_jobqueue(false)
@@ -260,10 +266,25 @@ wxString create_append_mapping();
 
 int default_track_checked(char type);
 
-void set_combobox_selection(wxComboBox *cb, const wxString wanted);
-#if defined(USE_WXBITMAPCOMBOBOX)
-void set_combobox_selection(wxBitmapComboBox *cb, const wxString wanted);
-#endif  // USE_WXBITMAPCOMBOBOX
+template<class T> void
+set_combobox_selection(T *cb,
+                       wxString const &wanted) {
+  cb->SetValue(wanted);
+  auto count = cb->GetCount();
+  for (auto idx = 0u; count > idx; ++idx)
+    if (cb->GetString(idx) == wanted) {
+      cb->SetSelection(idx);
+      return;
+    }
+}
+
+template<class T> void
+set_combobox_selection(T *cb,
+                       int selection) {
+  cb->SetSelection(selection);
+  cb->SetValue(cb->GetString(selection));
+}
+
 void set_menu_item_strings(wxFrame *frame, int id, const wxString &title, const wxString &help_text);
 void set_menu_label(wxFrame *frame, int pos, const wxString &label);
 
@@ -271,11 +292,12 @@ void wxdie(const wxString &errmsg);
 
 #if defined(SYS_WINDOWS)
 #define TIP(s) format_tooltip(Z(s))
-wxString format_tooltip(const wxString &s);
 #else
 #define TIP(s) Z(s)
 #endif
 
+wxString format_tooltip(const wxString &s);
+
 class mmg_app: public wxApp {
 public:
   std::string m_ui_locale;
