@@ -11,9 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include <algorithm>
 #include <wx/wx.h>
 #include <wx/aboutdlg.h>
 #include <wx/clipbrd.h>
@@ -29,7 +28,6 @@
 #include <wx/statline.h>
 #include <wx/strconv.h>
 
-#include "common/common_pch.h"
 #include "common/chapters/chapters.h"
 #include "common/command_line.h"
 #include "common/common_pch.h"
@@ -42,7 +40,6 @@
 #include "common/translation.h"
 #include "common/version.h"
 #include "common/wx.h"
-#include "common/xml/element_mapping.h"
 #include "merge/mkvmerge.h"
 #include "mmg/cli_options_dlg.h"
 #include "mmg/header_editor/frame.h"
@@ -59,7 +56,10 @@
 #if defined(HAVE_CURL_EASY_H)
 # include "mmg/update_checker.h"
 #endif  // defined(HAVE_CURL_EASY_H)
-#include "share/icons/32x32/mkvmergeGUI.xpm"
+
+#if !defined(SYS_WINDOWS)
+# include "share/icons/64x64/mkvmergeGUI.h"
+#endif
 
 mmg_dialog *mdlg;
 wxString last_open_dir;
@@ -179,7 +179,7 @@ mmg_dialog::mmg_dialog()
 
   load_job_queue();
 
-  SetIcon(wxIcon(mkvmergeGUI_xpm));
+  SetIcon(wx_get_png_or_icon(mkvmergeGUI));
 
   help = nullptr;
 
@@ -629,7 +629,9 @@ mmg_dialog::on_run(wxCommandEvent &) {
 
   set_on_top(false);
   muxing_in_progress = true;
-  new mux_dialog(this);
+
+  mux_dialog dlg{this};
+  dlg.run();
 }
 
 void
@@ -650,7 +652,7 @@ mmg_dialog::on_help(wxCommandEvent &) {
 
 void
 mmg_dialog::display_help(int id) {
-  if (help == nullptr) {
+  if (!help) {
     wxDirDialog dlg(this, Z("Choose the location of the mkvmerge GUI help files"));
     std::vector<wxString> potential_help_paths;
 
@@ -1080,9 +1082,13 @@ mmg_dialog::update_command_line() {
       clargs.Add(wxT("--no-chapters"));
 
     if (f->appending)
-      clargs.Add(wxString(wxT("+")) + f->file_name);
-    else
-      clargs.Add(f->file_name);
+      clargs.Add(wxT("+"));
+
+    clargs.Add(wxT("("));
+    clargs.Add(f->file_name);
+    for (auto &other_file_name : f->other_files)
+      clargs.Add(other_file_name.GetFullPath());
+    clargs.Add(wxT(")"));
   }
 
   wxString track_order = create_track_order(false);
@@ -1126,8 +1132,10 @@ mmg_dialog::update_command_line() {
       clargs.Add(wxT("size:") + global_page->cob_split_by_size->GetValue());
     else if (global_page->rb_split_by_time->GetValue())
       clargs.Add(wxT("duration:") + global_page->cob_split_by_time->GetValue());
-    else
+    else if (global_page->rb_split_after_timecodes->GetValue())
       clargs.Add(wxT("timecodes:") + global_page->tc_split_after_timecodes->GetValue());
+    else if (global_page->rb_split_by_parts->GetValue())
+      clargs.Add(wxT("parts:") + global_page->tc_split_by_parts->GetValue());
 
     if (global_page->tc_split_max_files->GetValue().Length() > 0) {
       clargs.Add(wxT("--split-max-files"));
@@ -1224,7 +1232,7 @@ mmg_dialog::update_file_menu() {
 
   for (i = ID_M_FILE_LOADLAST1; i <= ID_M_FILE_LOADLAST4; i++) {
     mi = file_menu->FindItem(i);
-    if (mi != nullptr)
+    if (mi)
       file_menu->Destroy(mi);
   }
 
@@ -1246,7 +1254,7 @@ mmg_dialog::update_chapter_menu() {
 
   for (i = ID_M_CHAPTERS_LOADLAST1; i <= ID_M_CHAPTERS_LOADLAST4; i++) {
     mi = chapter_menu->FindItem(i);
-    if (mi != nullptr)
+    if (mi)
       chapter_menu->Destroy(mi);
   }
 
@@ -1570,6 +1578,7 @@ mmg_dialog::save_preferences() {
   cfg->Write(wxU("process_priority"),                options.priority);
   cfg->Write(wxU("autoset_output_filename"),         options.autoset_output_filename);
   cfg->Write(wxU("output_directory_mode"),           (long)options.output_directory_mode);
+  cfg->Write(wxU("clear_job_after_run_mode"),        static_cast<long>(options.clear_job_after_run_mode));
   cfg->Write(wxU("output_directory"),                options.output_directory);
   cfg->Write(wxU("ask_before_overwriting"),          options.ask_before_overwriting);
   cfg->Write(wxU("filenew_after_add_to_jobqueue"),   options.filenew_after_add_to_jobqueue);
@@ -1590,6 +1599,7 @@ mmg_dialog::load_preferences() {
   wxConfigBase *cfg = wxConfigBase::Get();
   wxString s;
   int window_pos_x, window_pos_y;
+  long value_long;
 
   cfg->SetPath(wxT("/GUI"));
 
@@ -1605,7 +1615,10 @@ mmg_dialog::load_preferences() {
   cfg->Read(wxU("mkvmerge_executable"),           &options.mkvmerge, wxU("mkvmerge"));
   cfg->Read(wxU("process_priority"),              &options.priority, wxU("normal"));
   cfg->Read(wxU("autoset_output_filename"),       &options.autoset_output_filename, true);
-  cfg->Read(wxU("output_directory_mode"),         (long *)&options.output_directory_mode, ODM_FROM_FIRST_INPUT_FILE);
+  cfg->Read(wxU("output_directory_mode"),         &value_long, ODM_FROM_FIRST_INPUT_FILE);
+  options.output_directory_mode = static_cast<output_directory_mode_e>(value_long);
+  cfg->Read(wxU("clear_job_after_run_mode"),      &value_long, CJAR_NEVER);
+  options.clear_job_after_run_mode = static_cast<clear_job_after_run_mode_e>(value_long);
   cfg->Read(wxU("output_directory"),              &options.output_directory, wxU(""));
   cfg->Read(wxU("ask_before_overwriting"),        &options.ask_before_overwriting, true);
   cfg->Read(wxU("filenew_after_add_to_jobqueue"), &options.filenew_after_add_to_jobqueue, false);
@@ -1727,8 +1740,8 @@ mmg_dialog::on_update_check_state_changed(wxCommandEvent &evt) {
 
   if (UPDATE_CHECK_START == state) {
     if (m_interactive_update_check) {
-      if (nullptr != m_update_check_dlg) {
-        wxLogMessage(wxT("m_update_check_dlg != nullptr on start"));
+      if (m_update_check_dlg) {
+        wxLogMessage(wxT("m_update_check_dlg on start"));
         delete m_update_check_dlg;
       }
 
@@ -1760,7 +1773,7 @@ mmg_dialog::on_update_check_state_changed(wxCommandEvent &evt) {
     }
 
     if (show) {
-      if (nullptr == m_update_check_dlg) {
+      if (!m_update_check_dlg) {
         m_update_check_dlg = new update_check_dlg_c(this);
         m_update_check_dlg->Show();
       }
@@ -1768,7 +1781,7 @@ mmg_dialog::on_update_check_state_changed(wxCommandEvent &evt) {
       m_update_check_dlg->update_status(  UPDATE_CHECK_DONE_NO_NEW_RELEASE == state ? Z("You are already running the latest version.")
                                         : UPDATE_CHECK_DONE_NEW_RELEASE    == state ? Z("There is a new version available online.")
                                         :                                             Z("There was an error querying the update status."));
-      m_update_check_dlg->update_info(m_release_version);
+      m_update_check_dlg->update_info(m_release_version, m_releases_info);
 
     } else
       m_checking_for_updates = false;
@@ -1796,17 +1809,20 @@ mmg_dialog::check_for_updates(bool interactive) {
 }
 
 void
-mmg_dialog::set_release_version(mtx_release_version_t &release_version) {
+mmg_dialog::set_release_version(mtx_release_version_t const &release_version) {
   wxMutexLocker locker(m_update_check_mutex);
   m_release_version = release_version;
 }
 
+void
+mmg_dialog::set_releases_info(mtx::xml::document_cptr const &releases_info) {
+  wxMutexLocker locker(m_update_check_mutex);
+  m_releases_info = releases_info;
+}
+
 wxString
 mmg_dialog::version_key_for_config() {
-  wxString version = wxU(m_release_version.latest_source.to_string());
-  wxRegEx re(wxT("[^0-9]"));
-  re.Replace(&version, wxT("_"));
-  return wxString::Format(wxT("version_%s"), version.c_str());
+  return wxU(boost::format("version_%1%") % boost::regex_replace(m_release_version.latest_source.to_string(), boost::regex("[^\\d]+", boost::regex::perl), "_"));
 }
 #endif  // defined(HAVE_CURL_EASY_H)
 
