@@ -11,11 +11,10 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 
-#include "common/common_pch.h"
 #include "common/extern_data.h"
 #include "common/fs_sys_helpers.h"
 #include "common/wx.h"
@@ -36,10 +35,10 @@ mmg_options_t::init_popular_languages(const wxString &list) {
 
   if (popular_languages.IsEmpty()) {
     std::map<std::string, bool> codes_found;
-    for (i = 0; iso639_languages[i].english_name != nullptr; i++)
-      if (!codes_found[std::string(iso639_languages[i].iso639_2_code)] && is_popular_language_code(iso639_languages[i].iso639_2_code)) {
-        popular_languages.Add(wxU(iso639_languages[i].iso639_2_code));
-        codes_found[std::string(iso639_languages[i].iso639_2_code)] = true;
+    for (auto lang : iso639_languages)
+      if (!codes_found[lang.iso639_2_code] && is_popular_language_code(lang.iso639_2_code)) {
+        popular_languages.Add(wxU(lang.iso639_2_code));
+        codes_found[lang.iso639_2_code] = true;
       }
   }
 
