@@ -11,14 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
-
-#include <errno.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#include <wx/wxprec.h>
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/clipbrd.h>
@@ -30,11 +23,7 @@
 #include <wx/statusbr.h>
 #include <wx/statline.h>
 
-#if defined(SYS_WINDOWS)
-#include <windows.h>
-#endif
-
-#include "common/common_pch.h"
+#include "common/at_scope_exit.h"
 #include "common/fs_sys_helpers.h"
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
@@ -42,36 +31,21 @@
 #include "mmg/mmg_dialog.h"
 #include "mmg/mux_dialog.h"
 
-mux_dialog::mux_dialog(wxWindow *parent):
-  wxDialog(parent, -1, Z("mkvmerge is running"), wxDefaultPosition,
-#ifdef SYS_WINDOWS
-           wxSize(700, 560),
-#else
-           wxSize(700, 520),
-#endif
-           wxDEFAULT_FRAME_STYLE)
+mux_dialog::mux_dialog(wxWindow *parent)
+  : wxDialog(parent, -1, Z("mkvmerge is running"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_FRAME_STYLE)
+  , m_thread{nullptr}
+  , m_process{nullptr}
+  , m_pid{0}
 #if defined(SYS_WINDOWS)
-  , pid(0)
   , m_taskbar_progress(nullptr)
-  , m_abort_button_changed(false)
 #endif  // SYS_WINDOWS
+  , m_abort_button_changed(false)
   , m_exit_code(0)
   , m_progress(0)
 {
-  char c;
-  std::string arg_utf8, line;
-  long value;
-  wxString wx_line, tmp;
-  wxInputStream *out;
-  wxFile *opt_file;
-  uint32_t i;
-  wxArrayString *arg_list;
   wxBoxSizer *siz_all, *siz_buttons, *siz_line;
   wxStaticBoxSizer *siz_status, *siz_output;
 
-  m_window_disabler = new wxWindowDisabler(this);
-
-  c = 0;
   siz_status = new wxStaticBoxSizer(new wxStaticBox(this, -1, Z("Status and progress")), wxVERTICAL);
   st_label = new wxStaticText(this, -1, wxEmptyString);
   st_remaining_time_label = new wxStaticText(this, -1, Z("Remaining time:"));
@@ -88,13 +62,13 @@ mux_dialog::mux_dialog(wxWindow *parent):
 
   siz_output = new wxStaticBoxSizer(new wxStaticBox(this, -1, Z("Output")), wxVERTICAL);
   siz_output->Add(new wxStaticText(this, -1, Z("mkvmerge output:")), 0, wxALIGN_LEFT | wxALL, 5);
-  tc_output = new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY | wxTE_BESTWRAP | wxTE_MULTILINE);
+  tc_output = new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxSize(-1, 100), wxTE_READONLY | wxTE_BESTWRAP | wxTE_MULTILINE);
   siz_output->Add(tc_output, 2, wxGROW | wxALL, 5);
   siz_output->Add(new wxStaticText(this, -1, Z("Warnings:")), 0, wxALIGN_LEFT | wxALL, 5);
-  tc_warnings = new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY | wxTE_BESTWRAP | wxTE_MULTILINE);
+  tc_warnings = new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxSize(-1, 50), wxTE_READONLY | wxTE_BESTWRAP | wxTE_MULTILINE);
   siz_output->Add(tc_warnings, 1, wxGROW | wxALL, 5);
   siz_output->Add(new wxStaticText(this, -1, Z("Errors:")), 0, wxALIGN_LEFT | wxALL, 5);
-  tc_errors = new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY | wxTE_BESTWRAP | wxTE_MULTILINE);
+  tc_errors = new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxSize(-1, 50), wxTE_READONLY | wxTE_BESTWRAP | wxTE_MULTILINE);
   siz_output->Add(tc_errors, 1, wxGROW | wxALL, 5);
 
   siz_buttons = new wxBoxSizer(wxHORIZONTAL);
@@ -114,35 +88,36 @@ mux_dialog::mux_dialog(wxWindow *parent):
   siz_all->Add(siz_status, 0, wxGROW | wxALL, 5);
   siz_all->Add(siz_output, 1, wxGROW | wxALL, 5);
   siz_all->Add(siz_buttons, 0, wxGROW | wxALL, 10);
-  SetSizer(siz_all);
 
-  update_window(Z("Muxing in progress."));
-  Show(true);
+  SetSizerAndFit(siz_all);
+  SetSize(wxSize(720, 520));
+}
 
-  process = new mux_process(this);
+void
+mux_dialog::run() {
+  auto &arg_list = static_cast<mmg_dialog *>(GetParent())->get_command_line_args();
 
   opt_file_name.Printf(wxT("%smmg-mkvmerge-options-%d-%d"), get_temp_dir().c_str(), (int)wxGetProcessId(), (int)wxGetUTCTime());
   try {
     const unsigned char utf8_bom[3] = {0xef, 0xbb, 0xbf};
-    opt_file = new wxFile(opt_file_name, wxFile::write);
-    opt_file->Write(utf8_bom, 3);
+    wxFile opt_file{opt_file_name, wxFile::write};
+    opt_file.Write(utf8_bom, 3);
+
+    for (size_t i = 1; i < arg_list.Count(); i++) {
+      if (arg_list[i].IsEmpty())
+        opt_file.Write(wxT("#EMPTY#"));
+      else {
+        auto arg_utf8 = escape(to_utf8(arg_list[i]));
+        opt_file.Write(arg_utf8.c_str(), arg_utf8.length());
+      }
+      opt_file.Write(wxT("\n"));
+    }
   } catch (...) {
     wxString error;
     error.Printf(Z("Could not create a temporary file for mkvmerge's command line option called '%s' (error code %d, %s)."), opt_file_name.c_str(), errno, wxUCS(strerror(errno)));
     wxMessageBox(error, Z("File creation failed"), wxOK | wxCENTER | wxICON_ERROR);
     throw 0;
   }
-  arg_list = &static_cast<mmg_dialog *>(parent)->get_command_line_args();
-  for (i = 1; i < arg_list->Count(); i++) {
-    if ((*arg_list)[i].Length() == 0)
-      opt_file->Write(wxT("#EMPTY#"));
-    else {
-      arg_utf8 = escape(wxMB((*arg_list)[i]));
-      opt_file->Write(arg_utf8.c_str(), arg_utf8.length());
-    }
-    opt_file->Write(wxT("\n"));
-  }
-  delete opt_file;
 
 #if defined(SYS_WINDOWS)
   if (get_windows_version() >= WINDOWS_VERSION_7) {
@@ -152,80 +127,48 @@ mux_dialog::mux_dialog(wxWindow *parent):
   }
 #endif  // SYS_WINDOWS
 
+  update_label(Z("Muxing in progress."));
+
   m_start_time                 = get_current_time_millis();
   m_next_remaining_time_update = m_start_time + 8000;
 
-  wxString command_line = wxString::Format(wxT("\"%s\" \"@%s\""), (*arg_list)[0].c_str(), opt_file_name.c_str());
-  pid = wxExecute(command_line, wxEXEC_ASYNC, process);
-  if (0 == pid) {
-    wxLogError(wxT("Execution of '%s' failed."), command_line.c_str());
-    done(2);
-    return;
+  m_process                    = new mux_process{this};
+  m_pid                        = wxExecute(wxString::Format(wxT("\"%s\" \"@%s\""), arg_list[0].c_str(), opt_file_name.c_str()), wxEXEC_ASYNC, m_process);
+
+  if (0 == m_pid) {
+    wxCommandEvent evt(mux_thread::event, mux_thread::process_terminated);
+    evt.SetInt(2);
+    wxPostEvent(this, evt);
+
+  } else {
+    m_thread = new mux_thread{this, m_process};
+    m_thread->Create();
+    m_thread->Run();
   }
-  out = process->GetInputStream();
 
-  line = "";
-  log = wxEmptyString;
-  while (1) {
-    while (app->Pending())
-      app->Dispatch();
-
-    if (!out->CanRead() && !out->Eof()) {
-      wxMilliSleep(5);
-      continue;
-    }
-
-    if (!out->Eof())
-      c = out->GetC();
-    else
-      c = '\n';
-
-    if ((c == '\n') || (c == '\r') || out->Eof()) {
-      wx_line = wxU(line);
-      log += wx_line;
-      if (c != '\r')
-        log += wxT("\n");
-      if (wx_line.Find(Z("Warning:")) == 0)
-        tc_warnings->AppendText(wx_line + wxT("\n"));
-      else if (wx_line.Find(Z("Error:")) == 0)
-        tc_errors->AppendText(wx_line + wxT("\n"));
-      else if (wx_line.Find(Z("Progress")) == 0) {
-        if (wx_line.Find(wxT("%")) != 0) {
-          wx_line.Remove(wx_line.Find(wxT("%")));
-          tmp = wx_line.AfterLast(wxT(' '));
-          tmp.ToLong(&value);
-          if ((value >= 0) && (value <= 100))
-            update_gauge(value);
-        }
-      } else if (wx_line.Length() > 0)
-        tc_output->AppendText(wx_line + wxT("\n"));
-      line = "";
-
-      update_remaining_time();
-
-    } else if ((unsigned char)c != 0xff)
-      line += c;
-
-    if (out->Eof())
-      break;
-  }
+  ShowModal();
 }
 
 mux_dialog::~mux_dialog() {
 #if defined(SYS_WINDOWS)
-  if (nullptr != m_taskbar_progress)
+  if (m_taskbar_progress)
     m_taskbar_progress->set_state(TBPF_NOPROGRESS);
   delete m_taskbar_progress;
 #endif  // SYS_WINDOWS
 
-  process->dlg = nullptr;
-  delete process;
   wxRemoveFile(opt_file_name);
+
+  if (m_process) {
+    wxCriticalSectionLocker locker{m_process->m_cs_dialog};
+    m_process->m_dialog = nullptr;
+    m_process->Detach();
+  }
 }
 
 void
-mux_dialog::update_window(wxString text) {
+mux_dialog::update_label(wxString const &text) {
   st_label->SetLabel(text);
+  Layout();
 }
 
 void
@@ -233,7 +176,7 @@ mux_dialog::update_gauge(long value) {
   m_progress = value;
   g_progress->SetValue(value);
 #if defined(SYS_WINDOWS)
-  if (nullptr != m_taskbar_progress)
+  if (m_taskbar_progress)
     m_taskbar_progress->set_value(value, 100);
 #endif  // SYS_WINDOWS
 }
@@ -277,49 +220,36 @@ mux_dialog::on_save_log(wxCommandEvent &) {
 void
 mux_dialog::on_abort(wxCommandEvent &) {
 #if defined(SYS_WINDOWS)
-  if (0 == pid) {
+  if (m_abort_button_changed) {
     wxFileName output_file_name(static_cast<mmg_dialog *>(GetParent())->tc_output->GetValue());
     wxExecute(wxString::Format(wxT("explorer \"%s\""), output_file_name.GetPath().c_str()));
     return;
   }
 
-  wxKill(pid, wxSIGKILL);
   change_abort_button();
 #else
-  if (0 == pid)
+  if (m_abort_button_changed)
     return;
 
-  wxKill(pid, wxSIGTERM);
+  m_abort_button_changed = true;
+
   b_abort->Enable(false);
 #endif
+
+  b_ok->Enable(true);
+  b_ok->SetFocus();
+
+#if defined(SYS_WINDOWS)
+  wxKill(m_pid, wxSIGKILL);
+#else
+  wxKill(m_pid, wxSIGTERM);
+#endif
 }
 
 void
 mux_dialog::on_close(wxCloseEvent &) {
   mdlg->muxing_has_finished(m_exit_code);
-  delete m_window_disabler;
-  Destroy();
-}
-
-void
-mux_dialog::done(int status) {
-  SetTitle(Z("mkvmerge has finished"));
-  st_remaining_time_label->SetLabel(wxEmptyString);
-  st_remaining_time->SetLabel(wxEmptyString);
-
-  pid = 0;
-  b_ok->Enable(true);
-  b_ok->SetFocus();
-
-#if defined(SYS_WINDOWS)
-  change_abort_button();
-  if (nullptr != m_taskbar_progress)
-    m_taskbar_progress->set_state(0 != status ? TBPF_ERROR : TBPF_NOPROGRESS);
-#else  // SYS_WINDOWS
-  b_abort->Enable(false);
-#endif  // SYS_WINDOWS
-
-  wxLogMessage(wxT("Muxing done, status: %d"), status);
+  EndModal(0);
 }
 
 #if defined(SYS_WINDOWS)
@@ -335,21 +265,42 @@ mux_dialog::change_abort_button() {
 }
 #endif  // SYS_WINDOWS
 
-mux_process::mux_process(mux_dialog *mux_dlg):
-  wxProcess(wxPROCESS_REDIRECT),
-  dlg(mux_dlg) {
+void
+mux_dialog::on_output_available(wxCommandEvent &evt) {
+  wxString line = evt.GetString();
+
+  log += line;
+  if (line.Right(1) != wxT("\r"))
+    log += wxT("\n");
+
+  if (line.Find(Z("Warning:")) == 0)
+    tc_warnings->AppendText(line + wxT("\n"));
+
+  else if (line.Find(Z("Error:")) == 0)
+    tc_errors->AppendText(line + wxT("\n"));
+
+  else if (line.Find(Z("Progress")) == 0) {
+    if (line.Find(wxT("%")) != 0) {
+      line.Remove(line.Find(wxT("%")));
+      auto tmp   = line.AfterLast(wxT(' '));
+      long value = 0;
+      tmp.ToLong(&value);
+      if ((value >= 0) && (value <= 100))
+        update_gauge(value);
+    }
+
+  } else if (line.Length() > 0)
+    tc_output->AppendText(line + wxT("\n"));
+
+  update_remaining_time();
 }
 
 void
-mux_process::OnTerminate(int,
-                         int status) {
-  if (nullptr == dlg)
-    return;
-
-  dlg->set_exit_code(status);
+mux_dialog::on_process_terminated(wxCommandEvent &evt) {
+  m_exit_code = evt.GetInt();
 
   wxString format;
-  if ((status != 0) && (status != 1))
+  if ((0 != m_exit_code) && (1 != m_exit_code))
     format = Z("mkvmerge FAILED with a return code of %d. %s");
   else
     format = Z("mkvmerge finished with a return code of %d. %s");
@@ -360,13 +311,141 @@ mux_process::OnTerminate(int,
   wxString status_1 = Z("There were warnings");
 #endif
 
-  wxString status_str = 0 == status ? wxString(Z("Everything went fine."))
-                      : 1 == status ? status_1
-                      : 2 == status ? wxString(Z("There were ERRORs."))
-                      :               wxString(wxT(""));
+  auto status_str = 0 == m_exit_code ? wxString(Z("Everything went fine."))
+                  : 1 == m_exit_code ? status_1
+                  : 2 == m_exit_code ? wxString(Z("There were ERRORs."))
+                  :                    wxString(wxT(""));
 
-  dlg->update_window(wxString::Format(format, status, status_str.c_str()));
-  dlg->done((0 == status) || (1 == status) ? status : 2);
+  update_label(wxString::Format(format, m_exit_code, status_str.c_str()));
+
+  SetTitle(Z("mkvmerge has finished"));
+  st_remaining_time_label->SetLabel(wxEmptyString);
+  st_remaining_time->SetLabel(wxEmptyString);
+
+  b_ok->Enable(true);
+  b_ok->SetFocus();
+
+#if defined(SYS_WINDOWS)
+  change_abort_button();
+  if (m_taskbar_progress)
+    m_taskbar_progress->set_state(0 != m_exit_code ? TBPF_ERROR : TBPF_NOPROGRESS);
+#else  // SYS_WINDOWS
+  b_abort->Enable(false);
+#endif  // SYS_WINDOWS
+
+  wxCriticalSectionLocker thread_locker{m_cs_thread};
+  if (m_thread) {
+    wxCriticalSectionLocker process_locker{m_thread->m_cs_process};
+    m_thread->m_out = nullptr;
+  }
+
+  delete m_process;
+  m_process = nullptr;
+}
+
+// ------------------------------------------------------------
+
+wxEventType const mux_thread::event = wxNewEventType();
+
+mux_thread::mux_thread(mux_dialog *dialog,
+                       wxProcess *process)
+  : m_dialog{dialog}
+  , m_process{process}
+  , m_out{nullptr}
+{
+}
+
+void *
+mux_thread::Entry() {
+  at_scope_exit_c unlink_thread{[&]() {
+      if (!m_dialog)
+        return;
+
+      wxCriticalSectionLocker locker{m_dialog->m_cs_thread};
+      m_dialog->m_thread = nullptr;
+    }};
+
+  m_out = m_process->GetInputStream();
+
+  std::string line;
+
+  while (1) {
+    char c         = 0;
+    bool eof       = false;
+    bool char_read = false;
+
+    while (!char_read && !eof) {
+      if (TestDestroy())
+        return nullptr;
+      char_read = read_input(c, eof);
+    }
+
+    if ((c == '\n') || (c == '\r') || eof) {
+      if (m_dialog) {
+        // send line to dialog
+        wxCommandEvent evt(mux_thread::event, mux_thread::output_available);
+        evt.SetString(wxU(line));
+        wxPostEvent(m_dialog, evt);
+      }
+
+      line.clear();
+
+    } else if (char_read && (static_cast<unsigned char>(c) != 0xff))
+      line += c;
+
+    if (eof)
+      break;
+  }
+
+  return nullptr;
+}
+
+bool
+mux_thread::read_input(char &c,
+                       bool &eof) {
+  eof = false;
+
+  if (!m_available_input.empty()) {
+    c = m_available_input.front();
+    m_available_input.pop_front();
+    return true;
+  }
+
+  wxCriticalSectionLocker locker{m_cs_process};
+
+  if (!m_out || m_out->Eof()) {
+    eof = true;
+    return false;
+  }
+
+  while (m_out->CanRead())
+    m_available_input.push_back(m_out->GetC());
+
+  if (m_available_input.empty())
+    return false;
+
+  c = m_available_input.front();
+  m_available_input.pop_front();
+
+  return true;
+}
+
+mux_process::mux_process(mux_dialog *dialog)
+  : wxProcess(wxPROCESS_REDIRECT)
+  , m_dialog(dialog)
+{
+}
+
+void
+mux_process::OnTerminate(int,
+                         int status) {
+  wxCriticalSectionLocker locker{m_cs_dialog};
+  if (!m_dialog)
+    return;
+
+  wxCommandEvent evt(mux_thread::event, mux_thread::process_terminated);
+  evt.SetInt(status);
+  wxPostEvent(m_dialog, evt);
 }
 
 IMPLEMENT_CLASS(mux_dialog, wxDialog);
@@ -374,5 +453,7 @@ BEGIN_EVENT_TABLE(mux_dialog, wxDialog)
   EVT_BUTTON(ID_B_MUX_OK,      mux_dialog::on_ok)
   EVT_BUTTON(ID_B_MUX_SAVELOG, mux_dialog::on_save_log)
   EVT_BUTTON(ID_B_MUX_ABORT,   mux_dialog::on_abort)
+  EVT_COMMAND(mux_thread::output_available,   mux_thread::event, mux_dialog::on_output_available)
+  EVT_COMMAND(mux_thread::process_terminated, mux_thread::event, mux_dialog::on_process_terminated)
   EVT_CLOSE(mux_dialog::on_close)
 END_EVENT_TABLE();
