@@ -14,9 +14,9 @@
 #ifndef __TAB_ATTACHMENTS_H
 #define __TAB_ATTACHMENTS_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include <wx/config.h>
+#include <wx/wx.h>
 
 #define ID_B_ADDATTACHMENT                 12001
 #define ID_B_REMOVEATTACHMENT              12002
