@@ -11,9 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
-
-#include <errno.h>
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/dnd.h>
@@ -36,6 +34,7 @@
 #include "common/strings/parsing.h"
 #include "common/unique_numbers.h"
 #include "common/wx.h"
+#include "common/xml/ebml_chapters_converter.h"
 #include "mmg/mmg_dialog.h"
 #include "mmg/mmg.h"
 #include "mmg/tabs/chapters.h"
@@ -130,8 +129,8 @@ chapter_values_dlg::chapter_values_dlg(wxWindow *parent)
     cob_language->Append(sorted_iso_codes[i]);
 
   cob_country->Append(wxEmptyString);
-  for (i = 0; cctlds[i] != nullptr; i++)
-    cob_country->Append(wxU(cctlds[i]));
+  for (auto &cctld : cctlds)
+    cob_country->Append(wxU(cctld));
 
   siz_buttons = new wxBoxSizer(wxHORIZONTAL);
   siz_buttons->AddStretchSpacer();
@@ -292,8 +291,8 @@ tab_chapters::tab_chapters(wxWindow *parent,
   siz_line->Add(st_country, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 5);
   cob_country_code = new wxMTX_COMBOBOX_TYPE(this, ID_CB_CHAPTERSELECTCOUNTRYCODE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, nullptr, wxCB_DROPDOWN | wxCB_READONLY);
   cob_country_code->Append(wxEmptyString);
-  for (i = 0; cctlds[i] != nullptr; i++)
-    cob_country_code->Append(wxU(cctlds[i]));
+  for (auto &cctld : cctlds)
+    cob_country_code->Append(wxU(cctld));
   cob_country_code->SetValue(wxEmptyString);
   siz_line->Add(cob_country_code, 1, wxGROW, 0);
   siz_fg->Add(siz_line, 0, wxGROW, 0);
@@ -388,7 +387,7 @@ tab_chapters::on_new_chapters(wxCommandEvent &) {
   tc_chapters->DeleteAllItems();
   tid_root = tc_chapters->AddRoot(Z("(new chapter file)"));
   m_chapters_cp = ebml_element_cptr(new KaxChapters);
-  m_chapters    = static_cast<KaxChapters *>(m_chapters_cp.get_object());
+  m_chapters    = static_cast<KaxChapters *>(m_chapters_cp.get());
 
   m_chapters_menu->Enable(ID_M_CHAPTERS_SAVE, true);
   m_chapters_menu->Enable(ID_M_CHAPTERS_SAVEAS, true);
@@ -399,7 +398,7 @@ tab_chapters::on_new_chapters(wxCommandEvent &) {
   enable_inputs(false);
   source_is_kax_file = false;
   if (analyzer)
-    analyzer.clear();
+    analyzer.reset();
 
   clear_list_of_unique_uint32(UNIQUE_CHAPTER_IDS);
   clear_list_of_unique_uint32(UNIQUE_EDITION_IDS);
@@ -420,22 +419,22 @@ tab_chapters::create_chapter_label(KaxChapterAtom &chapter) {
   label = Z("(unnamed chapter)");
   language = nullptr;
   display = FindChild<KaxChapterDisplay>(chapter);
-  if (display != nullptr) {
+  if (display) {
     cstring = FindChild<KaxChapterString>(*display);
-    if (cstring != nullptr)
+    if (cstring)
       label =
         UTFstring_to_wxString(*static_cast<EbmlUnicodeString *>(cstring));
     language = FindChild<KaxChapterLanguage>(*display);
   }
   label += wxT(" [");
   tstart = FindChild<KaxChapterTimeStart>(chapter);
-  if (tstart != nullptr) {
+  if (tstart) {
     timestamp = uint64(*static_cast<EbmlUInteger *>(tstart));
     s.Printf(wxT(FMT_TIMECODEN), ARG_TIMECODEN(timestamp));
     label += s;
 
     tend = FindChild<KaxChapterTimeEnd>(chapter);
-    if (tend != nullptr) {
+    if (tend) {
       timestamp = uint64(*static_cast<EbmlUInteger *>(tend));
       s.Printf(wxT(FMT_TIMECODEN), ARG_TIMECODEN(timestamp));
       label += wxT(" - ") + s;
@@ -443,7 +442,7 @@ tab_chapters::create_chapter_label(KaxChapterAtom &chapter) {
 
     label += wxT("; ");
   }
-  if (language != nullptr)
+  if (language)
     label += wxU(language);
   else
     label += wxT("eng");
@@ -495,21 +494,21 @@ tab_chapters::fix_missing_languages(EbmlMaster &master) {
   for (i = 0; i < master.ListSize(); i++) {
     e = master[i];
 
-    if (dynamic_cast<EbmlMaster *>(e) != nullptr)
+    if (dynamic_cast<EbmlMaster *>(e))
       fix_missing_languages(*dynamic_cast<EbmlMaster *>(e));
 
     if (EbmlId(*e) == KaxChapterAtom::ClassInfos.GlobalId) {
       m = static_cast<EbmlMaster *>(e);
       d = FindChild<KaxChapterDisplay>(*m);
-      if (d == nullptr)
+      if (!d)
         d = &GetChild<KaxChapterDisplay>(*m);
       l = FindChild<KaxChapterLanguage>(*d);
-      if (l == nullptr) {
+      if (!l) {
         l = &GetChild<KaxChapterLanguage>(*d);
         *static_cast<EbmlString *>(l) = "eng";
       }
       u = FindChild<KaxChapterUID>(*m);
-      if (u != nullptr)
+      if (u)
         add_unique_uint32(uint32(*static_cast<EbmlUInteger *>(u)),
                           UNIQUE_CHAPTER_IDS);
     }
@@ -541,14 +540,14 @@ tab_chapters::load(wxString name) {
       file_name = name;
       if (!analyzer->process()) {
         wxMessageBox(Z("This file could not be opened or parsed."), Z("File parsing failed"), wxOK | wxCENTER | wxICON_ERROR);
-        analyzer.clear();
+        analyzer.reset();
 
         return false;
       }
       pos = analyzer->find(KaxChapters::ClassInfos.GlobalId);
       if (pos == -1) {
         wxMessageBox(Z("This file does not contain any chapters."), Z("No chapters found"), wxOK | wxCENTER | wxICON_INFORMATION);
-        analyzer.clear();
+        analyzer.reset();
 
         return false;
       }
@@ -566,7 +565,7 @@ tab_chapters::load(wxString name) {
       source_is_kax_file = false;
     }
   } catch (mtx::exception &) {
-    analyzer.clear();
+    analyzer.reset();
     s = Z("This file does not contain valid chapters.");
     break_line(s);
     while (s[s.Length() - 1] == wxT('\n'))
@@ -576,7 +575,7 @@ tab_chapters::load(wxString name) {
   }
 
   m_chapters_cp = new_chapters;
-  m_chapters    = static_cast<KaxChapters *>(m_chapters_cp.get_object());
+  m_chapters    = static_cast<KaxChapters *>(m_chapters_cp.get());
 
   tc_chapters->DeleteAllItems();
   m_chapters_menu->Enable(ID_M_CHAPTERS_SAVE, true);
@@ -641,7 +640,7 @@ tab_chapters::on_save_chapters_to_kax_file(wxCommandEvent &) {
 
   analyzer = wx_kax_analyzer_cptr(new wx_kax_analyzer_c(this, wxMB(file_name)));
   if (!analyzer->process()) {
-    analyzer.clear();
+    analyzer.reset();
     return;
   }
 
@@ -696,14 +695,7 @@ tab_chapters::save() {
 #if defined(SYS_WINDOWS)
   out->use_dos_style_newlines(true);
 #endif
-  out->write_bom("UTF-8");
-  out->puts("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-            "\n"
-            "<!-- <!DOCTYPE Tags SYSTEM \"matroskatags.dtd\"> -->\n"
-            "\n"
-            "<Chapters>\n");
-  write_chapters_xml(m_chapters, out.get_object());
-  out->puts("</Chapters>\n");
+  mtx::xml::ebml_chapters_converter_c::write_xml(*m_chapters, *out);
 
   source_is_kax_file = false;
   source_is_simple_format = false;
@@ -729,13 +721,13 @@ tab_chapters::verify_atom_recursively(EbmlElement *e) {
   std::string lang;
   uint32_t i;
 
-  if (dynamic_cast<KaxEditionUID *>(e) != nullptr)
+  if (dynamic_cast<KaxEditionUID *>(e))
     return true;
   chapter = dynamic_cast<KaxChapterAtom *>(e);
-  if (chapter == nullptr)
+  if (!chapter)
     return false;
 
-  if (FindChild<KaxChapterUID>(*chapter) == nullptr) {
+  if (FindChild<KaxChapterUID>(*chapter)) {
     uid = &GetChild<KaxChapterUID>(*chapter);
     *static_cast<EbmlUInteger *>(uid) =
       create_unique_uint32(UNIQUE_CHAPTER_IDS);
@@ -743,10 +735,10 @@ tab_chapters::verify_atom_recursively(EbmlElement *e) {
 
   cs = nullptr;
   display = FindChild<KaxChapterDisplay>(*chapter);
-  if (display != nullptr)
+  if (display)
     cs = FindChild<KaxChapterString>(*display);
 
-  if ((display == nullptr) || (cs == nullptr)) {
+  if ((!display) || (!cs)) {
     wxMessageBox(Z("One of the chapters does not have a name."), Z("Chapter verification error"), wxCENTER | wxOK | wxICON_ERROR);
     return false;
   }
@@ -754,13 +746,13 @@ tab_chapters::verify_atom_recursively(EbmlElement *e) {
     UTFstring_to_wxString(UTFstring(*static_cast<EbmlUnicodeString *>(cs)));
 
   start = FindChild<KaxChapterTimeStart>(*chapter);
-  if (start == nullptr) {
+  if (!start) {
     wxMessageBox(wxString::Format(Z("The chapter '%s' is missing the start time."), label.c_str()), Z("Chapter verification error"), wxCENTER | wxOK | wxICON_ERROR);
     return false;
   }
 
   language = FindChild<KaxChapterLanguage>(*display);
-  if (language == nullptr) {
+  if (!language) {
     wxMessageBox(wxString::Format(Z("The chapter '%s' is missing its language."), label.c_str()), Z("Chapter verification error"), wxCENTER | wxOK | wxICON_ERROR);
     return false;
   }
@@ -773,7 +765,7 @@ tab_chapters::verify_atom_recursively(EbmlElement *e) {
   }
 
   for (i = 0; i < chapter->ListSize(); i++)
-    if (dynamic_cast<KaxChapterAtom *>((*chapter)[i]) != nullptr)
+    if (dynamic_cast<KaxChapterAtom *>((*chapter)[i]))
       if (!verify_atom_recursively((*chapter)[i]))
         return false;
 
@@ -801,7 +793,7 @@ tab_chapters::verify(bool called_interactively) {
     bool contains_atom      = false;
 
     for (cidx = 0; cidx < eentry->ListSize(); cidx++)
-      if (dynamic_cast<KaxChapterAtom *>((*eentry)[cidx]) != nullptr) {
+      if (dynamic_cast<KaxChapterAtom *>((*eentry)[cidx])) {
         contains_atom = true;
         break;
       }
@@ -817,7 +809,7 @@ tab_chapters::verify(bool called_interactively) {
   for (eidx = 0; eidx < m_chapters->ListSize(); eidx++) {
     KaxEditionEntry *eentry = static_cast<KaxEditionEntry *>((*m_chapters)[eidx]);
     for (cidx = 0; cidx < eentry->ListSize(); cidx++)
-      if ((dynamic_cast<KaxChapterAtom *>((*eentry)[cidx]) != nullptr) && !verify_atom_recursively((*eentry)[cidx]))
+      if (dynamic_cast<KaxChapterAtom *>((*eentry)[cidx]) && !verify_atom_recursively((*eentry)[cidx]))
         return false;
   }
 
@@ -972,7 +964,7 @@ tab_chapters::on_remove_chapter(wxCommandEvent &) {
     m = m_chapters;
   else {
     p_d = (chapter_node_data_c *)tc_chapters->GetItemData(p_id);
-    if (p_d == nullptr)
+    if (!p_d)
       return;
     if (p_d->is_atom)
       m = p_d->chapter;
@@ -980,7 +972,7 @@ tab_chapters::on_remove_chapter(wxCommandEvent &) {
       m = p_d->eentry;
   }
   d = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if (d == nullptr)
+  if (!d)
     return;
   if (d->is_atom)
     del = d->chapter;
@@ -1020,20 +1012,20 @@ tab_chapters::on_entry_selected(wxTreeEvent &evt) {
   t = (chapter_node_data_c *)tc_chapters->GetItemData(evt.GetItem());
   lb_chapter_names->Clear();
 
-  if ((evt.GetItem() == tid_root) || (t == nullptr) || !t->is_atom) {
+  if ((evt.GetItem() == tid_root) || (!t) || !t->is_atom) {
     enable_inputs(false);
     no_update = true;
     tc_chapter_name->SetValue(wxEmptyString);
     tc_start_time->SetValue(wxEmptyString);
     tc_end_time->SetValue(wxEmptyString);
-    if ((evt.GetItem() != tid_root) && (t != nullptr) && !t->is_atom) {
+    if ((evt.GetItem() != tid_root) && t && !t->is_atom) {
       KaxEditionUID *euid;
       wxString s;
 
       st_uid->Enable(true);
       tc_uid->Enable(true);
-      euid = FINDFIRST(t->eentry, KaxEditionUID);
-      if (euid != nullptr)
+      euid = FindChild<KaxEditionUID>(t->eentry);
+      if (euid)
         s.Printf(wxT("%u"), uint32(*euid));
       tc_uid->SetValue(s);
     } else {
@@ -1047,13 +1039,13 @@ tab_chapters::on_entry_selected(wxTreeEvent &evt) {
 
   enable_inputs(true);
 
-  display = FINDFIRST(t->chapter, KaxChapterDisplay);
-  if (display == nullptr)
+  display = FindChild<KaxChapterDisplay>(t->chapter);
+  if (!display)
     wxdie(Z("on_entry_selected: display == nullptr. Should not have happened."));
   first = true;
-  while (display != nullptr) {
+  while (display) {
     cstring = FindChild<KaxChapterString>(*display);
-    if (cstring != nullptr)
+    if (cstring)
       label =
         UTFstring_to_wxString(*static_cast<EbmlUnicodeString *>(cstring));
     else
@@ -1064,27 +1056,27 @@ tab_chapters::on_entry_selected(wxTreeEvent &evt) {
       first = false;
     }
     lb_chapter_names->Append(label);
-    display = FINDNEXT(t->chapter, KaxChapterDisplay, display);
+    display = FindNextChild<KaxChapterDisplay>(t->chapter, display);
   }
 
   set_timecode_values(t->chapter);
 
-  fhidden = FINDFIRST(t->chapter, KaxChapterFlagHidden);
-  if (fhidden == nullptr)
+  fhidden = FindChild<KaxChapterFlagHidden>(t->chapter);
+  if (!fhidden)
     value = false;
   else
     value = uint8(*static_cast<EbmlUInteger *>(fhidden)) != 0;
   cb_flag_hidden->SetValue(value);
 
-  fenabled = FINDFIRST(t->chapter, KaxChapterFlagEnabled);
-  if (fenabled == nullptr)
+  fenabled = FindChild<KaxChapterFlagEnabled>(t->chapter);
+  if (!fenabled)
     value = true;
   else
     value = uint8(*static_cast<EbmlUInteger *>(fenabled)) != 0;
   cb_flag_enabled->SetValue(value);
 
-  cuid = FINDFIRST(t->chapter, KaxChapterUID);
-  if (cuid == nullptr)
+  cuid = FindChild<KaxChapterUID>(t->chapter);
+  if (!cuid)
     label = wxEmptyString;
   else
     label.Printf(wxT("%u"), uint32(*cuid));
@@ -1122,7 +1114,7 @@ tab_chapters::on_language_code_selected(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   clanguage = &GetChild<KaxChapterLanguage>(*cdisplay);
@@ -1158,7 +1150,7 @@ tab_chapters::on_country_code_selected(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   if (cob_country_code->GetStringSelection().Length() == 0) {
@@ -1205,7 +1197,7 @@ tab_chapters::on_chapter_name_changed(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   GetChildAs<KaxChapterString, EbmlUnicodeString>(*cdisplay) = cstrutf8_to_UTFstring(wxMB(tc_chapter_name->GetValue()));
@@ -1233,15 +1225,13 @@ tab_chapters::set_values_recursively(wxTreeItemId id,
     return;
 
   d = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if ((d != nullptr) && (d->is_atom)) {
-    display = FINDFIRST(d->chapter, KaxChapterDisplay);
-    while (display != nullptr) {
+  if (d && d->is_atom) {
+    display = FindChild<KaxChapterDisplay>(d->chapter);
+    while (display) {
       i = 0;
       while (i < display->ListSize()) {
-        if ((set_language &&
-             (dynamic_cast<KaxChapterLanguage *>((*display)[i]) != nullptr)) ||
-            (!set_language &&
-             (dynamic_cast<KaxChapterCountry *>((*display)[i]) != nullptr))) {
+        if (   ( set_language && dynamic_cast<KaxChapterLanguage *>((*display)[i]))
+            || (!set_language && dynamic_cast<KaxChapterCountry * >((*display)[i]))) {
           delete (*display)[i];
           display->Remove(i);
         } else
@@ -1258,7 +1248,7 @@ tab_chapters::set_values_recursively(wxTreeItemId id,
         display->PushElement(*country);
       }
 
-      display = FINDNEXT(d->chapter, KaxChapterDisplay, display);
+      display = FindNextChild<KaxChapterDisplay>(d->chapter, display);
     }
     text = create_chapter_label(*d->chapter);
     tc_chapters->SetItemText(id, text);
@@ -1301,7 +1291,7 @@ tab_chapters::on_set_values(wxCommandEvent &) {
   }
 
   t = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if ((t == nullptr) || !t->is_atom)
+  if ((!t) || !t->is_atom)
     return;
 
   cdisplay = nullptr;
@@ -1314,7 +1304,7 @@ tab_chapters::on_set_values(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   set_display_values(cdisplay);
@@ -1370,7 +1360,7 @@ tab_chapters::on_adjust_timecodes(wxCommandEvent &) {
   adjust_timecodes_recursively(id, adjustment);
 
   t = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if ((t == nullptr) || !t->is_atom)
+  if ((!t) || !t->is_atom)
     return;
 
   set_timecode_values(t->chapter);
@@ -1385,7 +1375,7 @@ tab_chapters::on_adjust_timecodes(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   set_display_values(cdisplay);
@@ -1406,17 +1396,17 @@ tab_chapters::adjust_timecodes_recursively(wxTreeItemId id,
     return;
 
   d = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if ((d != nullptr) && (d->is_atom)) {
-    tstart = FINDFIRST(d->chapter, KaxChapterTimeStart);
-    if (tstart != nullptr) {
+  if (d && (d->is_atom)) {
+    tstart = FindChild<KaxChapterTimeStart>(d->chapter);
+    if (tstart) {
       t = uint64(*tstart);
       t += adjust_by;
       if (t < 0)
         t = 0;
       *static_cast<EbmlUInteger *>(tstart) = t;
     }
-    tend = FINDFIRST(d->chapter, KaxChapterTimeEnd);
-    if (tend != nullptr) {
+    tend = FindChild<KaxChapterTimeEnd>(d->chapter);
+    if (tend) {
       t = uint64(*tend);
       t += adjust_by;
       if (t < 0)
@@ -1440,13 +1430,13 @@ tab_chapters::copy_values(wxTreeItemId id) {
   wxString label;
   KaxChapterAtom *chapter;
   EbmlElement *e;
-  int64_t ts_start, ts_end;
+  int64_t ts_start = 0, ts_end;
   std::vector<std::string> l_codes, c_codes;
   wxString s;
   uint32_t i;
 
   data = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if (data == nullptr)
+  if (!data)
     return true;
 
   label = tc_chapters->GetItemText(id);
@@ -1454,7 +1444,7 @@ tab_chapters::copy_values(wxTreeItemId id) {
 
   s = tc_uid->GetValue();
   if (s.Length() > 0) {
-    if (!parse_int(wxMB(s), ts_start))
+    if (!parse_number(wxMB(s), ts_start))
       wxMessageBox(Z("Invalid UID. A UID is simply a number."), Z("Input data error"), wxOK | wxCENTER | wxICON_ERROR);
     else {
       i = ts_start;
@@ -1554,7 +1544,7 @@ tab_chapters::on_add_chapter_name(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   cdisplay = new KaxChapterDisplay;
@@ -1606,7 +1596,7 @@ tab_chapters::on_remove_chapter_name(wxCommandEvent &) {
       }
     }
 
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   t->chapter->Remove(i);
@@ -1631,7 +1621,7 @@ tab_chapters::on_remove_chapter_name(wxCommandEvent &) {
       }
     }
 
-  if (cdisplay != nullptr)
+  if (cdisplay)
     set_display_values(cdisplay);
   tc_chapter_name->SetFocus();
   b_remove_chapter_name->Enable(lb_chapter_names->GetCount() > 1);
@@ -1661,7 +1651,7 @@ tab_chapters::on_chapter_name_selected(wxCommandEvent &) {
         break;
       }
     }
-  if (cdisplay == nullptr)
+  if (!cdisplay)
     return;
 
   set_display_values(cdisplay);
@@ -1715,7 +1705,7 @@ tab_chapters::on_flag_hidden(wxCommandEvent &) {
   if (!selected.IsOk() || (selected == tid_root))
     return;
   t = (chapter_node_data_c *)tc_chapters->GetItemData(selected);
-  if ((t == nullptr) || !t->is_atom)
+  if ((!t) || !t->is_atom)
     return;
 
   if (cb_flag_hidden->IsChecked())
@@ -1739,7 +1729,7 @@ tab_chapters::on_flag_enabled(wxCommandEvent &) {
   if (!selected.IsOk() || (selected == tid_root))
     return;
   t = (chapter_node_data_c *)tc_chapters->GetItemData(selected);
-  if ((t == nullptr) || !t->is_atom)
+  if ((!t) || !t->is_atom)
     return;
 
   if (!cb_flag_enabled->IsChecked())
@@ -1762,16 +1752,16 @@ tab_chapters::set_timecode_values(KaxChapterAtom *atom) {
 
   no_update = true;
 
-  tstart = FINDFIRST(atom, KaxChapterTimeStart);
-  if (tstart != nullptr) {
+  tstart = FindChild<KaxChapterTimeStart>(atom);
+  if (tstart) {
     timestamp = uint64(*static_cast<EbmlUInteger *>(tstart));
     label.Printf(wxT(FMT_TIMECODEN), ARG_TIMECODEN(timestamp));
     tc_start_time->SetValue(label);
   } else
     tc_start_time->SetValue(wxEmptyString);
 
-  tend = FINDFIRST(atom, KaxChapterTimeEnd);
-  if (tend != nullptr) {
+  tend = FindChild<KaxChapterTimeEnd>(atom);
+  if (tend) {
     timestamp = uint64(*static_cast<EbmlUInteger *>(tend));
     label.Printf(wxT(FMT_TIMECODEN), ARG_TIMECODEN(timestamp));
     tc_end_time->SetValue(label);
@@ -1792,16 +1782,16 @@ tab_chapters::set_display_values(KaxChapterDisplay *display) {
 
   no_update = true;
 
-  cstring = FINDFIRST(display, KaxChapterString);
-  if (cstring != nullptr) {
+  cstring = FindChild<KaxChapterString>(display);
+  if (cstring) {
     wxString tmp =
       UTFstring_to_wxString(*static_cast<EbmlUnicodeString *>(cstring));
     tc_chapter_name->SetValue(tmp);
   } else
     tc_chapter_name->SetValue(wxT("(unnamed)"));
 
-  clanguage = FINDFIRST(display, KaxChapterLanguage);
-  if (clanguage != nullptr)
+  clanguage = FindChild<KaxChapterLanguage>(display);
+  if (clanguage)
     language = wxU(clanguage);
   else
     language = wxT("eng");
@@ -1823,8 +1813,8 @@ tab_chapters::set_display_values(KaxChapterDisplay *display) {
   else
     cob_language_code->SetValue(language);
 
-  ccountry = FINDFIRST(display, KaxChapterCountry);
-  if (ccountry != nullptr)
+  ccountry = FindChild<KaxChapterCountry>(display);
+  if (ccountry)
     cob_country_code->SetValue(wxU(ccountry));
   else
     cob_country_code->SetValue(wxEmptyString);
@@ -1852,7 +1842,7 @@ tab_chapters::parse_time(wxString s) {
     }
     c++;
   }
-  if (!parse_int(utf8s, nsecs))
+  if (!parse_number(utf8s, nsecs))
     return -1;
   return nsecs * 1000000000;
 }
