@@ -11,9 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
-
-#include <wx/wxprec.h>
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/dnd.h>
@@ -23,7 +21,6 @@
 #include <wx/regex.h>
 #include <wx/statline.h>
 
-#include "common/common_pch.h"
 #include "common/extern_data.h"
 #include "common/iso639.h"
 #include "merge/mkvmerge.h"
@@ -140,8 +137,8 @@ tab_input_extra::translate_ui() {
 
 void
 tab_input_extra::set_track_mode(mmg_track_t *t) {
-  bool not_appending = (nullptr != t) && !t->appending;
-  bool normal_track  = (nullptr != t) && (('a' == t->type) || ('s' == t->type) || ('v' == t->type));
+  bool not_appending = t && !t->appending;
+  bool normal_track  = t && (('a' == t->type) || ('s' == t->type) || ('v' == t->type));
   wxString ctype     = t ? t->ctype.Lower() : wxT("");
 
   st_cues->Enable(not_appending && normal_track);
@@ -151,7 +148,7 @@ tab_input_extra::set_track_mode(mmg_track_t *t) {
   st_user_defined->Enable(normal_track);
   tc_user_defined->Enable(normal_track);
 
-  if (nullptr != t)
+  if (t)
     return;
 
   bool saved_dcvn             = input->dont_copy_values_now;
