@@ -11,9 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
-
-#include <wx/wxprec.h>
+#include "common/common_pch.h"
 
 #include <wx/wx.h>
 #include <wx/dnd.h>
@@ -23,7 +21,6 @@
 #include <wx/regex.h>
 #include <wx/statline.h>
 
-#include "common/common_pch.h"
 #include "common/extern_data.h"
 #include "common/iso639.h"
 #include "common/stereo_mode.h"
@@ -56,7 +53,7 @@ tab_input_format::tab_input_format(wxWindow *parent,
 
   cob_aspect_ratio = new wxMTX_COMBOBOX_TYPE(this, ID_CB_ASPECTRATIO, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, nullptr, wxCB_DROPDOWN);
 
-  for (i = 0; nullptr != predefined_aspect_ratios[i]; ++i)
+  for (i = 0; predefined_aspect_ratios[i]; ++i)
     cob_aspect_ratio->Append(predefined_aspect_ratios[i]);
 
   cob_aspect_ratio->SetSizeHints(0, -1);
@@ -163,7 +160,7 @@ tab_input_format::setup_control_contents() {
   size_t i;
   int selection;
   if (0 == cob_fourcc->GetCount())
-    for (i = 0; nullptr != predefined_fourccs[i]; ++i)
+    for (i = 0; predefined_fourccs[i]; ++i)
       cob_fourcc->Append(predefined_fourccs[i]);
 
   unsigned int num_stereo_modes = stereo_mode_c::max_index() + 1;
@@ -201,11 +198,9 @@ tab_input_format::setup_control_contents() {
   cob_nalu_size_length->SetString(2, Z("4 bytes"));
   cob_nalu_size_length->SetSelection(selection);
 
-  if (0 == sorted_charsets.Count()) {
-    for (i = 0; nullptr != sub_charsets[i]; ++i)
-      sorted_charsets.Add(wxU(sub_charsets[i]));
-    sorted_charsets.Sort();
-  }
+  if (0 == sorted_charsets.Count())
+    for (auto &sub_charset : sub_charsets)
+      sorted_charsets.Add(wxU(sub_charset));
 
   if (0 == cob_sub_charset->GetCount()) {
     cob_sub_charset->Append(wxEmptyString);
@@ -276,10 +271,10 @@ tab_input_format::set_track_mode(mmg_track_t *t) {
 
   ctype = ctype.Lower();
 
-  st_delay->Enable((nullptr != t) && normal_track);
-  tc_delay->Enable((nullptr != t) && normal_track);
-  st_stretch->Enable((nullptr != t) && normal_track);
-  tc_stretch->Enable((nullptr != t) && normal_track);
+  st_delay->Enable(t && normal_track);
+  tc_delay->Enable(t && normal_track);
+  st_stretch->Enable(t && normal_track);
+  tc_stretch->Enable(t && normal_track);
   st_sub_charset->Enable(chapters_app || (subs_app && (ctype.Find(wxT("vobsub")) < 0)));
   cob_sub_charset->Enable(chapters_app || (subs_app && (ctype.Find(wxT("vobsub")) < 0)));
   st_fourcc->Enable(video);
@@ -291,7 +286,7 @@ tab_input_format::set_track_mode(mmg_track_t *t) {
   st_nalu_size_length->Enable(avc || avc_es);
   cob_nalu_size_length->Enable(avc || avc_es);
 
-  bool ar_enabled = normal_track && (nullptr != t) && !t->display_dimensions_selected;
+  bool ar_enabled = normal_track && t && !t->display_dimensions_selected;
   rb_aspect_ratio->Enable(video);
   cob_aspect_ratio->Enable(video && ar_enabled);
   rb_display_dimensions->Enable(video);
@@ -306,7 +301,7 @@ tab_input_format::set_track_mode(mmg_track_t *t) {
 
   cb_aac_is_sbr->Enable(audio_app && ((ctype.Find(wxT("aac")) >= 0) || (ctype.Find(wxT("mp4a")) >= 0)));
 
-  if (nullptr != t)
+  if (t)
     return;
 
   bool saved_dcvn             = input->dont_copy_values_now;
