@@ -26,7 +26,7 @@ protected:
   ITaskbarList3 *m_interface;
 
 public:
-  taskbar_progress_c(wxWindow *window = NULL);
+  taskbar_progress_c(wxWindow *window = nullptr);
   virtual ~taskbar_progress_c();
   virtual void set_value(ULONGLONG completed, ULONGLONG total);
   virtual void set_state(TBPFLAG state);
