@@ -1,7 +1,7 @@
 #ifndef __TYPES_H__
 #define __TYPES_H__
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 typedef int64_t MediaTime;
 typedef uint8_t binary;
