@@ -17,25 +17,25 @@
 #include "common/common_pch.h"
 
 #include "common/ac3.h"
-#include "common/byte_buffer.h"
 #include "common/samples_timecode_conv.h"
 #include "merge/pr_generic.h"
 
 class ac3_packetizer_c: public generic_packetizer_c {
 protected:
-  int64_t m_bytes_output, m_packetno, m_bytes_skipped, m_last_timecode, m_num_packets_same_tc;
-  int m_samples_per_sec;
-  byte_buffer_c m_byte_buffer;
-  bool m_first_packet;
-  ac3_header_t m_first_ac3_header;
+  int64_t m_bytes_output, m_packetno, m_last_timecode, m_num_packets_same_tc;
+  ac3::frame_c m_first_ac3_header;
+  ac3::parser_c m_parser;
   samples_to_timecode_converter_c m_s2tc;
   int64_t m_single_packet_duration;
+  std::deque<std::pair<int64_t, uint64_t> > m_available_timecodes;
 
 public:
   ac3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, int bsid);
   virtual ~ac3_packetizer_c();
 
   virtual int process(packet_cptr packet);
+  virtual void flush_packets();
+  virtual void flush();
   virtual void set_headers();
 
   virtual const std::string get_format_name(bool translate = true) {
@@ -45,9 +45,10 @@ public:
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 protected:
-  virtual unsigned char *get_ac3_packet(ac3_header_t *ac3header);
-  virtual void add_to_buffer(unsigned char *buf, int size);
-  virtual void adjust_header_values(ac3_header_t &ac3_header);
+  virtual void add_to_buffer(unsigned char *const buf, int size);
+  virtual void adjust_header_values(ac3::frame_c &ac3_header);
+  virtual ac3::frame_c get_frame();
+  virtual int64_t calculate_timecode(uint64_t stream_position);
 };
 
 class ac3_bs_packetizer_c: public ac3_packetizer_c {
@@ -59,7 +60,7 @@ public:
   ac3_bs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, unsigned long samples_per_sec, int channels, int bsid);
 
 protected:
-  virtual void add_to_buffer(unsigned char *buf, int size);
+  virtual void add_to_buffer(unsigned char *const buf, int size);
 };
 
 #endif // __P_AC3_H
