@@ -53,13 +53,13 @@ mpeg4_p10_es_video_packetizer_c(generic_reader_c *p_reader,
   // packetizer because it takes care of handling the default
   // duration/FPS itself.
   if (m_ti.m_ext_timecodes.empty())
-    m_timecode_factory.clear();
+    m_timecode_factory.reset();
 
   if (4 == m_parser.get_nalu_size_length())
     set_default_compression_method(COMPRESSION_MPEG4_P10);
 
   int64_t factory_default_duration;
-  if (m_timecode_factory.is_set() && (-1 != (factory_default_duration = m_timecode_factory->get_default_duration(-1)))) {
+  if (m_timecode_factory && (-1 != (factory_default_duration = m_timecode_factory->get_default_duration(-1)))) {
     m_parser.force_default_duration(factory_default_duration);
     set_track_default_duration(factory_default_duration);
     m_default_duration_forced = true;
@@ -201,7 +201,7 @@ mpeg4_p10_es_video_packetizer_c::connect(generic_packetizer_c *src,
     return;
 
   mpeg4_p10_es_video_packetizer_c *real_src = dynamic_cast<mpeg4_p10_es_video_packetizer_c *>(src);
-  assert(nullptr != real_src);
+  assert(real_src);
 
   m_htrack_default_duration = real_src->m_htrack_default_duration;
   m_default_duration_forced = real_src->m_default_duration_forced;
@@ -214,19 +214,13 @@ connection_result_e
 mpeg4_p10_es_video_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                                 std::string &error_message) {
   mpeg4_p10_es_video_packetizer_c *vsrc = dynamic_cast<mpeg4_p10_es_video_packetizer_c *>(src);
-  if (nullptr == vsrc)
+  if (!vsrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_v_width( m_hvideo_pixel_width,  vsrc->m_hvideo_pixel_width);
   connect_check_v_height(m_hvideo_pixel_height, vsrc->m_hvideo_pixel_height);
   connect_check_codec_id(m_hcodec_id,           vsrc->m_hcodec_id);
-
-  if (((nullptr == m_ti.m_private_data) && (nullptr != vsrc->m_ti.m_private_data)) ||
-      ((nullptr != m_ti.m_private_data) && (nullptr == vsrc->m_ti.m_private_data)) ||
-      (m_ti.m_private_size != vsrc->m_ti.m_private_size)) {
-    error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % m_ti.m_private_size % vsrc->m_ti.m_private_size).str();
-    return CAN_CONNECT_MAYBE_CODECPRIVATE;
-  }
+  connect_check_codec_private(src);
 
   return CAN_CONNECT_YES;
 }
