@@ -87,7 +87,7 @@ connection_result_e
 flac_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                   std::string &error_message) {
   flac_packetizer_c *fsrc = dynamic_cast<flac_packetizer_c *>(src);
-  if (nullptr == fsrc)
+  if (!fsrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_a_samplerate(m_stream_info.sample_rate, fsrc->m_stream_info.sample_rate);
@@ -95,8 +95,8 @@ flac_packetizer_c::can_connect_to(generic_packetizer_c *src,
   connect_check_a_bitdepth(m_stream_info.bits_per_sample, fsrc->m_stream_info.bits_per_sample);
 
   if (   (m_header->get_size() != fsrc->m_header->get_size())
-      || !m_header.is_set()
-      || !fsrc->m_header.is_set()
+      || !m_header
+      || !fsrc->m_header
       || memcmp(m_header->get_buffer(), fsrc->m_header->get_buffer(), m_header->get_size())) {
     error_message = (boost::format(Y("The FLAC header data is different for the two tracks (lengths: %1% and %2%)")) % m_header->get_size() % fsrc->m_header->get_size()).str();
     return CAN_CONNECT_MAYBE_CODECPRIVATE;
