@@ -29,14 +29,14 @@ private:
   FLAC__StreamMetadata_StreamInfo m_stream_info;
 
 public:
-  flac_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, unsigned char *header, int l_header) throw (error_c);
+  flac_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, unsigned char *header, int l_header);
   virtual ~flac_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "FLAC";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("FLAC") : "FLAC";
   }
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
