@@ -27,19 +27,19 @@ private:
   int m_samples_per_sec, m_channels, m_samples_per_frame;
   byte_buffer_c m_byte_buffer;
   bool m_codec_id_set, m_valid_headers_found;
-  int64_t m_previous_timecode, m_num_packets_with_same_timecode;
+  int64_t m_previous_timecode, m_num_packets_since_previous_timecode;
   samples_to_timecode_converter_c m_s2tc;
   int64_t m_single_packet_duration;
 
 public:
-  mp3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, bool source_is_good) throw (error_c);
+  mp3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, bool source_is_good);
   virtual ~mp3_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "MP3";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("MP3") : "MP3";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
