@@ -58,7 +58,7 @@ mpeg4_p2_video_packetizer_c(generic_reader_c *p_reader,
     // packetizer because it takes care of handling the default
     // duration/FPS itself.
     if (m_ti.m_ext_timecodes.empty())
-      m_timecode_factory.clear();
+      m_timecode_factory.reset();
 
     if (m_default_duration_forced)
       m_fps = 1000000000.0 / m_htrack_default_duration;
@@ -173,11 +173,11 @@ mpeg4_p2_video_packetizer_c::process_non_native(packet_cptr packet) {
 
 void
 mpeg4_p2_video_packetizer_c::extract_config_data(packet_cptr &packet) {
-  if (nullptr != m_ti.m_private_data)
+  if (m_ti.m_private_data)
     return;
 
   memory_c *config_data = mpeg4::p2::parse_config_data(packet->data->get_buffer(), packet->data->get_size(), m_config_data);
-  if (nullptr == config_data)
+  if (!config_data)
     mxerror_tid(m_ti.m_fname, m_ti.m_id, Y("Could not find the codec configuration data in the first MPEG-4 part 2 video frame. This track cannot be stored in native mode.\n"));
 
   m_ti.m_private_data = (unsigned char *)safememdup(config_data->get_buffer(), config_data->get_size());
@@ -193,7 +193,7 @@ void
 mpeg4_p2_video_packetizer_c::fix_codec_string() {
   static const unsigned char start_code[4] = {0x00, 0x00, 0x01, 0xb2};
 
-  if ((nullptr == m_ti.m_private_data) || (0 == m_ti.m_private_size))
+  if (!m_ti.m_private_data || (0 == m_ti.m_private_size))
     return;
 
   int size = m_ti.m_private_size;
@@ -211,7 +211,7 @@ mpeg4_p2_video_packetizer_c::fix_codec_string() {
       continue;
 
     unsigned char *end_pos = (unsigned char *)memchr(&m_ti.m_private_data[i], 0, size);
-    if (nullptr == end_pos)
+    if (!end_pos)
       end_pos = &m_ti.m_private_data[i + size];
 
     --end_pos;
@@ -383,4 +383,3 @@ mpeg4_p2_video_packetizer_c::extract_size(const unsigned char *buffer,
   } else if (50 <= m_frames_output)
     m_aspect_ratio_extracted = true;
 }
-
