@@ -31,7 +31,7 @@ ra_packetizer_c::ra_packetizer_c(generic_reader_c *p_reader,
   , m_channels(channels)
   , m_bits_per_sample(bits_per_sample)
   , m_fourcc(fourcc)
-  , m_private_data(private_data.is_set() ? private_data->clone() : private_data)
+  , m_private_data(private_data ? private_data->clone() : private_data)
 {
   set_track_type(track_audio, TFA_SHORT_QUEUEING);
 }
@@ -43,11 +43,11 @@ void
 ra_packetizer_c::set_headers() {
   std::string codec_id = (boost::format("A_REAL/%1%%2%%3%%4%")
                           % (char)(m_fourcc >> 24) % (char)((m_fourcc >> 16) & 0xff) % (char)((m_fourcc >> 8) & 0xff) % (char)(m_fourcc & 0xff)).str();
-  set_codec_id(ba::to_upper_copy(codec_id));
+  set_codec_id(balg::to_upper_copy(codec_id));
   set_audio_sampling_freq((float)m_samples_per_sec);
   set_audio_channels(m_channels);
   set_audio_bit_depth(m_bits_per_sample);
-  if (m_private_data.is_set())
+  if (m_private_data)
     set_codec_private(m_private_data->get_buffer(), m_private_data->get_size());
 
   generic_packetizer_c::set_headers();
@@ -65,7 +65,7 @@ connection_result_e
 ra_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                 std::string &error_message) {
   ra_packetizer_c *psrc = dynamic_cast<ra_packetizer_c *>(src);
-  if (nullptr == psrc)
+  if (!psrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_a_samplerate(m_samples_per_sec, psrc->m_samples_per_sec);
