@@ -186,7 +186,7 @@ connection_result_e
 truehd_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                  std::string &error_message) {
   truehd_packetizer_c *asrc = dynamic_cast<truehd_packetizer_c *>(src);
-  if (nullptr == asrc)
+  if (!asrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_a_samplerate(m_first_truehd_header.m_sampling_rate, asrc->m_first_truehd_header.m_sampling_rate);
