@@ -24,14 +24,14 @@ private:
   int64_t m_samples_output;
 
 public:
-  tta_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int channels, int bits_per_sample, int sample_rate) throw (error_c);
+  tta_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int channels, int bits_per_sample, int sample_rate);
   virtual ~tta_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "TTA";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("TTA") : "TTA";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
