@@ -52,7 +52,7 @@ connection_result_e
 vp8_video_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                        std::string &error_message) {
   vp8_video_packetizer_c *psrc = dynamic_cast<vp8_video_packetizer_c *>(src);
-  if (nullptr == psrc)
+  if (!psrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_codec_id(m_hcodec_id, psrc->m_hcodec_id);
