@@ -42,7 +42,7 @@ change_c::change_c(change_c::change_type_e type,
 
 void
 change_c::validate(std::vector<property_element_c> *property_table) {
-  if (nullptr == property_table)
+  if (!property_table)
     return;
 
   for (auto &property : *property_table)
@@ -93,14 +93,14 @@ change_c::lookup_property(std::vector<property_element_c> &table) {
 void
 change_c::parse_value() {
   switch (m_property.m_type) {
-    case EBMLT_STRING:  parse_ascii_string();          break;
-    case EBMLT_USTRING: parse_unicode_string();        break;
-    case EBMLT_UINT:    parse_unsigned_integer();      break;
-    case EBMLT_INT:     parse_signed_integer();        break;
-    case EBMLT_BOOL:    parse_boolean();               break;
-    case EBMLT_BINARY:  parse_binary();                break;
-    case EBMLT_FLOAT:   parse_floating_point_number(); break;
-    default:            assert(false);
+    case property_element_c::EBMLT_STRING:  parse_ascii_string();          break;
+    case property_element_c::EBMLT_USTRING: parse_unicode_string();        break;
+    case property_element_c::EBMLT_UINT:    parse_unsigned_integer();      break;
+    case property_element_c::EBMLT_INT:     parse_signed_integer();        break;
+    case property_element_c::EBMLT_BOOL:    parse_boolean();               break;
+    case property_element_c::EBMLT_BINARY:  parse_binary();                break;
+    case property_element_c::EBMLT_FLOAT:   parse_floating_point_number(); break;
+    default:                                assert(false);
   }
 }
 
@@ -121,13 +121,13 @@ change_c::parse_unicode_string() {
 
 void
 change_c::parse_unsigned_integer() {
-  if (!parse_uint(m_value, m_ui_value))
+  if (!parse_number(m_value, m_ui_value))
     mxerror(boost::format(Y("The property value is not a valid unsigned integer in '%1%'. %2%\n")) % get_spec() % FILE_NOT_MODIFIED);
 }
 
 void
 change_c::parse_signed_integer() {
-  if (!parse_int(m_value, m_si_value))
+  if (!parse_number(m_value, m_si_value))
     mxerror(boost::format(Y("The property value is not a valid signed integer in '%1%'. %2%\n")) % get_spec() % FILE_NOT_MODIFIED);
 }
 
@@ -142,7 +142,7 @@ change_c::parse_boolean() {
 
 void
 change_c::parse_floating_point_number() {
-  if (!parse_double(m_value, m_fp_value))
+  if (!parse_number(m_value, m_fp_value))
     mxerror(boost::format(Y("The property value is not a valid floating point number in '%1%'. %2%\n")) % get_spec() % FILE_NOT_MODIFIED);
 }
 
@@ -158,9 +158,9 @@ change_c::parse_binary() {
 void
 change_c::execute(EbmlMaster *master,
                   EbmlMaster *sub_master) {
-  m_master = nullptr == m_property.m_sub_master_callbacks ? master : sub_master;
+  m_master = !m_property.m_sub_master_callbacks ? master : sub_master;
 
-  if (nullptr == m_master)
+  if (!m_master)
     return;
 
   if (change_c::ct_delete == m_type)
@@ -213,7 +213,7 @@ change_c::execute_add_or_set() {
   }
 
   const EbmlSemantic *semantic = get_semantic();
-  if ((nullptr != semantic) && semantic->Unique)
+  if (semantic && semantic->Unique)
     mxerror(boost::format(Y("This property is unique. More instances cannot be added in '%1%'. %2%\n")) % get_spec() % FILE_NOT_MODIFIED);
 
   do_add_element();
@@ -233,21 +233,21 @@ change_c::set_element_at(int idx) {
   EbmlElement *e = (*m_master)[idx];
 
   switch (m_property.m_type) {
-    case EBMLT_STRING:  *static_cast<EbmlString *>(e)        = m_s_value;                                  break;
-    case EBMLT_USTRING: *static_cast<EbmlUnicodeString *>(e) = cstrutf8_to_UTFstring(m_s_value);           break;
-    case EBMLT_UINT:    *static_cast<EbmlUInteger *>(e)      = m_ui_value;                                 break;
-    case EBMLT_INT:     *static_cast<EbmlSInteger *>(e)      = m_si_value;                                 break;
-    case EBMLT_BOOL:    *static_cast<EbmlUInteger *>(e)      = m_b_value ? 1 : 0;                          break;
-    case EBMLT_FLOAT:   *static_cast<EbmlFloat *>(e)         = m_fp_value;                                 break;
-    case EBMLT_BINARY:   static_cast<EbmlBinary *>(e)->CopyBuffer(m_x_value.data(), m_x_value.size() / 8); break;
-    default:            assert(false);
+    case property_element_c::EBMLT_STRING:  *static_cast<EbmlString *>(e)        = m_s_value;                                  break;
+    case property_element_c::EBMLT_USTRING: *static_cast<EbmlUnicodeString *>(e) = cstrutf8_to_UTFstring(m_s_value);           break;
+    case property_element_c::EBMLT_UINT:    *static_cast<EbmlUInteger *>(e)      = m_ui_value;                                 break;
+    case property_element_c::EBMLT_INT:     *static_cast<EbmlSInteger *>(e)      = m_si_value;                                 break;
+    case property_element_c::EBMLT_BOOL:    *static_cast<EbmlUInteger *>(e)      = m_b_value ? 1 : 0;                          break;
+    case property_element_c::EBMLT_FLOAT:   *static_cast<EbmlFloat *>(e)         = m_fp_value;                                 break;
+    case property_element_c::EBMLT_BINARY:   static_cast<EbmlBinary *>(e)->CopyBuffer(m_x_value.data(), m_x_value.size() / 8); break;
+    default:                                 assert(false);
   }
 }
 
 void
 change_c::validate_deletion_of_mandatory() {
   const EbmlSemantic *semantic = get_semantic();
-  if ((nullptr != semantic) && semantic->Mandatory)
+  if (semantic && semantic->Mandatory)
     mxerror(boost::format(Y("This property is mandatory and cannot be deleted in '%1%'. %2%\n")) % get_spec() % FILE_NOT_MODIFIED);
 }
 
