@@ -57,7 +57,7 @@ write_changes(options_cptr &options,
 
   for (auto &id_to_write : ids_to_write) {
     for (auto &target : options->m_targets) {
-      if (nullptr == target->m_level1_element)
+      if (!target->m_level1_element)
         continue;
 
       EbmlMaster &l1_element = *target->m_level1_element;
@@ -96,7 +96,7 @@ run(options_cptr &options) {
   if (!analyzer->process(options->m_parse_mode))
     mxerror(Y("This file could not be opened or parsed.\n"));
 
-  options->find_elements(analyzer.get_object());
+  options->find_elements(analyzer.get());
   options->validate();
 
   if (debugging_requested("dump_options")) {
@@ -108,7 +108,7 @@ run(options_cptr &options) {
 
   mxinfo(Y("The changes are written to the file.\n"));
 
-  write_changes(options, analyzer.get_object());
+  write_changes(options, analyzer.get());
 
   mxinfo(Y("Done.\n"));
 
@@ -117,7 +117,7 @@ run(options_cptr &options) {
 
 static
 void setup() {
-  mtx_common_init();
+  mtx_common_init("mkvpropedit");
   clear_list_of_unique_uint32(UNIQUE_ALL_IDS);
   version_info = get_version_info("mkvpropedit", vif_full);
 }
