@@ -24,8 +24,7 @@
 #include "common/output.h"
 #include "common/strings/editing.h"
 #include "common/strings/parsing.h"
-#include "common/tags/parser.h"
-#include "common/tags/tags.h"
+#include "common/xml/ebml_tags_converter.h"
 #include "propedit/propedit.h"
 #include "propedit/target.h"
 
@@ -52,12 +51,12 @@ target_c::validate() {
   assert(target_c::tt_undefined != m_type);
 
   std::vector<property_element_c> *property_table
-    = nullptr == m_level1_element ? nullptr
-    :                            &property_element_c::get_table_for(target_c::tt_segment_info == m_type ? KaxInfo::ClassInfos : KaxTracks::ClassInfos,
-                                                                      track_audio == m_track_type ? &KaxTrackAudio::ClassInfos
-                                                                    : track_video == m_track_type ? &KaxTrackVideo::ClassInfos
-                                                                    :                               nullptr,
-                                                                    false);
+    = !m_level1_element ? nullptr
+    :                   &property_element_c::get_table_for(target_c::tt_segment_info == m_type ? KaxInfo::ClassInfos : KaxTracks::ClassInfos,
+                                                             track_audio == m_track_type ? &KaxTrackAudio::ClassInfos
+                                                           : track_video == m_track_type ? &KaxTrackVideo::ClassInfos
+                                                           :                               nullptr,
+                                                           false);
 
   for (auto &change : m_changes)
     change->validate(property_table);
@@ -91,7 +90,7 @@ target_c::parse_target_spec(std::string spec) {
     return;
 
   m_spec = spec;
-  ba::to_lower(spec);
+  balg::to_lower(spec);
 
   if ((spec == "segment_info") || (spec == "segmentinfo") || (spec == "info")) {
     m_type = target_c::tt_segment_info;
@@ -99,7 +98,7 @@ target_c::parse_target_spec(std::string spec) {
   }
 
   std::string prefix("track:");
-  if (ba::istarts_with(spec, prefix)) {
+  if (balg::istarts_with(spec, prefix)) {
     m_type = target_c::tt_track;
     parse_track_spec(spec.substr(prefix.length()));
     return;
@@ -117,7 +116,7 @@ target_c::parse_track_spec(const std::string &spec) {
     throw false;
 
   std::string prefix = matches[1].str();
-  parse_uint(matches[2].str(), m_selection_param);
+  parse_number(matches[2].str(), m_selection_param);
 
   m_selection_mode = prefix.empty() ? target_c::sm_by_position
                    : prefix == "="  ? target_c::sm_by_uid
@@ -140,7 +139,7 @@ void
 target_c::parse_tags_spec(const std::string &spec) {
   m_spec                         = spec;
   std::vector<std::string> parts = split(spec, ":", 2);
-  ba::to_lower(parts[0]);
+  balg::to_lower(parts[0]);
 
   if (parts[0] == "all")
     m_tag_operation_mode = target_c::tom_all;
@@ -151,7 +150,7 @@ target_c::parse_tags_spec(const std::string &spec) {
   else if (parts[0] == "track") {
     m_tag_operation_mode = target_c::tom_track;
     parts                = split(parts[1], ":", 2);
-    parse_track_spec(ba::to_lower_copy(parts[0]));
+    parse_track_spec(balg::to_lower_copy(parts[0]));
 
   } else
     throw false;
@@ -227,7 +226,7 @@ void
 target_c::set_level1_element(ebml_element_cptr level1_element_cp,
                              ebml_element_cptr track_headers_cp) {
   m_level1_element_cp = level1_element_cp;
-  m_level1_element    = static_cast<EbmlMaster *>(m_level1_element_cp.get_object());
+  m_level1_element    = static_cast<EbmlMaster *>(m_level1_element_cp.get());
 
   m_track_headers_cp  = track_headers_cp;
 
@@ -250,7 +249,7 @@ target_c::set_level1_element(ebml_element_cptr level1_element_cp,
   if (!track_headers_cp)
     track_headers_cp = level1_element_cp;
 
-  EbmlMaster *track_headers = static_cast<EbmlMaster *>(track_headers_cp.get_object());
+  EbmlMaster *track_headers = static_cast<EbmlMaster *>(track_headers_cp.get());
 
   size_t i;
   for (i = 0; track_headers->ListSize() > i; ++i) {
@@ -258,15 +257,15 @@ target_c::set_level1_element(ebml_element_cptr level1_element_cp,
       continue;
 
     KaxTrackEntry *track = dynamic_cast<KaxTrackEntry *>((*track_headers)[i]);
-    assert(nullptr != track);
+    assert(track);
 
-    KaxTrackType *kax_track_type     = dynamic_cast<KaxTrackType *>(FINDFIRST(track, KaxTrackType));
-    track_type this_track_type       = nullptr == kax_track_type ? track_video : static_cast<track_type>(uint8(*kax_track_type));
+    KaxTrackType *kax_track_type     = dynamic_cast<KaxTrackType *>(FindChild<KaxTrackType>(track));
+    track_type this_track_type       = !kax_track_type ? track_video : static_cast<track_type>(uint8(*kax_track_type));
 
-    KaxTrackUID *kax_track_uid       = dynamic_cast<KaxTrackUID *>(FINDFIRST(track, KaxTrackUID));
-    uint64_t track_uid               = nullptr == kax_track_uid ? 0 : uint64(*kax_track_uid);
+    KaxTrackUID *kax_track_uid       = dynamic_cast<KaxTrackUID *>(FindChild<KaxTrackUID>(track));
+    uint64_t track_uid               = !kax_track_uid ? 0 : uint64(*kax_track_uid);
 
-    KaxTrackNumber *kax_track_number = dynamic_cast<KaxTrackNumber *>(FINDFIRST(track, KaxTrackNumber));
+    KaxTrackNumber *kax_track_number = dynamic_cast<KaxTrackNumber *>(FindChild<KaxTrackNumber>(track));
 
     ++num_tracks_total;
     ++num_tracks_by_type[this_track_type];
@@ -278,7 +277,7 @@ target_c::set_level1_element(ebml_element_cptr level1_element_cp,
 
     bool track_matches = target_c::sm_by_uid      == m_selection_mode ? m_selection_param == track_uid
                        : target_c::sm_by_position == m_selection_mode ? m_selection_param == num_tracks_total
-                       : target_c::sm_by_number   == m_selection_mode ? (nullptr            != kax_track_number)       && (m_selection_param == uint64(*kax_track_number))
+                       : target_c::sm_by_number   == m_selection_mode ? kax_track_number  && (m_selection_param == uint64(*kax_track_number))
                        :                                                (this_track_type == m_selection_track_type) && (m_selection_param == num_tracks_by_type[this_track_type]);
 
     if (!track_matches)
@@ -287,11 +286,11 @@ target_c::set_level1_element(ebml_element_cptr level1_element_cp,
     m_track_uid  = track_uid;
     m_track_type = this_track_type;
     m_master     = track;
-    m_sub_master = track_video == m_track_type ? dynamic_cast<EbmlMaster *>(FINDFIRST(track, KaxTrackVideo))
-                 : track_audio == m_track_type ? dynamic_cast<EbmlMaster *>(FINDFIRST(track, KaxTrackAudio))
+    m_sub_master = track_video == m_track_type ? dynamic_cast<EbmlMaster *>(FindChild<KaxTrackVideo>(track))
+                 : track_audio == m_track_type ? dynamic_cast<EbmlMaster *>(FindChild<KaxTrackAudio>(track))
                  :                               nullptr;
 
-    if (   (nullptr == m_sub_master)
+    if (   !m_sub_master
         && (   (track_video == m_track_type)
             || (track_audio == m_track_type))
         && has_add_or_set_change()) {
@@ -328,27 +327,23 @@ target_c::execute() {
 
 void
 target_c::add_or_replace_tags() {
-  KaxTags *new_tags = nullptr;
+  kax_tags_cptr new_tags;
 
-  if (!m_file_name.empty()) {
-    new_tags = new KaxTags;
-    parse_xml_tags(m_file_name, new_tags);
-  }
+  if (!m_file_name.empty())
+    new_tags = mtx::xml::ebml_tags_converter_c::parse_file(m_file_name);
 
   if (target_c::tom_all == m_tag_operation_mode)
-    add_or_replace_all_master_elements(new_tags);
+    add_or_replace_all_master_elements(new_tags.get());
 
   else if (target_c::tom_global == m_tag_operation_mode)
-    add_or_replace_global_tags(new_tags);
+    add_or_replace_global_tags(new_tags.get());
 
   else if (target_c::tom_track == m_tag_operation_mode)
-    add_or_replace_track_tags(new_tags);
+    add_or_replace_track_tags(new_tags.get());
 
   else
     assert(false);
 
-  delete new_tags;
-
   if (m_level1_element->ListSize()) {
     fix_mandatory_tag_elements(m_level1_element);
     if (!m_level1_element->CheckMandatory())
@@ -376,7 +371,7 @@ target_c::add_or_replace_global_tags(KaxTags *tags) {
   size_t idx = 0;
   while (m_level1_element->ListSize() > idx) {
     KaxTag *tag = dynamic_cast<KaxTag *>((*m_level1_element)[idx]);
-    if ((nullptr == tag) || (-1 != get_tag_tuid(*tag)))
+    if (!tag || (-1 != get_tag_tuid(*tag)))
       ++idx;
     else {
       delete tag;
@@ -388,7 +383,7 @@ target_c::add_or_replace_global_tags(KaxTags *tags) {
     idx = 0;
     while (tags->ListSize() > idx) {
       KaxTag *tag = dynamic_cast<KaxTag *>((*tags)[0]);
-      if ((nullptr == tag) || (-1 != get_tag_tuid(*tag)))
+      if (!tag || (-1 != get_tag_tuid(*tag)))
         ++idx;
       else {
         m_level1_element->PushElement(*tag);
@@ -405,7 +400,7 @@ target_c::add_or_replace_track_tags(KaxTags *tags) {
   size_t idx = 0;
   while (m_level1_element->ListSize() > idx) {
     KaxTag *tag = dynamic_cast<KaxTag *>((*m_level1_element)[idx]);
-    if ((nullptr == tag) || (track_uid != get_tag_tuid(*tag)))
+    if (!tag || (track_uid != get_tag_tuid(*tag)))
       ++idx;
     else {
       delete tag;
@@ -419,7 +414,7 @@ target_c::add_or_replace_track_tags(KaxTags *tags) {
     idx = 0;
     while (tags->ListSize() > idx) {
       KaxTag *tag = dynamic_cast<KaxTag *>((*tags)[0]);
-      if (nullptr == tag)
+      if (!tag)
         ++idx;
       else {
         GetChildAs<KaxTagTrackUID, EbmlUInteger>(GetChild<KaxTagTargets>(tag)) = track_uid;
@@ -432,16 +427,12 @@ target_c::add_or_replace_track_tags(KaxTags *tags) {
 
 void
 target_c::add_or_replace_chapters() {
-  KaxChapters *new_chapters = nullptr;
+  kax_chapters_cptr new_chapters{};
 
-  if (!m_file_name.empty()) {
-    new_chapters = new KaxChapters;
+  if (!m_file_name.empty())
     new_chapters = parse_chapters(m_file_name);
-  }
 
-  add_or_replace_all_master_elements(new_chapters);
-
-  delete new_chapters;
+  add_or_replace_all_master_elements(new_chapters.get());
 
   if (m_level1_element->ListSize()) {
     fix_mandatory_chapter_elements(m_level1_element);
@@ -449,4 +440,3 @@ target_c::add_or_replace_chapters() {
       mxerror(boost::format(Y("Error parsing the chapters in '%1%': some mandatory elements are missing.\n")) % m_file_name);
   }
 }
-
