@@ -17,15 +17,15 @@ class T_217file_identification < Test
       "data/ogg/v.ogg",
       "data/rm/rv3.rm",
       "data/rm/rv4.rm",
-      "data/simple/misdetected_as_mp2.ac3",
-      "data/simple/misdetected_as_mpeges.ac3",
-      "data/simple/v.aac",
-      "data/simple/v.ac3",
+      "data/ac3/misdetected_as_mp2.ac3",
+      "data/ac3/misdetected_as_mpeges.ac3",
+      "data/aac/v.aac",
+      "data/ac3/v.ac3",
       "data/simple/v.flac",
       "data/simple/v.mp3",
-      "data/simple/v.wav",
-      "data/textsubs/fe.ssa",
-      "data/textsubs/vde.srt",
+      "data/wav/v.wav",
+      "data/ssa-ass/fe.ssa",
+      "data/srt/vde.srt",
       "data/vobsub/ally1-short.sub",
       "data/wp/with-correction.wv",
       "data/wp/without-correction.wv"
