@@ -6,7 +6,7 @@ class T_233srt_with_coordinates < Test
   end
 
   def run
-    merge(1, "data/textsubs/season2_us_disc1_episode01.srt")
+    merge(1, "data/srt/season2_us_disc1_episode01.srt")
     return hash_tmp
   end
 end
