@@ -123,6 +123,10 @@ class SimpleTest
       :name  => full_command_line,
       :block => lambda {
         sys "../src/mkvmerge #{full_command_line} > #{tmp}", :exit_code => options[:exit_code]
+        if options[:filter]
+          text = options[:filter].call(IO.readlines(tmp).join(''))
+          File.open(tmp, 'w') { |file| file.puts text }
+        end
         options[:keep_tmp] ? hash_file(tmp) : hash_tmp
       },
     }
@@ -198,6 +202,7 @@ class SimpleTest
 
     output  = options[:output] || self.tmp
     output  = "> #{output}" unless /^[>\|]/.match(output)
+    output  = '' if options[:output] == :return
     command = "../src/mkvinfo --engage no_variable_data --ui-language en_US #{args.first} #{output}"
     self.sys command, :exit_code => options[:exit_code]
   end
@@ -219,9 +224,16 @@ class SimpleTest
 
     command    = args.shift
     @commands << command
-    command   << " >/dev/null 2>/dev/null " unless />/.match(command)
+
+    if !/>/.match command
+      temp_file = Tempfile.new('mkvtoolnix-test-output')
+      temp_file.close
+      command  << " >#{temp_file.path} 2>&1 "
+    end
 
     self.error "system command failed: #{command} (#{$? >> 8})" if !system(command) && (options[:exit_code] != ($? >> 8))
+
+    return IO.readlines(temp_file.path) if temp_file
   end
 
   def error reason
