@@ -28,11 +28,11 @@ LOGFILE=$(mktemp)
 function update_mingw_cross_env {
   if [[ ! -d $INSTALL_DIR ]]; then
     echo Retrieving the mingw-cross-env build scripts >> $LOGFILE
-    hg clone http://hg.savannah.nongnu.org/hgweb/mingw-cross-env $INSTALL_DIR >> $LOGFILE 2>&1
+    git clone https://github.com/mxe/mxe $INSTALL_DIR >> $LOGFILE 2>&1
   else
     echo Updating the mingw-cross-env build scripts >> $LOGFILE
     cd $INSTALL_DIR
-    hg update >> $LOGFILE 2>&1
+    git pull >> $LOGFILE 2>&1
   fi
 }
 
@@ -91,7 +91,7 @@ function build_base {
 function build_libraries {
   echo Building the required libraries
   cd ${INSTALL_DIR}
-  make TARGET=${TARGET} JOBS=${PARALLEL} gettext boost bzip2 curl flac expat libiconv ogg pthreads vorbis wxwidgets zlib >> $LOGFILE 2>&1
+  make TARGET=${TARGET} JOBS=${PARALLEL} gettext boost bzip2 curl file flac libiconv lzo ogg pthreads vorbis wxwidgets zlib >> $LOGFILE 2>&1
 }
 
 # main
